/** 
 * Copyright Intermesh
 * 
 * This file is part of Group-Office. You should have received a copy of the
 * Group-Office license along with Group-Office. See the file /LICENSE.TXT
 * 
 * If you have questions write an e-mail to info@intermesh.nl
 * 
 * @copyright Copyright Intermesh
 * @version $Id: BookDialog.js 8517 2010-07-22 09:29:56Z mschering $
 * @author Merijn Schering <mschering@intermesh.nl>
 */

GO.billing.BookDialog = function(config){
	
	
	if(!config)
	{
		config={};
	}
	
	
	this.buildForm();
	
	var focusFirstField = function(){
		this.propertiesPanel.items.items[0].focus();
	};
	
	
	config.maximizable=true;
	config.layout='fit';
	config.modal=false;
	config.resizable=false;
	config.width=700;
	config.height=530;
	config.closeAction='hide';
	config.title= GO.billing.lang.book;					
	config.items= this.formPanel;
	config.focus= focusFirstField.createDelegate(this);
	config.buttons=[{
		text: GO.lang['cmdOk'],
		handler: function(){
			this.submitForm(true);
		},
		scope: this
	},{
		text: GO.lang['cmdApply'],
		handler: function(){
			this.submitForm();
		},
		scope:this
	},{
		text: GO.lang['cmdClose'],
		handler: function(){
			this.hide();
		},
		scope:this
	}
	];
	
	GO.billing.BookDialog.superclass.constructor.call(this, config);
	this.addEvents({
		'save' : true
	});
}
Ext.extend(GO.billing.BookDialog, Ext.Window,{
	
	show : function (book_id) {
		if(!this.rendered)
		{
			this.render(Ext.getBody());
		}
				
		this.tabPanel.setActiveTab(0);		
		
		if(!book_id)
		{
			book_id=0;			
		}
			
		this.setBookId(book_id);
		
		if(this.book_id>0)
		{
			this.formPanel.load({
				url : GO.settings.modules.billing.url+'json.php',
				
				success:function(form, action)
				{
					this.readPermissionsTab.setAcl(action.result.data.acl_id);

					this.selectUser.setRemoteText(action.result.data.user_name);									
					
					GO.billing.BookDialog.superclass.show.call(this);
				},
				failure:function(form, action)
				{
					Ext.Msg.alert(GO.lang['strError'], action.result.feedback)
				},
				scope: this
				
			});
		}else 
		{			
			this.formPanel.form.reset();
			this.readPermissionsTab.setAcl(0);
			
			GO.billing.BookDialog.superclass.show.call(this);
		}
	},
	
	setBookId : function(book_id)
	{
		this.formPanel.form.baseParams['book_id']=book_id;
		this.book_id=book_id;
		
		this.orderStatusesTab.setBookId(book_id);
		this.costCodesGrid.setBookId(book_id);
		
		if(book_id>0)
		{
			this.templatesTab.setDisabled(false);
			this.templatesTab.store.baseParams.book_id=book_id;
			this.templatesTab.store.on('load', function(){
				this.body.unmask();
			}, this);
			
			this.body.mask(GO.lang.waitMsgLoad);
			this.templatesTab.store.load();			
		}else
		{
			this.templatesTab.setDisabled(true);
		}		
	},
	
	submitForm : function(hide){
		this.formPanel.form.submit(
		{
			url:GO.settings.modules.billing.url+'action.php',
			params: {
				'task' : 'save_book'
			},
			waitMsg:GO.lang['waitMsgSave'],
			success:function(form, action){
								
				this.fireEvent('save', this);
				
				if(hide)
				{
					this.hide();	
				}else
				{
					if(action.result.book_id)
					{
						this.setBookId(action.result.book_id);
						
						this.readPermissionsTab.setAcl(action.result.acl_id);
					}
				}									
			},		
			failure: function(form, action) {
				if(action.failureType == 'client')
				{					
					Ext.MessageBox.alert(GO.lang['strError'], GO.lang['strErrorsInForm']);			
				} else {
					Ext.MessageBox.alert(GO.lang['strError'], action.result.feedback);
				}
			},
			scope: this
		});
		
	},
	
	
		
	
	
	buildForm : function () {
		
		
		var propItems = [
		this.selectUser = new GO.form.SelectUser({
			fieldLabel: GO.lang['strUser'],
			disabled: !GO.settings.modules['billing']['write_permission'],
			value: GO.settings.user_id,
			anchor: '-20'
		}),{
			xtype: 'textfield',
			name: 'name',
			anchor: '-20',
			allowBlank:false,
			fieldLabel: GO.lang.strName
		},{
			xtype: 'textfield',
			name: 'order_id_prefix',
			anchor: '-20',
			allowBlank:false,
			fieldLabel: GO.billing.lang.orderIdPrefix,
			value: "%y-"
		},{
			xtype: 'textfield',
			name: 'next_id',
			value: 0,
			anchor: '-20',
			allowBlank:false,
			fieldLabel: GO.billing.lang.nextId
		},{
			xtype: 'numberfield',
			name: 'default_vat',
			anchor: '-20',
			allowBlank:false,
			fieldLabel: GO.billing.lang.defaultVat
		},{
			xtype: 'textfield',
			name: 'currency',
			anchor: '-20',
			allowBlank:false,
			fieldLabel: GO.billing.lang.currency,
			value: GO.settings.currency
		},{
			xtype: 'textarea',
			name: 'order_csv_template',
			anchor: '-20',
			allowBlank:true,
			fieldLabel: GO.billing.lang.orderCsvTemplate
		},{
			xtype: 'textarea',
			name: 'item_csv_template',
			anchor: '-20',
			allowBlank:true,
			fieldLabel: GO.billing.lang.itemCsvTemplate
		},
		new GO.form.SelectCountry({
			name: 'country_text',
			hiddenName: 'country',
			anchor:'-20',
			allowBlank:false,
			fieldLabel: GO.lang.strCountry
		}),
		{
			xtype: 'textfield',
			name: 'bcc',
			anchor: '-20',
			allowBlank:true,
			fieldLabel: GO.billing.lang.bcc
		},{
			xtype: 'textfield',
			name: 'sender_email',
			anchor: '-20',
			fieldLabel: GO.billing.lang.sender_email
		},{
			xtype: 'textfield',
			name: 'sender_name',
			anchor: '-20',
			fieldLabel: GO.billing.lang.sender_name
		}];
			
		if(GO.tasks)
		{
			propItems.push({
				xtype: 'numberfield',
				decimals:0,
				name: 'call_after_days',
				anchor: '-20',
				allowBlank:true,
				fieldLabel: GO.billing.lang.callAfterDays
			});
		}
		
		this.propertiesPanel = new Ext.Panel({
			url: GO.settings.modules.billing.url+'action.php',
			border: false,
			baseParams: {
				task: 'book'
			},
			title:GO.lang['strProperties'],			
			cls:'go-form-panel',			
			layout:'form',
			autoScroll:true,
			items: propItems				
		});
		var items  = [this.propertiesPanel];
		
		this.templatesTab = new GO.billing.TemplatesGrid();
		items.push(this.templatesTab);
    
		this.orderStatusesTab = new GO.billing.OrderStatusesGrid();
		items.push(this.orderStatusesTab);

		this.costCodesGrid = new GO.billing.CostCodesGrid();
		items.push(this.costCodesGrid);
		
		this.readPermissionsTab = new GO.grid.PermissionsPanel();
		items.push(this.readPermissionsTab);		
 
		this.tabPanel = new Ext.TabPanel({
			activeTab: 0,
			deferredRender: false,
			border: false,
			items: items,
			anchor: '100% 100%'
		}) ;
    
    
		this.formPanel = new Ext.form.FormPanel({
			waitMsgTarget:true,
			url: GO.settings.modules.billing.url+'action.php',
			border: false,
			baseParams: {
				task: 'book'
			},
			items:this.tabPanel				
		});
    
    
	}
});