/** 
 * Copyright Intermesh
 * 
 * This file is part of Group-Office. You should have received a copy of the
 * Group-Office license along with Group-Office. See the file /LICENSE.TXT
 * 
 * If you have questions write an e-mail to info@intermesh.nl
 * 
 * @version $Id: CatalogPanel.js 6934 2010-02-02 15:29:34Z wvbeusekom $
 * @copyright Copyright Intermesh
 * @author Merijn Schering <mschering@intermesh.nl>
 */
 
 
GO.billing.CatalogPanel = function(config){
	
	var linksDialog;
	
	//Ext.apply(this, config);
	
	if(!config)
	{
		config={};
	}
	
	this.categoriesTree = new GO.billing.CategoriesTree({
		region:'west',
		split:true,
		title:GO.billing.lang.categories,
		enableDD: true
		
	});
	
	this.categoriesTree.on('click', function(node)	{
		this.setCategory(node.id.substr(10));
	}, this);
	
	this.categoriesTree.on('beforenodedrop', function(e){
		
		var target = {
			category_id: e.target.id.substr(10)
		};
		
		var selections = [];		
		if(e.data.selections)
		{
			//dropped from grid
			for(var i=0;i<e.data.selections.length;i++)
			{
				if(e.data.selections[i].data.id.substr(0,1)=='f')
				{					
					var id = e.data.selections[i].data.id.substr(2);
					var movedNode = this.categoriesTree.getNodeById('bs-folder-'+id);
					var targetNode = this.categoriesTree.getNodeById('bs-folder-'+target.category_id);
					targetNode.appendChild(movedNode);
				}
				selections.push(e.data.selections[i].data.id);
			}
		}else
		{
			//dropped from tree		  
			var selections = ['f:'+e.data.node.id.substr(10)];
		}
		
		this.moveSelections(selections, target);		
	},
	this);
	
	this.productsGrid = new GO.billing.ProductsGrid({
		region:'center',
		enableDragDrop:true,
		deleteConfig: {
			scope:this,
			success:function(){
				var activeNode = this.categoriesTree.getNodeById('bs-folder-'+this.category_id);
				if(activeNode)
				{
					activeNode.reload();
				}else
				{
					this.categoriesTree.getRootNode().reload();
				}
			}
		}
	});
	
	this.productsGrid.on('folderDrop', function(grid, selections, dropRecord){
		var target = {
			category_id: dropRecord.data.id.substr(2)
		};
		var selectedKeys=[]
		for(var i=0;i<selections.length;i++)
		{
			selectedKeys.push(selections[i].data.id);
		}
		
		this.moveSelections(selectedKeys, target);
		this.categoriesTree.getRootNode().reload();
		
	}, this);
	
	this.categoryDialog = new GO.billing.CategoryDialog();
	this.categoryDialog.on('save', function(){
		this.productsGrid.store.reload();
		
		var activeNode = this.categoriesTree.getNodeById('bs-folder-'+this.category_id);
		if(activeNode && activeNode.parentNode)
		{
			activeNode.parentNode.reload();			
		}else
		{
			this.categoriesTree.getRootNode().reload();
		}
	}, this);
	
	config.items=[this.categoriesTree, this.productsGrid];	

	config['layout']='border';
	config.border=false;
	
	//was required to show the search field in the tbar
	config.hideMode='offsets';
		
	if(GO.settings.modules.billing.write_permission)
	{
		config['tbar'] = [{
			iconCls: 'btn-add',							
			text: GO.billing.lang.addProduct,
			cls: 'x-btn-text-icon',
			handler: function(){
				
				this.productsGrid.productDialog.show();
				this.productsGrid.productDialog.formPanel.baseParams.category_id=this.category_id;
			},
			scope: this
		},{
			iconCls: 'btn-add',							
			text: GO.billing.lang.addCategory,
			cls: 'x-btn-text-icon',
			handler: function(){
				
				this.categoryDialog.show();
				this.categoryDialog.formPanel.baseParams.parent_id=this.category_id;
			},
			scope: this
		},{
			iconCls: 'btn-delete',
			text: GO.lang['cmdDelete'],
			cls: 'x-btn-text-icon',
			handler: function(){
				this.productsGrid.deleteSelected();
			},
			scope: this
		},{
			iconCls: 'btn-copy',
			text: GO.lang.copy,
			handler: function(){
			
				var selModel = this.productsGrid.getSelectionModel().selections;
				var selModelTree = this.categoriesTree.getSelectionModel();
				if(selModel.items.length==0)
				{
					Ext.MessageBox.alert(GO.lang.strError, GO.billing.lang.selectFiles);
				}else
				{
					this.copyFolders=[];
					this.copyFiles=[];
					for(var i=0;i<selModel.items.length;i++)
					{
						if(this.itemType(selModel.items[i].id)=='p')
						{
							this.copyFiles.push(this.itemNumber(selModel.items[i].id));
						}else
						{
							this.copyFolders.push(this.itemNumber(selModel.items[i].id));
						}
					}

					this.pasteButton.setDisabled(false);


				}
			},
			scope: this
		},this.pasteButton = new Ext.Button({
			disabled:true,
			iconCls: 'btn-paste',
			text: GO.lang.paste,
			handler: function(){
				var selModelTree = this.categoriesTree.getSelectionModel();

				if(this.copyFolders.length==0 && this.copyFiles.length==0)
				{
					Ext.MessageBox.alert(GO.lang.strError, GO.billing.lang.selectDestination);
				}else
				{

						var destination_folder_id = this.category_id;
					var params = {
						task: 'copy',
						copy_folders: Ext.encode(this.copyFolders),
						copy_files: Ext.encode(this.copyFiles),
						destination_folder_id: destination_folder_id
					};

					Ext.Ajax.request({
						url: GO.settings.modules.billing.url+'action.php',
						params: params,
						callback: function(options, success, response)
						{
							if(!success)
							{
								Ext.MessageBox.alert(GO.lang['strError'], GO.lang['strRequestError']);
							}else
							{
								var responseParams = Ext.decode(response.responseText);
								if(!responseParams.success)
								{
									Ext.MessageBox.alert(GO.lang['strError'], responseParams.feedback);
								}else
								{
									this.productsGrid.store.load();
									this.categoriesTree.root.reload();

									this.copyFolders=[];
									this.copyFiles=[];
									this.pasteButton.setDisabled(true);
								}
							}
						},
						scope:this
					});

				}
			},
			scope: this
		}),this.editCategoryButton = new Ext.Button({
			iconCls: 'btn-edit',							
			text: GO.billing.lang.editCategory,
			cls: 'x-btn-text-icon',
			disabled: true,
			handler: function(){
				
				this.categoryDialog.show(this.category_id);
	    	
			},
			scope: this
		})
		];
	}
		
	this.productsGrid.on("rowdblclick", this.rowDoulbleClicked, this);
	
	
	GO.billing.CatalogPanel.superclass.constructor.call(this, config);
	
}

Ext.extend(GO.billing.CatalogPanel, Ext.Panel, {
	
	afterRender : function(){
		
		GO.billing.CatalogPanel.superclass.afterRender.call(this);
		
		this.setCategory(0);
	},
	
	
	moveSelections : function(selections, target)
	{
		Ext.Ajax.request({
			url: GO.settings.modules.billing.url+'action.php',
			params: {
				'task' : 'move_products',
				selections : Ext.encode(selections),
				target : Ext.encode(target)
			},
			callback: function(options, success, response){				
				
				if(!success)
				{
					Ext.MessageBox.alert(GO.lang['strError'], GO.lang['strRequestError']);
				}else
				{
					var responseParams = Ext.decode(response.responseText);
					
					if(responseParams.moved_products)
					{
						for(var i=0;i<responseParams.moved_products.length;i++)
						{
							var record = this.productsGrid.store.getById(responseParams.moved_products[i]);
							if(record)
							{
								this.productsGrid.store.remove(record);
							}
						}
					}					
				}
			},
			scope:this								
			
		});
		
		
	},
	
	
	rowDoulbleClicked : function(grid, rowClicked, e) {
			
		var selectionModel = grid.getSelectionModel();
		var record = selectionModel.getSelected();
		
		var type = record.data.id.substr(0,1);
		var id = record.data.id.substr(2);
		
		if(type=='f')
		{
			this.setCategory(id);			
		}else	
		{
			this.productsGrid.productDialog.show(id);
		}
	},
	

	
	setWritePermission : function(writePermission){
		this.linkButton.setDisabled(!writePermission);
		this.unlinkButton.setDisabled(!writePermission);
		this.newCategoryButton.setDisabled(!writePermission);
		this.deleteButton.setDisabled(!writePermission);		
	},
	
	setCategory : function(category_id)
	{
		var activeNode = this.categoriesTree.getNodeById('bs-folder-'+category_id);
		if(activeNode)
		{
			activeNode.expand();			
		}
		

		if(GO.settings.modules.billing.write_permission)
			this.editCategoryButton.setDisabled(category_id==0);
		
		
		this.categoryDialog.category_id=category_id;
		
		this.category_id=category_id;
		this.productsGrid.store.baseParams["category_id"]=category_id;
		this.productsGrid.store.load();
	},

	itemType : function ( id ) {
		return id.substr(0,1);
	},

	itemNumber : function ( id ) {
		return id.substr(2);
	},

	folderNumber : function (id) {
		return id.substr(10);
	}

});