/** 
 * Copyright Intermesh
 * 
 * This file is part of Group-Office. You should have received a copy of the
 * Group-Office license along with Group-Office. See the file /LICENSE.TXT
 * 
 * If you have questions write an e-mail to info@intermesh.nl
 * 
 * @copyright Copyright Intermesh
 * @version $Id: ItemDialog.js 3046 2008-09-17 09:40:47Z mschering $
 * @author Merijn Schering <mschering@intermesh.nl>
 */

 
GO.billing.ItemDialog = function(config){
	
	
	if(!config)
	{
		config={};
	}
	
	
	this.buildForm();
	
	var focusFirstField = function(){
		this.formPanel.items.items[0].focus();
	};
	
	
	config.maximizable=true;
	config.layout='fit';
	config.modal=false;
	config.resizable=false;
	config.width=700;
	config.autoHeight=true,
	config.closeAction='hide';
	config.title= GO.billing.lang.item;					
	config.items= this.formPanel;
	config.focus= focusFirstField.createDelegate(this);
	config.buttons=[{
			text: GO.lang['cmdOk'],
			handler: function(){
				this.submitForm(true);
			},
			scope: this
		},{
			text: GO.lang.cmdAddPlusNew,
			handler: function(){
				this.submitForm(false, true);
				
			},
			scope:this
		},{
			text: GO.lang['cmdApply'],
			handler: function(){
				this.submitForm();
			},
			scope:this
		},{
			text: GO.lang['cmdClose'],
			handler: function(){
				this.hide();
			},
			scope:this
		}					
	];
	
	GO.billing.ItemDialog.superclass.constructor.call(this, config);
	this.addEvents({'save' : true});	
}
Ext.extend(GO.billing.ItemDialog, Ext.Window,{
	
	unformattedInclPrice : 0,
	
	unformattedExclPrice : 0,
	
	calculateInclusivePrice : function(){  	
  	this.unformattedExclPrice = GO.util.unlocalizeNumber(this.priceField.getValue());
  	var vat = GO.util.unlocalizeNumber(this.vatField.getValue());  	
  	this.unformattedInclPrice = this.unformattedExclPrice*(1+(vat/100));  	
  	this.totalField.setValue(GO.util.numberFormat(this.unformattedInclPrice));
  },
  
  calculateExclusivePrice : function(){  	
  	this.unformattedInclPrice = GO.util.unlocalizeNumber(this.totalField.getValue());
  	var vat = GO.util.unlocalizeNumber(this.vatField.getValue());  	
  	this.unformattedExclPrice = this.unformattedInclPrice / (1+(vat/100));  	
  	this.priceField.setValue(GO.util.numberFormat(this.unformattedExclPrice ));
  },
	
	show : function (item_id) {
		if(!this.rendered)
		{
			this.render(Ext.getBody());
		}

		
		if(!item_id)
		{
			item_id=0;			
		}
			
		this.setItemId(item_id);
		
		if(this.item_id>0)
		{
			this.formPanel.load({
				url : GO.settings.modules.billing.url+'json.php',
				
				success:function(form, action)
				{
					this.unformattedExclPrice=action.result.data.unformatted_unit_price;
					this.unformattedInclPrice=action.result.data.unformatted_unit_total;
					
					this.productField.setRemoteText(action.result.data.product_name);
					
					GO.billing.ItemDialog.superclass.show.call(this);
				},
				failure:function(form, action)
				{
					Ext.Msg.alert(GO.lang['strError'], action.result.feedback)
				},
				scope: this
				
			});
		}else 
		{
			
			this.formPanel.form.reset();
			
			this.unformattedInclPrice=0;
			this.unformattedExclPrice=0;
			
			this.vatField.setValue(GO.util.numberFormat(GO.billing.defaultVAT));
			GO.billing.ItemDialog.superclass.show.call(this);
		}
	},
	
	setItemId : function(item_id)
	{
		this.formPanel.form.baseParams['item_id']=item_id;
		this.item_id=item_id;
		
	},
	
	submitForm : function(hide, reset){
		this.formPanel.form.submit(
		{
			url:GO.settings.modules.billing.url+'action.php',
			params: {
				'task' : 'save_item',
				unformatted_unit_price : this.unformattedExclPrice,
				unformatted_unit_total : this.unformattedInclPrice
			},
			waitMsg:GO.lang['waitMsgSave'],
			success:function(form, action){		
						
				this.fireEvent('save', this);
					
				if(hide)
				{
					this.hide();	
				}else if(reset)
				{					
					this.setItemId(0);
				}else
				{				
					if(action.result.item_id)
					{
						this.setItemId(action.result.item_id);
					}
				}
			},		
			failure: function(form, action) {
				if(action.failureType == 'client')
				{					
					Ext.MessageBox.alert(GO.lang['strError'], GO.lang['strErrorsInForm']);			
				} else {
					Ext.MessageBox.alert(GO.lang['strError'], action.result.feedback);
				}
			},
			scope: this
		});
		
	},
	
	
	buildForm : function () {
		
		
		this.productField = new GO.billing.SelectProduct({
					anchor: '100%',
					hiddenName: 'product_id',
				  allowBlank:true,
				  fieldLabel:GO.billing.lang.product,
				  emptyText: GO.billing.lang.productCatalogSearch
				});
				
		this.productField.on('select', function(combo, record){
			this.priceField.setValue();
			
			this.costField.setValue(GO.util.numberFormat(record.data.cost_price));
			this.unformattedExclPrice = record.data.list_price;
			this.vatField.setValue(GO.util.numberFormat(record.data.vat));
	  	
	  	this.listField.setValue(GO.util.numberFormat(this.unformattedExclPrice));
	  	this.priceField.setValue(GO.util.numberFormat(this.unformattedExclPrice));
	  	this.calculateInclusivePrice();
	  	
	  	this.descriptionField.setValue(record.data.name+"\n\n"+record.data.description);
	  	
		}, this);
		
		this.amountField = new GO.form.NumberField({
				width:80,
			  fieldLabel: GO.billing.lang.amount,
			  value: GO.util.numberFormat("1"),
			  name:'amount'
			});
			
		this.vatField = new GO.form.NumberField({
				width:80,
			  fieldLabel: GO.billing.lang.vat,
			  value: 19,
			  name:'vat'
			});
		this.priceField = new GO.form.NumberField({
				width:80,
			  fieldLabel: GO.billing.lang.unitPrice,
			  value: GO.util.numberFormat("0"),
			  name:'unit_price'
			});
		this.listField = new GO.form.NumberField({
				width:80,
			  fieldLabel: GO.billing.lang.unitList,
			  value: GO.util.numberFormat("0"),
			  name:'unit_list'
			});
		this.costField = new GO.form.NumberField({
				width:80,
			  fieldLabel: GO.billing.lang.unitCost,
			  value: GO.util.numberFormat("0"),
			  name:'unit_cost'
			});
		this.discountField = new GO.form.NumberField({
				width:80,
			  fieldLabel: GO.billing.lang.discount,
			  value: GO.util.numberFormat("0"),
			  name:'discount'
			});
		this.totalField = new GO.form.NumberField({
				width:80,
			  fieldLabel: GO.billing.lang.unitTotal,
			  value: GO.util.numberFormat("0"),
			  name:'unit_total'
			});
			
		this.descriptionField = new Ext.form.TextArea({
					anchor: '100%',
					height: 100,
				  allowBlank:true,
				  fieldLabel:GO.lang.strDescription,
			  	name:'description'
				});
				
				
		this.priceField.on('blur', this.calculateInclusivePrice,this);
	  this.vatField.on('blur', this.calculateInclusivePrice,this);
	  this.totalField.on('blur', this.calculateExclusivePrice,this);
	  this.discountField.on('blur', function(){
	  	var discount = parseFloat(GO.util.unlocalizeNumber(this.discountField.getValue()));
	  	if(discount==0)
	  	{
	  		return;
	  	}
	  	
	  	if(discount>0)
	  	{
	  		var number = parseFloat(GO.util.unlocalizeNumber(this.listField.getValue()));
	  	}else
	  	{
	  		var number = parseFloat(GO.util.unlocalizeNumber(this.costField.getValue()));
	  	} 	
	  	
	  	this.unformattedExclPrice = number*((100-discount)/100);  	
	  	
	  	this.priceField.setValue(GO.util.numberFormat(this.unformattedExclPrice ));
	  	this.calculateInclusivePrice();
	  }, this);
  
		
		this.formPanel = new Ext.form.FormPanel({
			url: GO.settings.modules.billing.url+'action.php',
			border: false,
			baseParams: {task: 'item'},			
			cls:'go-form-panel',			
			waitMsgTarget:true,
			layout:'form',
			autoHeight:true,
			items:[
			this.productField,
			this.amountField,
			this.vatField,
			this.priceField,
			this.listField,
			this.costField,
			this.discountField,
			this.totalField,
			this.descriptionField
			]				
		});
	
    
	}
});