/** 
 * Copyright Intermesh
 * 
 * This file is part of Group-Office. You should have received a copy of the
 * Group-Office license along with Group-Office. See the file /LICENSE.TXT
 * 
 * If you have questions write an e-mail to info@intermesh.nl
 * 
 * @copyright Copyright Intermesh
 * @version $Id: ItemsGrid.js 10708 2011-04-29 10:17:21Z mschering $
 * @author Merijn Schering <mschering@intermesh.nl>
 */

GO.billing.OrderItem = Ext.data.Record.create([
{
	name: 'id',
	type: 'string'
},
{
	name: 'amount',
	type: 'string'
},
{
	name: 'vat',
	type: 'string'
},
{
	name: 'unit_price'
},
{
	name: 'unit_list'
},
{
	name: 'unit_cost'
},
{
	name: 'discount',
	type: 'string'
},
{
	name: 'unit_total',
	type: 'string'
},
{
	name: 'description',
	type: 'string'
},
{
	name: 'cost_code',
	type: 'string'
}
]);


GO.billing.ItemsGrid = function(config){
	
	config = config || {};
	
	config.enableDragDrop=true;
	config.ddGroup='bsItemsDD';

	config.stateId='bs-items-grid';
	
	config.cls='bs-items-grid';
	config.layout='fit';
	config.autoScroll=true;
	config.split=true;
	config.store = new GO.data.JsonStore({
		url: GO.settings.modules.billing.url+ 'json.php',
		baseParams: {
			task: 'items',
			order_id: 0
	    	
		},
		root: 'results',
		id: 'id',
		totalProperty:'total',
		fields: ['id','order_id','product_id','description','unit_cost','unit_price','unit_list','unit_total','amount','vat','discount','sort_order','cost_code','markup','item_price','item_total'],
		remoteSort: true
	});
	
	config.store.on('load', this.updateTotals, this);



	config.paging=true;
	var columnModel =  new Ext.grid.ColumnModel({
		defaults:{
			sortable:false
		},
		columns:[
		{
			header: GO.billing.lang.amount, 
			dataIndex: 'amount',
			align:"center",
			width:50,
			renderer:this.numberRenderer,
			editor:this.amountField = new GO.form.NumberField({
				width:80,
				fieldLabel: GO.billing.lang.amount,
				value: GO.util.numberFormat("1"),
				name:'amount'
			})
		},{
			header: GO.lang.strDescription, 
			dataIndex: 'description',
			name:'description',
			width:250,
			editor:new Ext.grid.GridEditor(
				this.descriptionField = new Ext.form.TextArea({
					height:150,
					width:500,
					allowBlank:true,
					fieldLabel:GO.lang.strDescription
				}),{
					autoSize: false
				}),
			renderer:GO.util.nl2br,
			id:'description'
		},{
			header: GO.billing.lang.costCode,
			dataIndex: 'cost_code',
			align:"left",
			width:100,
			editor:this.costCodeBox = new GO.form.ComboBoxReset({
				store: GO.billing.costCodesStore,
				displayField:'code',
				valueField: 'code',
				mode:'local',
				triggerAction:'all',
				selectOnFocus:true,
				forceSelection: true
			}),
			scope : this
		},	{
			header: GO.billing.lang.unitCost, 
			dataIndex: 'unit_cost',
			align:"right",
			width:80,
			renderer:this.numberRenderer,
			editor: this.costField = new GO.form.NumberField({
				width:80,
				fieldLabel: GO.billing.lang.unitCost,
				value: GO.util.numberFormat("0"),
				name:'unit_cost'
			})
		},		{
			header: GO.billing.lang.unitPrice, 
			dataIndex: 'unit_price', 
			align:"right",
			width:80,
			renderer:this.numberRenderer,
			editor:this.priceField = new GO.form.NumberField({
				width:80,
				fieldLabel: GO.billing.lang.unitPrice,
				value: GO.util.numberFormat("0"),
				name:'unit_price'
			})
		},{
			header: GO.billing.lang.unitPriceIncVat,
			dataIndex: 'unit_total',
			align:"right",
			width:80,
			renderer:this.numberRenderer,
			editor:this.totalField = new GO.form.NumberField({
				width:80,
				fieldLabel: GO.billing.lang.unitPriceIncVat,
				value: GO.util.numberFormat("0"),
				name:'unit_total'
			}),
			hidden:true
		},{
			header: GO.billing.lang.unitList, 
			dataIndex: 'unit_list',
			align:"right",
			width:80,
			renderer:this.numberRenderer,
			editor:this.listField = new GO.form.NumberField({
				width:80,
				fieldLabel: GO.billing.lang.unitList,
				value: GO.util.numberFormat("0"),
				name:'unit_list'
			})
		},{
			header: GO.billing.lang.totalPrice,
			dataIndex: 'item_price',
			align:"right",
			width:100,
			renderer:this.numberRenderer
		},{
			header: GO.billing.lang.totalPriceIncVat,
			dataIndex: 'item_total',
			align:"right",
			width:100,
			renderer:this.numberRenderer,
			hidden:true
		},{
			header: GO.billing.lang.vat, 
			dataIndex: 'vat',
			align:"right",
			width:50,
			renderer:this.numberRenderer,
			editor: this.vatField = new GO.form.NumberField({
				fieldLabel: GO.billing.lang.vat,
				value: 19,
				name:'vat'
			})
		},		{
			header: GO.billing.lang.discount, 
			dataIndex: 'discount',
			align:"right",
			width:50,
			renderer:this.numberRenderer,
			editor:this.discountField = new GO.form.NumberField({
				width:80,
				fieldLabel: GO.billing.lang.discount,
				value: GO.util.numberFormat("0"),
				name:'discount'
			})
		},{
			header: GO.billing.lang.markup,
			dataIndex: 'markup',
			align:"right",
			width:80,
			renderer:this.numberRenderer,
			editor: this.markupField = new GO.form.NumberField({
				fieldLabel: GO.billing.lang.markup,
				value: 19,
				name:'markip'
			})
		}
		]
	});
	
	config.cm=columnModel;
	//config.autoExpandColumn='description';
	config.view=new Ext.grid.GridView({
		emptyText: GO.lang['strNoItems'],
	
		/*
		 * For scrolling with textarea's in editor grid
		 * (when using Ext.getBody() the only drawback is that the editors won't be destroyed when destroying the grid)
		 */
		getEditorParent: function(ed){
			//return Ext.getBody();
			return GO.billing.orderDialog.itemsPanel.el.dom;
		}
	});
	config.sm=new Ext.grid.RowSelectionModel();
	config.loadMask=true;
	config.clicksToEdit=1;	
	
	this.itemDialog = new GO.billing.ItemDialog();
	    			    		
	this.itemDialog.on('save', function(){
		this.store.reload();
	}, this);
	
	config.tbar=[{
		iconCls: 'btn-add',
		text: GO.lang['cmdAdd'],
		cls: 'x-btn-text-icon',
		handler: this.addBlankRow,
		scope: this
	},{
		iconCls: 'bs-btn-catalog',
		text: GO.billing.lang.catalog,
		cls: 'x-btn-text-icon',
		handler: function(){
			if(!this.selectProductDialog)
			{
				this.selectProductDialog = new GO.billing.SelectProductDialog();
				this.selectProductDialog.on('productselect', this.addProduct, this);
			}
			this.selectProductDialog.show();
		},
		scope: this
	},{
		iconCls: 'btn-add',
		text: GO.billing.lang.addPageBreak,
		cls: 'x-btn-text-icon',
		handler: this.addPageBreak,
		scope: this
	},'-',{
		iconCls: 'btn-delete',
		text: GO.lang['cmdDelete'],
		cls: 'x-btn-text-icon',
		handler: function(){
			this.changed=true;
			var selectedRows = this.selModel.getSelections();
			for(var i=0;i<selectedRows.length;i++)
			{
				selectedRows[i].commit();
				this.store.remove(selectedRows[i]);
			}
				
			this.updateTotals();
		},
		scope: this
	}/*,{
			iconCls: 'btn-delete',
			text: GO.lang['cmdDelete'],
			cls: 'x-btn-text-icon',
			handler: function(){
				alert(Ext.encode(this.getGridData()));				
			},
			scope: this
		}*/];

	
	
	GO.billing.ItemsGrid.superclass.constructor.call(this, config);
	
	/*this.on('rowdblclick', function(grid, rowIndex){
		var record = grid.getStore().getAt(rowIndex);	
		
		this.itemDialog.show(record.data.id);
		
		}, this);*/
		
		
	this.on('afteredit', this.afterEdit, this);
	this.on('beforeedit', this.beforeEdit, this);
	
	this.addEvents({
		'afternoedit' : true
	});
	
	this.on('afternoedit', this.afterNoEdit, this);
};

Ext.extend(GO.billing.ItemsGrid, Ext.grid.EditorGridPanel,{
	changed : false,

	defaultCostCode : '',
	
	afterRender : function(){
		
		GO.billing.ItemsGrid.superclass.afterRender.call(this);
		//enable row sorting
		var DDtarget = new Ext.dd.DropTarget(this.getView().mainBody, 
		{
			ddGroup : 'bsItemsDD',
			copy:false,
			notifyDrop : this.notifyDrop.createDelegate(this)
		});
	},
	
	addBlankRow : function(){
		//this.itemDialog.show();
		//this.itemDialog.formPanel.baseParams.order_id=this.store.baseParams.order_id;
  	
		var i = new GO.billing.OrderItem({
			id:0,
			amount: '1',
			vat: GO.billing.defaultVAT,
			unit_price: '0',
			unit_list: '0',
			unit_cost: '0',
			discount: '0',
			unit_total: '0',
			product_id: '0',
			description: '',
			cost_code: this.defaultCostCode
		});
		this.stopEditing();
		this.store.insert(this.store.getCount(), i);
		this.startEditing(this.store.getCount()-1, 0);

	},

	addPageBreak : function(){

		var i = new GO.billing.OrderItem({
			id:0,
			amount: '-',
			vat: '-',
			unit_price: '-',
			unit_list: '-',
			unit_cost: '-',
			discount: '-',
			unit_total: '-',
			product_id: '-',
			description: 'PAGEBREAK',
			cost_code: '-'
		});
		this.stopEditing();
		this.store.insert(this.store.getCount(), i);
		this.startEditing(this.store.getCount()-1, 0);

	},
	
	addProduct : function(record)
	{
		this.changed=true;
		var id = record.get('id');
		id = id.substr(2);


		Ext.Ajax.request({
			url: GO.settings.modules.billing.url+'json.php',
			params: {
				task: 'product',
				product_id: id
			},
			callback: function(options, success, response)
			{
				this.body.unmask();
				if(!success)
				{
					Ext.MessageBox.alert(GO.lang['strError'], GO.lang['strRequestError']);
				}else
				{
					var responseParams = Ext.decode(response.responseText);
					
					var r = responseParams.data;

					var language_id=GO.billing.orderDialog.formPanel.form.findField('language_id').getValue();

					var i = new GO.billing.OrderItem({
						id:0,
						amount: '1',
						vat: GO.util.unlocalizeNumber(r.vat),
						unit_price: r.list_price,
						unit_list: r.list_price,
						unit_cost: GO.util.unlocalizeNumber(r.cost_price),
						discount: '0',
						unit_total: r.total_price,
						product_id: id,
						description: r['name_'+language_id]+"\n"+r['description_'+language_id]
					});

					this.stopEditing();
					this.store.insert(this.store.getCount(), i);
					this.startEditing(this.store.getCount()-1, 0);

					this.updateTotals();

				}
			},
			scope: this
		});

		
		
		
	},
	getGridData : function(){
		
		var data = {};
		
		for (var i = 0; i < this.store.data.items.length;  i++)
		{
			var r = this.store.data.items[i].data;
			
			data[i]={};
			
			for(var key in r)
			{
				data[i][key]=r[key];
			}	
		}
		
		return data;		
	},
	overrideParams : {},
	
	/*
	 * Overide ext method because there's no way to capture afteredit when there's no change.
	 * We need this because we format /unformat numbers before and after edit.
	 */
	onEditComplete : function(ed, value, startValue){
  	
  	
  	
		GO.billing.ItemsGrid.superclass.onEditComplete.call(this, ed, value, startValue);
  	
		if(startValue != 'undefined' && String(value) === String(startValue)){
			var r = ed.record;
			var field = this.colModel.getDataIndex(ed.col);
			value = this.postEditValue(value, startValue, r, field);
		    
			var e = {
				grid: this,
				record: r,
				field: field,
				originalValue: startValue,
				value: value,
				row: ed.row,
				column: ed.col,
				cancel:false
			};
			this.fireEvent('afternoedit', e);
		}
  	
	},
	
	afterNoEdit : function (e)
	{
		e.record.set(e.field, this.currentOriginalValue);
		
		if(e.field=='discount' && e.row==this.store.getCount()-1)
		{
			this.addBlankRow.defer(100, this);
		}
	},
	
	afterEdit : function (e)
	{
		this.changed=true;
		
		if(e.field!='description' && e.field!='cost_code')
			e.record.set(e.field, GO.util.unlocalizeNumber(e.value));
		
		var r = e.record.data;	
				
		switch(e.field)
		{
			case 'markup':
				var unit_price = r.unit_cost*(1+(r.markup/100));
				e.record.set('unit_price', unit_price);
				var unit_total = r.unit_price*(1+(r.vat/100));
				e.record.set('unit_total', unit_total);
				var item_price = r.unit_price*(r.amount);
				e.record.set('item_price', item_price);
				var item_total = r.unit_total*(r.amount);
				e.record.set('item_total', item_total);
				break;

			case 'amount':
				var item_price = r.unit_price*(r.amount);
				e.record.set('item_price', item_price);
				var item_total = r.unit_total*(r.amount);
				e.record.set('item_total', item_total);
				break;
				
			case 'vat':
			case 'unit_price':
				var unit_total = r.unit_price*(1+(r.vat/100));
				e.record.set('unit_total', unit_total);
				var item_price = r.unit_price*(r.amount);
				e.record.set('item_price', item_price);
				var item_total = r.unit_total*(r.amount);
				e.record.set('item_total', item_total);
				break;
			
			case 'unit_total':
				var unit_price = r.unit_total/ (1+(r.vat/100));
				e.record.set('unit_price', unit_price);
				var item_price = r.unit_price*(r.amount);
				e.record.set('item_price', item_price);
				var item_total = r.unit_total*(r.amount);
				e.record.set('item_total', item_total);
				break;
			
			case 'discount':
			
				var number = parseFloat(r.unit_list);
				if(number==0)
				{
					e.record.set('unit_list', r.unit_price);
					number = parseFloat(r.unit_list);
				}

				e.record.set('unit_price', number*((100-r.discount)/100));
				var unit_total = r.unit_price*(1+(r.vat/100));
				e.record.set('unit_total', unit_total);
				var item_price = r.unit_price*(r.amount);
				e.record.set('item_price', item_price);
				var item_total = r.unit_total*(r.amount);
				e.record.set('item_total', item_total);
				break;
		}		
		
		this.updateTotals();
	},

	beforeEdit : function(e)
	{
		if(e.record.get('description')=='PAGEBREAK'){
			return false;
		}

		var colId = this.colModel.getColumnId(e.column);

		var col = this.colModel.getColumnById(colId);

		//console.log(col);

		this.currentOriginalValue=e.value;
		if(col && col.editor && col.editor.decimals)
		{
			e.record.set(e.field, GO.util.numberFormat(e.value));
		}
	},
	
	
	
	setIds : function(ids)
	{
		for(var index in ids)
		{
			if(index!="remove")
			{
				this.store.data.items[index].set('id', ids[index]);
			}
		}
	},
	
	notifyDrop : function(dd, e, data)
	{
		var sm=this.getSelectionModel();
		var rows=sm.getSelections();
		var dragData = dd.getDragData(e);
		var cindex=dragData.rowIndex;
		if(cindex=='undefined')
		{
			cindex=this.store.data.length-1;
		}	
		
		for(i = 0; i < rows.length; i++) 
		{								
			var rowData=this.store.getById(rows[i].id);
			
			if(!this.copy){
				this.store.remove(this.store.getById(rows[i].id));
			}
			
			this.store.insert(cindex,rowData);
		}
		
		//save sort order							
		var records = [];
		for (var i = 0; i < this.store.data.items.length;  i++)
		{
			records.push({
				id: this.store.data.items[i].get('id'),
				sort_order : i
			});
		}
  	
		this.changed=true;
	/*
		
		Ext.Ajax.request({
			url: GO.settings.modules.billing.url+'action.php',
			params: {
				task: 'save_items_sort_order',
				items: Ext.encode(records)
			}
		});*/					
		
	},
	
	numberRenderer : function(v, meta, record)
	{
		if(record.get('description')=='PAGEBREAK'){
			return '-';
		}
		//v = GO.util.unlocalizeNumber(v);
		return GO.util.numberFormat(v);
	},
	
	updateTotals : function(){
		
		var records = this.store.getRange();
		
		var costs = 0;
		var subtotal = 0;
		var total = 0;		
		var amount = 0;
		
		for(var i=0;i<records.length;i++)
		{
			amount = parseFloat(records[i].get("amount"));			
			total += amount*parseFloat(records[i].get("unit_total"));
			subtotal += amount*parseFloat(records[i].get("unit_price"));
			costs += amount*parseFloat(records[i].get("unit_cost"));
		}
		
		var profit = (subtotal-costs);
		var margin = 100-(100*costs/subtotal);
		var vat = total-subtotal;
		
		GO.billing.itemsCostsField.setValue(GO.util.numberFormat(costs.toString()));
		GO.billing.itemsProfitField.setValue(GO.util.numberFormat(profit.toString()));
		GO.billing.itemsMarginField.setValue(GO.util.numberFormat(margin.toString())+'%');
		GO.billing.itemsSubtotalField.setValue(GO.util.numberFormat(subtotal.toString()));
		GO.billing.itemsVatField.setValue(GO.util.numberFormat(vat.toString()));
		GO.billing.itemsTotalField.setValue(GO.util.numberFormat(total.toString()));
		
		
	}


});