/** 
 * Copyright Intermesh
 * 
 * This file is part of Group-Office. You should have received a copy of the
 * Group-Office license along with Group-Office. See the file /LICENSE.TXT
 * 
 * If you have questions write an e-mail to info@intermesh.nl
 * 
 * @copyright Copyright Intermesh
 * @version $Id: OrderDialog.js 10788 2011-05-13 13:25:46Z mschering $
 * @author Merijn Schering <mschering@intermesh.nl>
 */

 
GO.billing.OrderDialog = function(config){	
	if(!config)
	{
		config={};
	}

	//for adding listeners before contstruction
	config.goDialogId='order';
	
	this.buildForm();
	
	var focusFirstField = function(){
		this.propertiesPanel.items.items[0].focus();
	};
	
	config.tbar=[
	{
		iconCls: 'filetype-pdf',
		text: 'PDF',
		handler: function(){
			if(this.formPanel.form.findField('status_id').getValue()>0)
			{
				document.location=GO.settings.modules.billing.url+'pdf.php?order_id='+this.order_id;
			}else
			{
				if(!GO.billing.orderStatusWindow)
				{
					GO.billing.orderStatusWindow = new GO.billing.OrderStatusWindow();
				}
				GO.billing.orderStatusWindow.show(this.order_id);
			}
		},
		scope: this
	},{
		iconCls: 'bs-send-email',
		text: GO.lang.strEmail,
		cls: 'x-btn-text-icon',
		handler: function(){
			if(!GO.settings.modules.email)
			{
				Ext.Msg.alert(GO.lang['strError'], GO.billing.lang.noEmailModule);
			}else
			{
				GO.email.showComposer({
					loadUrl: GO.settings.modules.billing.url+'json.php',
					loadParams:{
						task:'sendmail',
						order_id: this.order_id
						},
					template_id: 0
				});
			}
				
		},
		scope:this
	},{
		iconCls: 'bs-duplicate',
		text: GO.billing.lang.duplicate,
		cls: 'x-btn-text-icon',
		handler: function(){
			GO.billing.duplicateDialog.show(this.order_id, this.formPanel.baseParams.book_id);
		},
		scope:this
	}
	];
	
	config.collapsible=true;
	config.maximizable=true;
	config.layout='fit';
	config.modal=false;
	config.animCollapse=false;
	config.resizable=true;
	config.width=800;
	config.height=600;
	config.closeAction='hide';
	config.title= GO.billing.lang.order;					
	config.items= this.formPanel;
	config.focus= focusFirstField.createDelegate(this);
	config.buttons=[{
		text: GO.lang['cmdOk'],
		handler: function(){
			this.submitForm(true);
		},
		scope: this
	},{
		text: GO.lang['cmdSave'],
		handler: function(){
			this.submitForm();
		},
		scope:this
	},{
		text: GO.lang['cmdClose'],
		handler: function(){
			this.hide();
		},
		scope:this
	}
	];
	
	GO.billing.OrderDialog.superclass.constructor.call(this, config);
	this.addEvents({
		'save' : true
	});
}
Ext.extend(GO.billing.OrderDialog, GO.Window,{
		
	show : function (order_id, config) {
		
		config = config || {};
		
		if(!this.rendered)
		{
			this.render(Ext.getBody());
		}

		if(!this.inititalized){

			this.getEl().mask(GO.lang.waitMsgLoad);
			Ext.Ajax.request({
				url: GO.settings.modules.billing.url+'json.php',
				params:{
					task:'init_order_window'
				},
				callback: function(options, success, response)
				{

					if(!success)
					{
						alert( GO.lang['strRequestError']);
					}else
					{
						var jsonData = Ext.decode(response.responseText);

						if(GO.billing.webshopsStore && !GO.billing.webshopsStore.loaded)
						{
							GO.billing.webshopsStore.loadData(jsonData.webshops);
						}

						this.selectBook.store.loadData(jsonData.writable_books);

						if(!GO.billing.languagesStore.loaded)
						{
							GO.billing.languagesStore.loadData(jsonData.languages);
						}

						
						this.getEl().unmask();

						this.inititalized=true;
						this.show(order_id, config);

					}
				},
				scope:this
			});
			return false;
		}
		
		delete this.link_config;
		this.formPanel.form.reset();
		
		
		if(config.values)
		{
			this.formPanel.form.setValues(config.values);	
		}
		
		
		this.tabPanel.setActiveTab(0);
		
		if(!order_id)
		{
			order_id=0;			
		}
			
		this.setOrderId(order_id);
		
		this.formPanel.baseParams.contact_id=0;
		this.formPanel.baseParams.company_id=0;
		
		if(this.order_id>0)
		{
			this.formPanel.load({
				url : GO.settings.modules.billing.url+'json.php',				
				success:function(form, action)
				{					
					this.statusPanel.setBookId(action.result.data.book_id);	
					//this.formPanel.baseParams.book_id=action.result.data.book_id;
					this.selectUser.setRemoteText(action.result.data.user_name);			
					
					this.formPanel.baseParams.contact_id=action.result.data.contact_id;					
					this.formPanel.baseParams.company_id=action.result.data.company_id;

					this.setTitleFromBook(action.result.data.order_id);
					
					GO.billing.OrderDialog.superclass.show.call(this);
				},
				failure:function(form, action)
				{
					Ext.Msg.alert(GO.lang['strError'], action.result.feedback)
				},
				scope: this
				
			});
		}else 
		{
			var book_id=this.selectBook.getValue();
			this.selectBook.setValue(book_id);
			this.selectCountry.setValue(GO.billing.defaultCountry);
			
			this.statusPanel.setBookId(book_id);

			this.setTitleFromBook();
			this.costCodeCombo.selectFirst();
			
			GO.billing.OrderDialog.superclass.show.call(this);			
		}
		
		this.selectBook.container.up('div.x-form-item').setDisplayed(this.order_id==0 && this.selectBook.getValue()==0);
		
		//if the newMenuButton from another passed a linkTypeId then set this value in the select link field
		if(config && config.link_config)
		{
			this.link_config=config.link_config;
			if(config.link_config.type_id)
			{
				this.selectLinkField.setValue(config.link_config.type_id);
				this.selectLinkField.setRemoteText(config.link_config.text);
				
				var params=false;
				//console.log(config);
				if(config.link_config.type==2)
				{
					params={
						task:"load_contact",
						contact_id:config.link_config.id
					};

					this.formPanel.baseParams.contact_id=config.link_config.id;

				}
				if(config.link_config.type==3)
				{
					params={
						task:"load_company",
						company_id:config.link_config.id
					};
					this.formPanel.baseParams.company_id=config.link_config.id;
				}
				
				if(params)
				{				
					this.formPanel.load({
						url : GO.settings.modules.billing.url+'json.php',			
						params: params,
						failure:function(form, action)
						{
							Ext.Msg.alert(GO.lang['strError'], action.result.feedback)
						},
						scope: this						
					});
				}
			}
		}
	},
	
	setOrderId : function(order_id, items_loaded)
	{
		this.getTopToolbar().setDisabled(order_id==0);
		this.formPanel.form.baseParams['order_id']=order_id;
		this.order_id=order_id;
		this.itemsPanel.setOrderId(order_id, items_loaded);
		this.statusPanel.setOrderId(order_id);	
		
		this.selectLinkField.container.up('div.x-form-item').setDisplayed(order_id==0);		
	},
	
	submitForm : function(hide, params){
		
		params = params || {
			'task' : 'save_order'				
		};

//		if(!params.dialog && (this.formPanel.baseParams.company_id == 0 || (this.formPanel.baseParams.contact_id == 0 && !GO.util.empty(this.selectContact.getValue()))))
//		{
//			params['add_company']=0;
//			this.addContactDialog = new GO.billing.AddContactDialog();
//			this.addContactDialog.show();
//
//			params['ab'] = '';
//
//			this.addContactDialog.on('hide', function(){
//				params['dialog']=true;
//				if(this.addContactDialog.addToAddressbook)
//				{
//					params['ab'] = this.addContactDialog.selectAddressbook.getRawValue();
//					params['add_company']=1;
//				}
//				this.submitForm(hide, params);
//			}, this);
//		}
//		else
//		{
		
			if(this.itemsPanel.itemsGrid.changed)
			{
				params['items']=Ext.encode(this.itemsPanel.itemsGrid.getGridData());
			}

			this.formPanel.form.submit(
			{
				url:GO.settings.modules.billing.url+'action.php',
				params: params,
				waitMsg:GO.lang['waitMsgSave'],
				success:function(form, action){

					if(action.result.order_id)
					{
						this.setOrderId(action.result.order_id, this.itemsPanel.itemsGrid.changed);
					}

					if(action.result.contact_id)
					{
						this.formPanel.baseParams.contact_id = action.result.contact_id;
					}

					if(action.result.company_id)
					{
						this.formPanel.baseParams.company_id = action.result.company_id;
					}

					if(action.result.text_order_id)
					{
						this.setTitleFromBook(action.result.text_order_id);
					}

					if(hide)
					{
						this.hide();
					}else
					{
						if(action.result.new_items)
						{
							this.itemsPanel.itemsGrid.setIds(action.result.new_items);
						}

						this.itemsPanel.itemsGrid.store.commitChanges();

						if(action.result.status_history_changed)
						{
							if(action.result.ptime)
							{
								this.formPanel.form.findField('ptime').setValue(action.result.ptime);
							}

							//if(this.statusPanel.statusGrid.store.loaded)
							//{
							this.statusPanel.statusGrid.store.load();
						//}
						}
					}

					this.fireEvent('save', this, this.order_id);

					if(this.link_config && this.link_config.callback)
					{
						this.link_config.callback.call(this);
					}
				},
				failure: function(form, action) {
					if(action.failureType == 'client')
					{
						Ext.MessageBox.alert(GO.lang['strError'], GO.lang['strErrorsInForm']);
					} else {
						Ext.MessageBox.alert(GO.lang['strError'], action.result.feedback);

						if(action.result.order_id)
						{
							this.setOrderId(action.result.order_id, this.itemsPanel.itemsGrid.changed);
						}

						if(action.result.new_items)
						{
							this.itemsPanel.itemsGrid.setIds(action.result.new_items);
						}
						this.itemsPanel.itemsGrid.store.commitChanges();

					}
				},
				scope: this
			});
		//}
	},

	setTitleFromBook : function(order_id){
		var bookRecord = this.selectBook.store.getById(this.selectBook.getValue());

		if(GO.util.empty(order_id)){
			order_id=GO.lang.cmdNew;
		}

		if(bookRecord)
			this.setTitle(bookRecord.get('name')+' - '+order_id);
		else
			this.setTitle(GO.billing.lang.selectBook);
	},

	applyCompanyRecord : function(record){
		var values = {
			customer_name : record.data.name,
			customer_address: record.data.post_address,
			customer_address_no: record.data.post_address_no,
			customer_zip: record.data.post_zip,
			customer_city: record.data.post_city,
			customer_state: record.data.post_state,
			customer_country: record.data.post_country,
			customer_email: record.data.email,
			customer_vat_no: record.data.vat_no
		};

		if(GO.customfields){
			var map = GO.customfields.getMatchingFieldNamesMap(3, 7);

			for(var contact_col in map){
				values[map[contact_col]]=record.data[contact_col];
			}
		}
		var cmp;
		for(var field in values){
			cmp=this.formPanel.form.findField(field);
			if(cmp && (cmp.getValue()=='' || cmp.getName()=='customer_country'))
				cmp.setValue(values[field]);
		}
		
		//this.formPanel.form.setValues(values);
		this.formPanel.baseParams.company_id=record.data.id;
	},
	
	buildForm : function () {
		
		var now = new Date();
		
		this.selectLinkField = new GO.form.SelectLink({
			anchor:'-20'
		});
		
		this.selectCompany = new GO.addressbook.SelectCompany ({
			name: 'customer_name',
			anchor: '-20',
			allowBlank:false,
			fieldLabel: GO.billing.lang.customer
		});

		this.selectCompany.on('focus',function(){
			this.oldCompany=this.selectCompany.getRawValue();
			this.oldContact=this.selectContact.getRawValue();
		}, this);
			
		this.selectCompany.on('select', function(combo, record){
			this.applyCompanyRecord(record);
		}, this);

		this.selectCompany.on('change', function(){
				if((this.txtCustomerTo.getValue()==this.buildCustomerTo(this.oldCompany, this.oldContact) || (this.txtCustomerTo.getValue()== '')))
				this.txtCustomerTo.setValue(this.buildCustomerTo(this.selectCompany.getRawValue(),this.selectContact.getRawValue()));
		},this);

		this.txtCustomerTo = new Ext.form.TextArea({
			name: 'customer_to',
			anchor: '-20',
			height: 36,
			fieldLabel: GO.billing.lang.customerTo
		});


		
		this.selectContact = new GO.addressbook.SelectContact ({
			name: 'customer_contact_name',
			anchor: '-20',
			getCompanyInfo:true,
			fieldLabel: GO.billing.lang.customerContact
		});

		this.selectContact.on('focus',function(){
			this.oldContact=this.selectContact.getRawValue();
			this.oldCompany=this.selectCompany.getRawValue();
		}, this);

		this.selectContact.on('change', function(){
			if((this.txtCustomerTo.getValue()==this.buildCustomerTo(this.oldCompany, this.oldContact) || (this.txtCustomerTo.getValue()== '')))
				this.txtCustomerTo.setValue(this.buildCustomerTo(this.selectCompany.getRawValue(),this.selectContact.getRawValue()));
		},this);

		this.selectContact.on('select', function(combo, record){
			this.formPanel.form.setValues({
				customer_salutation: record.data.salutation,
				customer_email: record.data.email
			});

			if(this.selectCompany.getValue()<1 && record.data.company_id>0){
				this.getEl().mask(GO.lang.waitMsgLoad);
				Ext.Ajax.request({
					url:GO.settings.modules.addressbook.url+'json.php',
					params:{
						task:'load_company',
						company_id:record.data.company_id
					},
					callback: function(options, success, response)
					{
						this.getEl().unmask();
						
						var record = Ext.decode(response.responseText);
						this.applyCompanyRecord(record);

						
					},
					scope:this
				});
			}
			else if(this.selectCompany.getValue()<1)
			{

				var values = {
					customer_name: record.data.name,
					customer_contact_name: record.data.name,
					customer_address: record.data.address,
					customer_address_no: record.data.address_no,
					customer_zip: record.data.zip,
					customer_city: record.data.city,
					customer_state: record.data.state,
					customer_country: record.data.country,
					customer_email: record.data.email
				};
				
				if(GO.customfields){
					var map = GO.customfields.getMatchingFieldNamesMap(2, 7);

					for(var contact_col in map){
						values[map[contact_col]]=record.data[contact_col];
					}
				}
				this.formPanel.form.setValues(values);
			}
			this.formPanel.baseParams.contact_id=record.data.id;
		}, this);

		this.selectUser = new GO.form.SelectUser({
			fieldLabel: GO.lang['strUser'],
			disabled: !GO.settings.modules['billing']['write_permission'],
			value: GO.settings.user_id,
			anchor: '-20'
		});

		this.selectUser.on('select', function(combo, record){

			if(this.selectCompany.getValue()==''){
				var values = {
					customer_name: record.data.company,
					customer_contact_name: record.data.name,
					customer_address: record.data.address,
					customer_address_no: record.data.address_no,
					customer_zip: record.data.zip,
					customer_city: record.data.city,
					customer_state: record.data.state,
					customer_country: record.data.country,
					customer_email: record.data.email
				};

				this.formPanel.form.setValues(values);
			}
		}, this);
		

		var leftPanelItems = [
		this.selectLinkField,
		this.selectUser,
		this.selectBook = new GO.form.ComboBox({
			fieldLabel: GO.billing.lang.bookId,
			hiddenName:'book_id',
			anchor:'-20',
			emptyText:GO.lang.strPleaseSelect,
			store: new GO.data.JsonStore({
				url: GO.settings.modules.billing.url+ 'json.php',
				baseParams: {
					task: 'books',
					auth_type: 'write'
				},
				root: 'results',
				id: 'id',
				totalProperty:'total',
				fields: ['id','name', 'user_name', 'report_checked'],
				remoteSort: true
			}),
			pageSize: parseInt(GO.settings.max_rows_list),
			valueField:'id',
			displayField:'name',
			mode: 'local',
			triggerAction: 'all',
			editable: true,
			selectOnFocus:true,
			forceSelection: true,
			allowBlank: false,
			listeners:{
				change: function(combo, newval, oldval){
					this.statusPanel.setBookId(newval);

					this.setTitleFromBook();
				},
				scope:this
			}
		}),
		{
			xtype: 'textfield',
			name: 'po_id',
			anchor: '-20',
			allowBlank:true,
			fieldLabel: GO.billing.lang.poId
		},new Ext.form.DateField({
			name: 'btime',
			anchor: '-20',
			allowBlank:false,
			format: GO.settings.date_format,
			value: now.format(GO.settings.date_format),
			fieldLabel: GO.billing.lang.btime
		}),new Ext.form.DateField({
			name: 'ptime',
			anchor: '-20',
			format: GO.settings.date_format,
			fieldLabel: GO.billing.lang.ptime
		}),{
			xtype: 'textfield',
			name: 'reference',
			anchor: '-20',
			allowBlank:true,
			fieldLabel: GO.billing.lang.reference
		},
		new Ext.form.ComboBox({
			hiddenName: 'language_id',
			fieldLabel: GO.billing.lang.languageId,
			store: GO.billing.languagesStore,
			value:'1',
			valueField:'id',
			displayField:'name',
			mode: 'local',
			triggerAction: 'all',
			editable: false,
			selectOnFocus:true,
			forceSelection: true,
			anchor: '-20'
		}),{
			xtype:'compositefield',
			fieldLabel: GO.billing.lang.recurType,
			anchor: '-20',
			items:[{
					xtype:'numberfield',
					value:1,
					decimals:0,
					name:'recur_number',
					flex:1
			},
			new Ext.form.ComboBox({
				hiddenName: 'recur_type',
				store: new Ext.data.SimpleStore({
					fields: ['code', 'text'],
					data : [
					['', GO.lang.none],
					['W', GO.lang.strWeeks],
					['M', GO.lang.strMonths],
					['Y', GO.lang.strYears]
					]
				}),
				value:'',
				valueField:'code',
				displayField:'text',
				mode: 'local',
				triggerAction: 'all',
				editable: false,
				selectOnFocus:true,
				forceSelection: true,
				flex:4
				
			})]
		},
		this.costCodeCombo = new GO.form.ComboBoxReset({
				name : 'cost_code',
				fieldLabel: GO.billing.lang.costCode,
				store: GO.billing.costCodesStore ,
				displayField:'code',
				valueField: 'code',
				mode:'local',
				triggerAction:'all',
				selectOnFocus:true,
				forceSelection: true,
				anchor:'-20',
				value:'',
				listeners:{
					change:function(cb, newValue, oldValue){						
						this.itemsPanel.itemsGrid.defaultCostCode=newValue;
					},
					scope:this
				}
		})];

		GO.billing.costCodesStore.on('load', function(){
			this.costCodeCombo.selectFirst();
			this.itemsPanel.itemsGrid.defaultCostCode=this.costCodeCombo.getValue();
		}, this);
		
		this.selectBook.on('change', function(){		
			GO.billing.orderStatusesStore.baseParams.book_id=this.selectBook.getValue();
			GO.billing.orderStatusesStore.load();			
		}, this);
		
		if(GO.webshop)
		{
			leftPanelItems.push(new GO.form.ComboBox({
				hiddenName: 'webshop_id',
				fieldLabel: GO.webshop.lang.webshop,
				store: GO.billing.webshopsStore,
				value:'',
				valueField:'id',
				displayField:'name',
				mode: 'local',
				triggerAction: 'all',
				emptyText: 'No webshop',
				editable: false,
				selectOnFocus:true,
				forceSelection: false,
				anchor: '-20'
			}));
		}

		this.propertiesPanel = new Ext.Panel({
			url: GO.settings.modules.billing.url+'action.php',
			border: false,
			baseParams: {
				task: 'order'
			},
			title:GO.lang['strProperties'],						
			layout:'column',
			autoScroll:true,
			items:[{
				border:false,
				cls:'go-form-panel',
				layout:'form',
				columnWidth:.5,
				items:leftPanelItems
			},{
				cls:'go-form-panel',
				layout:'form',
				columnWidth:.5,
				border:false,
				items:[
				this.selectContact,
				this.selectCompany,
				this.txtCustomerTo,
				{
					xtype: 'textfield',
					name: 'customer_salutation',
					anchor: '-20',
					allowBlank:true,
					fieldLabel: GO.lang.strSalutation,
					value: GO.billing.lang.defaultSalutation
				},{
					xtype: 'textfield',
					name: 'customer_address',
					anchor: '-20',
					allowBlank:true,
					fieldLabel: GO.lang.strAddress
				},{
					xtype: 'textfield',
					name: 'customer_address_no',
					anchor: '-20',
					allowBlank:true,
					fieldLabel: GO.lang.strNo
				},{
					xtype: 'textfield',
					name: 'customer_zip',
					anchor: '-20',
					allowBlank:true,
					fieldLabel: GO.lang.strZip
				},{
					xtype: 'textfield',
					name: 'customer_city',
					anchor: '-20',
					allowBlank:true,
					fieldLabel: GO.lang.strCity
				},{
					xtype: 'textfield',
					name: 'customer_state',
					anchor: '-20',
					fieldLabel: GO.lang.strState
				},this.selectCountry = new GO.form.SelectCountry({
					name: 'customer_country_name',
					anchor: '-20',
					allowBlank:false,
					fieldLabel: GO.lang.strCountry,
					hiddenName: 'customer_country'
				}),{
					xtype: 'textfield',
					name: 'customer_vat_no',
					anchor: '-20',
					allowBlank:true,
					fieldLabel: GO.billing.lang.customerVatNo
				},{
					xtype: 'textfield',
					name: 'customer_email',
					anchor: '-20',
					allowBlank:true,
					fieldLabel: GO.lang.strEmail
				},{
					xtype: 'textarea',
					name: 'customer_extra',
					anchor: '-20',
					height:80,
					fieldLabel: GO.billing.lang.customerExtra
				}]
			}]				
		});
		
		this.frontPagePanel = new Ext.Panel({
			title: GO.billing.lang.frontpage,
			layout:'form',
			cls:'go-form-panel',
			hideMode:'offsets',
			items:[{
				xtype:'checkbox',
				name:'pagebreak',
				boxLabel: GO.billing.lang.pagebreak,
				hideLabel:true
			},{
				xtype: 'htmleditor',
				name: 'frontpage_text',
				anchor: '100% -22',
				value:'<br />',
				enableFont:false,
				allowBlank:true,
				hideLabel: true
			}]			
		});
		
		this.itemsPanel = new GO.billing.ItemsPanel();
		this.statusPanel = new GO.billing.StatusPanel();
		
		var items  = [
		this.propertiesPanel,
		this.frontPagePanel,
		this.itemsPanel,
		this.statusPanel		
		];

		if(GO.customfields && GO.customfields.types["7"])
		{
			for(var i=0;i<GO.customfields.types["7"].panels.length;i++)
			{			  	
				items.push(GO.customfields.types["7"].panels[i]);
			}
		}		
 
		this.tabPanel = new Ext.TabPanel({
			activeTab: 0,
			deferredRender: false,
			border: false,
			items: items,
			anchor: '100% 100%'
		});
    
		this.formPanel = new Ext.form.FormPanel({
			url: GO.settings.modules.billing.url+'action.php',
			waitMsgTarget:true,
			border: false,
			baseParams: {
				task: 'order'
			},
			items:this.tabPanel	
		});    
	},
	buildCustomerTo : function (company, contact){
		var str='';
		
		if(company == contact)
			company = '';


		if(company!=''){
			str = company;
		}
		if(contact!=''){

			if(company!='')
				str += '\n'+GO.billing.lang.tav + ' ';
			
			str +=  contact;
		}

		return str;

	}
});