/** 
 * Copyright Intermesh
 * 
 * This file is part of Group-Office. You should have received a copy of the
 * Group-Office license along with Group-Office. See the file /LICENSE.TXT
 * 
 * If you have questions write an e-mail to info@intermesh.nl
 * 
 * @copyright Copyright Intermesh
 * @version $Id: ProductDialog.js 7407 2010-03-26 08:09:53Z mschering $
 * @author Merijn Schering <mschering@intermesh.nl>
 */

 
GO.billing.ProductDialog = function(config){
	
	
	if(!config)
	{
		config={};
	}
	
	
	this.buildForm();
	
	var focusFirstField = function(){
		this.propertiesPanel.items.items[0].focus();
	};
	
	if(GO.webshop && GO.email)
	{
		config.tbar=[{
			text: GO.billing.lang.emailBuyers,
			iconCls: 'btn-message',
			handler: function(){
				Ext.Ajax.request({
					url: GO.settings.modules.billing.url+'json.php',
					params: {task:'email_buyers', product_id: this.product_id},
					callback: function(options, success, response)
					{
						var result = Ext.decode(response.responseText);
						
						GO.email.showComposer({
								values : {to: GO.settings.email, bcc: result.addresses}							
							});
							
					},
					scope: this			
				});
			
			},
			scope: this	
		}];
	}
	
	config.maximizable=true;
	config.layout='fit';
	config.modal=false;
	config.resizable=false;
	config.width=700;
	config.height=500;
	config.closeAction='hide';
	config.title= GO.billing.lang.product;					
	config.items= this.formPanel;
	config.focus= focusFirstField.createDelegate(this);
	config.buttons=[{
			text: GO.lang['cmdOk'],
			handler: function(){
				this.submitForm(true);
			},
			disabled: !GO.settings.modules.billing.write_permission,
			scope: this
		},{
			text: GO.lang['cmdApply'],
			handler: function(){
				this.submitForm();
			},
			disabled: !GO.settings.modules.billing.write_permission,
			scope:this
		},{
			text: GO.lang['cmdClose'],
			handler: function(){
				this.hide();
			},
			scope:this
		}					
	];
	
	GO.billing.ProductDialog.superclass.constructor.call(this, config);
	this.addEvents({'save' : true});	
}
Ext.extend(GO.billing.ProductDialog, GO.Window,{
	
	show : function (product_id) {
		if(!this.rendered)
		{
			this.render(Ext.getBody());
		}

		if(!product_id)
		{
			product_id=0;			
		}
			
		this.setProductId(product_id);
		
		if(this.product_id>0)
		{
			this.formPanel.load({
				url : GO.settings.modules.billing.url+'json.php',
				
				success:function(form, action)
				{
					this.formPanel.baseParams.category_id=action.result.data.category_id;
					
					this.selectCompany.setRemoteText(action.result.data.supplier);
					
					this.productImage.setSrc(action.result.data.image);
					this.deleteImageCB.setDisabled(action.result.data.image=='');
				
					this.unformattedExclPrice=action.result.data.list_price;
					this.unformattedInclPrice=action.result.data.total_price;
					
					this.unformattedSpecialExclPrice=action.result.data.special_list_price;
					this.unformattedSpecialInclPrice=action.result.data.special_total_price;
					
					GO.billing.ProductDialog.superclass.show.call(this);
				},
				failure:function(form, action)
				{
					Ext.Msg.alert(GO.lang['strError'], action.result.feedback)
				},
				scope: this
				
			});
		}else 
		{
			
			this.formPanel.form.reset();
			this.vatField.setValue(GO.util.numberFormat(GO.billing.defaultVAT));
			GO.billing.ProductDialog.superclass.show.call(this);
		}
	},
	
	
	setProductId : function(product_id)
	{
		this.formPanel.form.baseParams['product_id']=product_id;
		this.product_id=product_id;
		
	},
	
	submitForm : function(hide){
		this.formPanel.form.submit(
		{
			url:GO.settings.modules.billing.url+'action.php',
			params: {
				'task' : 'save_product',
				'list_price' : this.unformattedExclPrice,
				'total_price' : this.unformattedInclPrice,
				'special_list_price' : this.unformattedSpecialExclPrice,
				'special_total_price' : this.unformattedSpecialInclPrice
			},
			waitMsg:GO.lang['waitMsgSave'],
			success:function(form, action){
				
				this.fireEvent('save', this);
				this.uploadFile.clearQueue();
				if(hide)
				{
					this.hide();	
				}else
				{				
					if(action.result.product_id)
					{
						this.setProductId(action.result.product_id);
					}
					
					if(action.result.image != undefined)
					{
						this.productImage.setSrc(Ext.util.Format.htmlDecode(action.result.image));
						
						this.deleteImageCB.setValue(false);
						this.deleteImageCB.setDisabled(action.result.image=='');
					}
				}	
			},		
			failure: function(form, action) {
				if(action.failureType == 'client')
				{					
					Ext.MessageBox.alert(GO.lang['strError'], GO.lang['strErrorsInForm']);			
				} else {
					Ext.MessageBox.alert(GO.lang['strError'], action.result.feedback);
				}
			},
			scope: this
		});
		
	},
	
	
	buildForm : function () {
		
		
		var items = [];
		
		var records = GO.billing.languagesStore.getRange();
		
		for(var i=0;i<records.length;i++)
		{
			var textfield = new Ext.form.TextField({
				fieldLabel:GO.lang.strName+' ('+records[i].get("name")+')',
				name:"name_"+records[i].get("id"),
				anchor:'-20',
				allowBlank: false
			});
			
			items.push(textfield);	
			
			var descriptionField = new Ext.form.TextArea({
				fieldLabel:GO.lang.strDescription+' ('+records[i].get("name")+')',
				name:"description_"+records[i].get("id"),
				anchor:'-20'
			});
			
			items.push(descriptionField);	
			
			var shortDescriptionField = new Ext.form.TextArea({
				fieldLabel:GO.billing.lang.shortDescription+' ('+records[i].get("name")+')',
				name:"short_description_"+records[i].get("id"),
				anchor:'-20'
			});
			
			items.push(shortDescriptionField);	
		}
		
		items.push(this.selectCompany = new GO.addressbook.SelectCompany ({
			  hiddenName: 'supplier_company_id',
				anchor: '-20',
			  fieldLabel: GO.billing.lang.supplier
			}));
		items.push({
				xtype: 'textfield',
			  name: 'supplier_product_id',
				anchor: '-20',			  
			  fieldLabel: GO.billing.lang.supplierProductId
			});

		
	
		
		
		this.propertiesPanel = new Ext.Panel({
			columnWidth: .65,
			border: false,		
			cls:'go-form-panel',			
			layout:'form',			
			labelWidth:120,
			items:items				
		}); 
		
		GO.billing.ProductImage = Ext.extend(Ext.BoxComponent, {
		     onRender : function(ct, position){
		          this.el = ct.createChild({tag: 'img'});
		          this.setVisible(false);
		     },
		     setSrc : function(src)
		     {
		     	this.el.set({src: src});
		     	this.setVisible(true);
		     }
		});
		
		
		this.productImage = new GO.billing.ProductImage();
		
		this.deleteImageCB = new Ext.form.Checkbox({
				boxLabel: GO.billing.lang.deleteImage,
				labelSeparator: '',
				name: 'delete_image',		
				allowBlank: true,
				hideLabel:true,
				disabled:true
			});
		
		this.pricePanel = new Ext.Panel({
			columnWidth: .35,
			border: false,		
			cls:'go-form-panel',			
			layout:'form',			
			labelWidth:120,
			items:[{
				xtype: 'numberfield',
			  name: 'cost_price',
				anchor: '-20',
			  fieldLabel: GO.billing.lang.costPrice,
			  value: GO.util.numberFormat("0")
			},this.listPriceField = new GO.form.NumberField({
			  name: 'formatted_list_price',
				anchor: '-20',
			  fieldLabel: GO.billing.lang.listPrice,
			  value: GO.util.numberFormat("0")
			}),this.vatField = new GO.form.NumberField({
			  name: 'vat',
				anchor: '-20',
			  fieldLabel: GO.billing.lang.vat,
			  value: GO.util.numberFormat("19")
			}),this.totalPriceField = new GO.form.NumberField({
			  name: 'formatted_total_price',
				anchor: '-20',
			  fieldLabel: GO.billing.lang.totalPrice
			}),this.specialCB = new Ext.form.Checkbox({
				xtype: 'checkbox',
			  name: 'special',
			  hideLabel: true,
			  boxLabel: GO.billing.lang.special
			}),this.specialListPriceField = new GO.form.NumberField({
				xtype: 'numberfield',
			  name: 'formatted_special_list_price',
				anchor: '-20',
			  fieldLabel: GO.billing.lang.specialListPrice,
			  disabled:true,
			  value: GO.util.numberFormat("0")
			}),this.specialTotalPriceField = new GO.form.NumberField({
				xtype: 'numberfield',
			  name: 'formatted_special_total_price',
				anchor: '-20',
			  fieldLabel: GO.billing.lang.specialTotalPrice,
			  disabled:true,
			  value: GO.util.numberFormat("0")
			}),{
				xtype: 'checkbox',
			  name: 'charge_shipping_costs',
				anchor: '-20',
			  hideLabel: true,
			  boxLabel: GO.billing.lang.chargeShippingCosts
			},{
				xtype: 'checkbox',
			  name: 'allow_bonus_points',			  
			  hideLabel: true,
			  boxLabel: GO.billing.lang.allowBonusPoints
			},{
				xtype: 'numberfield',
			  name: 'stock',
			  decimals:0,
				anchor: '-20',
			  fieldLabel: GO.billing.lang.stock
			},{
				xtype: 'numberfield',
			  name: 'bonus_points',
			  decimals:0,
				anchor: '-20',
			  fieldLabel: GO.billing.lang.bonusPoints
			},
			this.uploadFile = new GO.form.UploadFile({
					inputName : 'image',
					max: 1
			}),
			this.productImage,
			this.deleteImageCB]				
		}); 
		
		this.specialCB.on('check', function(cb, checked){
			this.specialListPriceField.setDisabled(!checked);
			this.specialTotalPriceField.setDisabled(!checked);
		}, this);
		
		
		this.listPriceField.on('change', this.calculateInclusivePrice,this);
  	this.vatField.on('change', this.calculateInclusivePrice,this);
  	this.totalPriceField.on('change', this.calculateExclusivePrice,this);
  	
  	this.specialListPriceField.on('change', this.calculateSpecialInclusivePrice,this);
  	this.specialTotalPriceField.on('change', this.calculateSpecialExclusivePrice,this);

    
    this.formPanel = new Ext.form.FormPanel({
    	waitMsgTarget:true,
			url: GO.settings.modules.billing.url+'action.php',
			border: false,
			fileUpload: true,
			baseParams: {task: 'product', category_id: 0 },	
			layout:'column',
			autoScroll:true,
			items:[this.propertiesPanel, this.pricePanel]			
		});
    
    
	},
	calculateInclusivePrice : function(){  	
  	this.unformattedExclPrice = GO.util.unlocalizeNumber(this.listPriceField.getValue());
  	var vat = GO.util.unlocalizeNumber(this.vatField.getValue());  	
  	this.unformattedInclPrice = this.unformattedExclPrice*(1+(vat/100));  	
  	this.totalPriceField.setValue(GO.util.numberFormat(this.unformattedInclPrice));
  },
  
  calculateExclusivePrice : function(){  	
  	this.unformattedInclPrice = GO.util.unlocalizeNumber(this.totalPriceField.getValue());
  	var vat = GO.util.unlocalizeNumber(this.vatField.getValue());  	
  	this.unformattedExclPrice = this.unformattedInclPrice / (1+(vat/100));  	
  	this.listPriceField.setValue(GO.util.numberFormat(this.unformattedExclPrice ));
  },
  
	calculateSpecialInclusivePrice : function(){  	
  	this.unformattedSpecialExclPrice = GO.util.unlocalizeNumber(this.specialListPriceField.getValue());
  	var vat = GO.util.unlocalizeNumber(this.vatField.getValue());  	
  	this.unformattedSpecialInclPrice = this.unformattedSpecialExclPrice*(1+(vat/100));  	
  	this.specialTotalPriceField.setValue(GO.util.numberFormat(this.unformattedSpecialInclPrice));
  },
  
  calculateSpecialExclusivePrice : function(){  	
  	this.unformattedSpecialInclPrice = GO.util.unlocalizeNumber(this.specialTotalPriceField.getValue());
  	var vat = GO.util.unlocalizeNumber(this.vatField.getValue());  	
  	this.unformattedSpecialExclPrice = this.unformattedSpecialInclPrice / (1+(vat/100));  	
  	this.specialListPriceField.setValue(GO.util.numberFormat(this.unformattedSpecialExclPrice ));
  }
});