/** 
 * Copyright Intermesh
 * 
 * This file is part of Group-Office. You should have received a copy of the
 * Group-Office license along with Group-Office. See the file /LICENSE.TXT
 * 
 * If you have questions write an e-mail to info@intermesh.nl
 * 
 * @version $Id: ProductsGrid.js 6866 2010-01-27 12:52:35Z mschering $
 * @copyright Copyright Intermesh
 * @author Merijn Schering <mschering@intermesh.nl>
 */
 
 
GO.billing.ProductsGrid = function(config){
	
	if(!config)
	{
		config = {};
	}
	
	config.layout='fit';
	config.autoScroll=true;
	config.split=true;
	config.store = new GO.data.JsonStore({
	    url: GO.settings.modules.billing.url+ 'json.php',
	    baseParams: {
	    	task: 'products_grid',
	    	category_id:"0"
	    	},
	    root: 'results',
	    id: 'id',
	    totalProperty:'total',
	    fields: ['id', 'name','sort_order','category_id','image','cost_price','list_price','vat','total_price','supplier','supplier_product_id','allow_bonus_points','special','special_list_price','special_total_price','charge_shipping_costs','stock','bonus_points','required_products', 'iconCls', 'description'],
	    remoteSort: true
	});
	
	
	config.ddGroup='BsCategoriesDD';
	config.paging=true;
	
	this.searchField = new GO.form.SearchField({
								store: config.store,
								width:320
						  });
	
	config['tbar']=[
	            GO.lang['strSearch']+': ', ' ',this.searchField
	            ];
	            
	var columnModel =  new Ext.grid.ColumnModel({
		defaults:{
			sortable:true
		},
		columns:[{
		      header: "",
		      width:28,
					dataIndex: 'icon',
					renderer: this.iconRenderer
		    },
		{
			header: GO.lang.strName, 
			dataIndex: 'name',
			id:'name'
		},	
		{
			header: GO.billing.lang.supplier, 
			dataIndex: 'supplier'
		},{
			header: GO.billing.lang.supplierProductId, 
			dataIndex: 'supplier_product_id'
		},{
			header: GO.billing.lang.listPrice, 
			dataIndex: 'list_price',
			renderer:this.numberRenderer,
			width:50
		},		{
			header: GO.billing.lang.totalPrice, 
			dataIndex: 'total_price',
			renderer:this.numberRenderer,
			width:50
		},		{
			header: GO.billing.lang.stock, 
			dataIndex: 'stock',
			width:50
		}
	]
	});
	
	config.cm=columnModel;
	config.autoExpandColumn='name';
	config.view=new Ext.grid.GridView({
		emptyText: GO.lang['strNoItems']		
	}),
	config.sm=new Ext.grid.RowSelectionModel();
	config.loadMask=true;
	
	
	this.productDialog = new GO.billing.ProductDialog();
	    			    		
		this.productDialog.on('save', function(){   
			this.store.reload();	    			    			
		}, this);
	
	

	
	
	
	GO.billing.ProductsGrid.superclass.constructor.call(this, config);
	
	/*this.on('rowdblclick', function(grid, rowIndex){
		var record = grid.getStore().getAt(rowIndex);	
		
		this.productDialog.show(record.data.id);
		
		}, this);*/
		
	this.addEvents({
  	folderOpened : true, 
  	folderDrop : true
  	});
	
};

Ext.extend(GO.billing.ProductsGrid, GO.grid.GridPanel,{
	iconRenderer : function(src,cell,record){
		return '<div class="' + record.data.iconCls +'"></div>';
	},
	afterRender : function(){
		
		GO.grid.LinksGrid.superclass.afterRender.call(this);
		
		if(this.enableDragDrop)
		{
	  	var DDtarget = new Ext.dd.DropTarget(this.getView().mainBody, 
			{
				ddGroup : 'BsCategoriesDD',
				copy:false,
				notifyOver : this.onGridNotifyOver,
				notifyDrop : this.onGridNotifyDrop.createDelegate(this)
			});
		}
		
	},
	
	onGridNotifyOver : function(dd, e, data){
			var dragData = dd.getDragData(e);
			if(data.grid)
			{
  			var dropRecord = data.grid.store.data.items[dragData.rowIndex];
  			if(dropRecord)
    		{
  				if(dropRecord.data.id.substr(0,1)=='f')
  				{
  					return this.dropAllowed;
  				}
				}
			}
			return false;
	},

	onGridNotifyDrop : function(dd, e, data)
	{
	  if(data.grid)
		{
			var sm=data.grid.getSelectionModel();
			var rows=sm.getSelections();
			var dragData = dd.getDragData(e);
			
			var dropRecord = data.grid.store.data.items[dragData.rowIndex];
			
			if(dropRecord.data.id.substr(0,1)=='f')
	    {
				this.fireEvent('folderDrop', this, data.selections, dropRecord);
	    }
		}else
		{
		  return false;
		}
	},
	numberRenderer : function(v)
	{
		//v = GO.util.unlocalizeNumber(v);
		return GO.util.numberFormat(v);
	}
	
});