GO.customfields.dataTypes={
	user:{
		label : GO.lang.strUser,
		getFormField : function(customfield, config){

			var f = GO.customfields.dataTypes.text.getFormField(customfield, config);

			delete f.name;

			f=Ext.apply(f, {
				xtype: 'selectuser',
				idValuePair:true,
				startBlank:true,
				forceSelection:true,
				hiddenName:customfield.dataname,
				anchor:'-20',
				valueField:'cf'
			});

			return f;
		}
    },
	datetime:{
		label:'Date time',
		getFormField : function(customfield, config){
			var hourWidth = GO.settings.time_format.substr(0, 1) == 'G' ? 40 : 60;

			var now = new Date();

			var hour = new Ext.form.ComboBox({
				hiddenName : customfield.dataname+'_hour',
				store : new Ext.data.SimpleStore({
					fields : ['value', 'text'],
					data : GO.date.hours
				}),
				value:now.format('G'),
				valueField : 'value',
				displayField : 'text',
				mode : 'local',
				triggerAction : 'all',
				selectOnFocus : true,
				width : hourWidth,
				hideLabel : true,
				allowBlank: GO.util.empty(customfield.required)
			});

			var min = new Ext.form.ComboBox({
				hiddenName : customfield.dataname+'_min',
				store : new Ext.data.SimpleStore({
					fields : ['value', 'text'],
					data : GO.date.minutes
				}),
				value:'00',
				displayField : 'text',
				mode : 'local',
				triggerAction : 'all',
				selectOnFocus : true,
				width : 40,
				hideLabel : true,
				allowBlank: GO.util.empty(customfield.required)
			});

			var f = GO.customfields.dataTypes.text.getFormField(customfield, config);

			delete f.anchor;
			delete f.name;
			//delete f.fieldLabel;

			return Ext.apply(f, {
				xtype:'compositefield',
				items :[{
					xtype:'datefield',
					name: customfield.dataname,
					format: GO.settings['date_format'],
					width : 100,
					value:now,
					allowBlank: GO.util.empty(customfield.required)
				},
				hour,
				min]
			});
		}
	},

	date : {
		label:'Date',
		getFormField : function(customfield, config){

			var f = GO.customfields.dataTypes.text.getFormField(customfield, config);

			delete f.anchor;

			return Ext.apply(f, {
				xtype:'datefield',
				format: GO.settings['date_format'],
				width : 100
			});
		}
	},

	number : {
		label : 'Number',
		getFormField : function(customfield, config){

			var f = GO.customfields.dataTypes.text.getFormField(customfield, config);

			return Ext.apply(f, {
				xtype:'numberfield'
			});
		}
	},
	checkbox :{
		label: 'Checkbox',
		getFormField : function(customfield, config){

			var f = GO.customfields.dataTypes.text.getFormField(customfield, config);

			delete f.fieldLabel;

			return Ext.apply(f, {
				xtype:'xcheckbox',
				boxLabel: customfield.name,
				hideLabel: true
			});
		}
	},
	textarea : {
		label : 'Textarea',
		getFormField : function(customfield, config){
			var f = GO.customfields.dataTypes.text.getFormField(customfield, config);


			return Ext.apply(f, {
				xtype:'textarea'
			}, config);
		}
	},
	html : {
		label : 'HTML',
		getFormField : function(customfield, config){
			var f = GO.customfields.dataTypes.text.getFormField(customfield, config);

			return Ext.apply(f, {
				xtype:'htmleditor',
				height:200
			}, config);
		}
	},
	select : {
		label : 'Select',
		getFormField : function(customfield, config){
			var f = GO.customfields.dataTypes.text.getFormField(customfield, config);

			var store = new GO.data.JsonStore({
				url: GO.settings.modules.customfields.url+'json.php',
				baseParams: {
					'task': 'field_options',
					'field_id' : customfield.id
				},
				root: 'results',
				totalProperty: 'total',
				id: 'id',
				fields:['id','text'],
				remoteSort:true
			});

			if(GO.util.empty(customfield.multiselect)){
				return Ext.apply(f, {
					xtype:'combo',
					store: store,
					valueField:'text',
					displayField:'text',
					mode: 'remote',
					triggerAction: 'all',
					editable: true,
					selectOnFocus:true,
					forceSelection:true
				}, config);
			}else
			{
				return Ext.apply(f, {
					max:parseInt(customfield.max),
					allowAddNewData:true, //otherwise every value will be looked up at the server. We don't want that.
					xtype:'superboxselect',
					resizable: true,
					store: store,
					mode: 'remote',
					displayField: 'text',
					displayFieldTpl: '{text}',
					valueField: 'text',
					forceSelection : true,
					valueDelimiter:'|',
					hiddenName:customfield.dataname+'[]',
					anchor:'-20',
					allowBlank: GO.util.empty(customfield.required),
					queryDelay: 0,
					triggerAction: 'all'
				});
			}
		}
	},
	/*
	 * A treeselect consists of one master and one or more slave comboboxes.
	 * The slave is loaded with data depending on the selection of it's parent.
	 * The last slave can be a multiselect combo (superboxselect).
	 */
	treeselect : {
		label : 'Tree select',
		getFormField : function(customfield, config){

			//store the slaves of this treeselect in an array
			if(!GO.customfields.slaves)
				GO.customfields.slaves={};

			var treemaster_field_id = !GO.util.empty(customfield.treemaster_field_id) ? customfield.treemaster_field_id : customfield.id;

			if(!GO.customfields.slaves[treemaster_field_id])
				GO.customfields.slaves[treemaster_field_id]={};

			GO.customfields.slaves[treemaster_field_id][parseInt(customfield.nesting_level)]=customfield.dataname;

			var f = GO.customfields.dataTypes.text.getFormField(customfield, config);

			var store = new GO.data.JsonStore({
				url: GO.settings.modules.customfields.url+'json.php',
				baseParams: {
					'task': 'tree_select_options_combo',
					'field_id' : treemaster_field_id,
					parent_id:0
				},
				root: 'results',
				totalProperty: 'total',
				id: 'id',
				fields:['id','name','name_with_id'],
				remoteSort:true
			});

			delete f.name;

			if(GO.util.empty(customfield.multiselect)){
				return Ext.apply(f, {
					treemaster_field_id:treemaster_field_id,
					nesting_level:parseInt(customfield.nesting_level),
					xtype:'combo',
					store: store,
					hiddenName:customfield.dataname,
					valueField:'name_with_id',
					displayField:'name',
					mode: 'remote',
					triggerAction: 'all',
					editable: true,
					selectOnFocus:true,
					forceSelection:true,
					listeners:{
						scope:this,
						select:function(combo, record, index){
							var nextNestingLevel=combo.nesting_level+1;

							while(GO.customfields.slaves[combo.treemaster_field_id][nextNestingLevel]){
								var formPanel = combo.findParentByType('form');
								var field = formPanel.form.findField(GO.customfields.slaves[combo.treemaster_field_id][nextNestingLevel]);
								if(!field)
									field = formPanel.form.findField(GO.customfields.slaves[combo.treemaster_field_id][nextNestingLevel]+'[]');

								field.store.baseParams.parent_id=record.id;
								field.lastQuery = null;
								field.clearValue();

								nextNestingLevel++;
							}							
						},
						render:function(combo){
							var formPanel = combo.findParentByType('form');
							//add listener to form to set the correct form values and store parameters
							if(!formPanel.treeselectListenerAdded){
								formPanel.treeselectListenerAdded=true;

								formPanel.on('actioncomplete', function(form, action){
									if(action.type=='load'){
										form.items.each(function(field){
											//check if this field is a tree select
											if(field.treemaster_field_id){

												var nextField=false;
												var nextNestingLevel=field.nesting_level+1;
												if(GO.customfields.slaves[field.treemaster_field_id][nextNestingLevel]){

													var nextField = formPanel.form.findField(GO.customfields.slaves[field.treemaster_field_id][nextNestingLevel]);
													if(!nextField)
														nextField = formPanel.form.findField(GO.customfields.slaves[field.treemaster_field_id][nextNestingLevel]+'[]');
												}
												var v = field.getValue();

												if(v){
													if(!field.valueDelimiter){
														//normal combo

														v=v.split(':');
														if(v.length==2){

															if(nextField)
																nextField.store.baseParams.parent_id=v[0];

															field.setRawValue(v[1]);
														}
													}/*else
													{
														//superboxselect
														nextField.store.baseParams.parent_id=v;
													}*/
												}
											}
											
										});
									}
								});
							}
						}
					}
				}, config);
			}else
			{
				//only the last slave can be a multiselect combo
				return Ext.apply(f, {
					allowAddNewData:true,
					//itemId:customfield.dataname,
					max:parseInt(customfield.max),
					treemaster_field_id:treemaster_field_id,
					nesting_level:parseInt(customfield.nesting_level),
					xtype:'superboxselect',
					resizable: true,
					store: store,
					mode: 'remote',
					displayField:'name',
					displayFieldTpl: '{name}',
					valueField: 'name_with_id',
					forceSelection : true,
					valueDelimiter:'|',
					hiddenName:customfield.dataname+'[]',
					anchor:'-20',
					allowBlank: GO.util.empty(customfield.required),
					queryDelay: 0,
					triggerAction: 'all'
				}, config);
			}

		}
	},
	treeselect_slave : {
		label:'Tree select slave',
		getFormField : function(customfield, config){
			return GO.customfields.dataTypes.treeselect.getFormField(customfield, config);
		}
	},
	heading : {
		label : 'Heading',
		getFormField : function(customfield, config){
			return new GO.form.HtmlComponent(Ext.apply({
				html: "<h1 class=\"cf-heading\">"+customfield.name+"</h1>"
			}, config));
		}
	},
	'function' : {
		label : 'Function',
		getFormField : function(customfield, config){
			/*return new GO.form.PlainField(Ext.apply({
				name: customfield.dataname,
				fieldLabel: customfield.name,
				anchor:'-20'
			}, config));*/
			return false;
		}
	},
	text: {
		label : 'Text',
		getFormField : function(customfield, config){

			config = config || {};

			if(!GO.util.empty(customfield.validation_regex))
				config.regex=new RegExp(customfield.validation_regex);

			if(!GO.util.empty(customfield.helptext))
				config.plugins=new Ext.ux.FieldHelp(customfield.helptext);

			var fieldLabel = customfield.name;
			if(!GO.util.empty(customfield.required))
				fieldLabel+='*';

			return Ext.apply({
				xtype:'textfield',
				name: customfield.dataname,
				fieldLabel: fieldLabel,
				anchor:'-20',
				allowBlank: GO.util.empty(customfield.required)
			}, config);
		}
	},
	infotext: {
		label : 'Info text',
		getFormField : function(customfield, config){

			config = config || {};

			return Ext.apply({
				xtype:'htmlcomponent',
				html: customfield.name,
				style:'font-size:12px;margin-bottom:15px;'
			}, config);
		}
	}
};
