/**
 * Copyright Intermesh
 * 
 * This file is part of Group-Office. You should have received a copy of the
 * Group-Office license along with Group-Office. See the file /LICENSE.TXT
 * 
 * If you have questions write an e-mail to info@intermesh.nl
 * 
 * @copyright Copyright Intermesh
 * @version $Id: FieldDialog.js 10213 2011-02-22 12:51:37Z mschering $
 * @author Merijn Schering <mschering@intermesh.nl>
 */

 
GO.customfields.FieldDialog = function(config){	
	
	if(!config)
	{
		config={};
	}	
	
	this.nameField = new Ext.form.TextField({
		name: 'name',
		anchor:'100%',
		allowBlank:false,
		fieldLabel: GO.lang['strName']
	});
	
	
	this.categoryField = new GO.form.ComboBox({
		fieldLabel: GO.customfields.lang.category,
		hiddenName:'category_id',
		anchor:'100%',
		store: GO.customfields.categoriesStore,
		value:'text',
		valueField:'id',
		displayField:'name',
		mode: 'local',
		triggerAction: 'all',
		editable: false,
		selectOnFocus:true,
		forceSelection: true
	});



	var dataTypes=[];

	for (var type in GO.customfields.dataTypes){
		dataTypes.push([type, GO.customfields.dataTypes[type].label]);
	}

	/*
	['text', 'Text'],
	['textarea', 'Textarea'],
	['checkbox', 'Checkbox'],
	['number', 'Number'],
	['function', 'Function'],
	['date', 'Date'],
	['datetime', 'Date time'],
	['select', 'Select'],
	['heading', 'Heading']
];*/
  
	
	
	this.typeField = new Ext.form.ComboBox({
		fieldLabel: GO.lang.strType,
		hiddenName:'datatype',
		anchor:'100%',
		store: new Ext.data.SimpleStore({
			fields: ['value', 'text'],
			data : dataTypes,
			sortInfo : {
				field:'text',
				direction:'ASC'
			}
		}),
		value:'text',
		valueField:'value',
		displayField:'text',
		typeAhead: true,
		mode: 'local',
		triggerAction: 'all',
		editable: false,
		selectOnFocus:true,
		forceSelection: true
	});
    
	this.typeField.on('select', function(combo, record, index){
		this.typeChange(combo, record.data.value);
	}, this);
   
	this.typeField.on('change', this.typeChange, this);
    
  
	this.functionField = new Ext.form.TextField({
		name: 'function',
		anchor:'100%',
		allowBlank:true,
		fieldLabel: GO.lang.strFunction
	});
	
	var textComponent = new GO.form.HtmlComponent({
		html: GO.customfields.lang.numberField+GO.customfields.lang.usableOperators
	});	
	
	
	this.optionsGrid = new GO.customfields.SelectOptionsGrid();	
	this.optionsGrid.setVisible(false);


	this.treeSelectOptions = new GO.customfields.TreeSelectOptions();
	this.treeSelectOptions.setVisible(false);
	
  
	this.functionPanel = new Ext.form.FieldSet({
		title: GO.customfields.lang.functionProperties,
		autoHeight: true,
		border: true,
		items: [textComponent, this.functionField]
	});
  
	this.functionPanel.setVisible(false);
	
	this.formPanel = new Ext.FormPanel({
		labelWidth:140,
		autoHeight:true,
		waitMsgTarget:true,
		bodyStyle:'padding:5px;',
		items: [
		this.nameField,
		this.typeField,
		this.multiSelectCB = new Ext.form.Checkbox({
			name:'multiselect',
			fieldLabel:GO.customfields.lang.multiselect,
			listeners:{
				check:function(cb, check){
					this.max.getEl().up('.x-form-item').setDisplayed(check);
				},
				scope:this
			},
			plugins:[new Ext.ux.FieldHelp(GO.customfields.lang.multiselectForLastSlaveOnly)]
		}),
		this.max = new GO.form.NumberField({
			name:'max',
			decimals:0,
			width:40,
			value:0,
			fieldLabel:GO.customfields.lang.maxOptions,
			plugins:[new Ext.ux.FieldHelp(GO.customfields.lang.zeroMeansUnlimited)]
		}),
		this.masterTree = new GO.form.PlainField({
			name:'master_tree',
			fieldLabel:'Master select'
		}),
		this.categoryField,
		this.requiredCB = new Ext.form.Checkbox({
			xtype:'checkbox',
			name:'required',
			fieldLabel:GO.customfields.lang.required
		}),this.regexField = new Ext.form.TextField({
			disabled:true,
			name:'validation_regex',
			fieldLabel:GO.customfields.lang.validationRegexp,
			anchor:'100%'
		}),this.helptextField = new Ext.form.TextField({
			xtype:'textfield',
			anchor:'100%',
			name:'helptext',
			fieldLabel:GO.customfields.lang.helpText
		}),
		this.functionPanel,
		this.optionsGrid,
		this.treeSelectOptions
		],
		baseParams:{
			field_id:0
		}
	});	


	var focusName = function(){
		this.nameField.focus();		
	};

	config.maximizable=true;
	config.layout='fit';
	config.modal=false;
	config.resizable=false;
	config.width=500;
	//config.height=180;
	config.autoHeight=true;
	config.closeAction='hide';
	config.title= GO.lang.field;					
	config.items= this.formPanel;
	config.focus= focusName.createDelegate(this);
	config.buttons=[{
		text: GO.lang['cmdOk'],
		handler: function(){
			this.submitForm(true);
		},
		scope: this
	},{
		text: GO.lang['cmdApply'],
		handler: function(){
			this.submitForm();
		},
		scope:this
	},{
		text: GO.lang['cmdClose'],
		handler: function(){
			this.hide();
		},
		scope:this
	}
	];

	
	GO.customfields.FieldDialog.superclass.constructor.call(this, config);
	
	
	this.addEvents({
		'save' : true
	});
}

Ext.extend(GO.customfields.FieldDialog, Ext.Window,{

	typeChange : function(combo, newValue)
	{		
		this.helptextField.setDisabled(newValue=='infotext');
		this.requiredCB.setDisabled(newValue=='infotext');

		this.nameField.setHeight(newValue=='infotext' ? 120 : 22);

		this.treeSelectOptions.setVisible(newValue=='treeselect');
		if(newValue=='treeselect')
		{
			this.treeSelectOptions.setFieldId(this.field_id);
		}

		this.masterTree.container.up('div.x-form-item').setDisplayed(newValue=='treeselect_slave');

		this.functionPanel.setVisible(newValue=='function');
		if(newValue=='function')
		{
			this.functionPanel.doLayout();
		}

		this.multiSelectCB.container.up('div.x-form-item').setDisplayed(newValue=='select' || newValue=='treeselect_slave');

		this.multiSelectCB.helpTextEl.setDisplayed(newValue=='treeselect_slave');

		this.optionsGrid.setVisible(newValue=='select');
		if(newValue=='select')
		{
			this.optionsGrid.setFieldId(this.field_id);
		}

		this.regexField.setDisabled(newValue!='text');

		this.syncShadow();
		this.center();
	},
	
	show : function (field_id) {
		
		if(!this.rendered){
			this.render(Ext.getBody());
			this.max.getEl().up('.x-form-item').setDisplayed(false);
		}
		//this.formPanel.form.reset();
			
		this.setFieldId(field_id);
		
		if(field_id>0)
		{
			this.formPanel.load({
				url : GO.settings.modules.customfields.url+'json.php',
				params : {
					task: 'field'
				},
				
				success:function(form, action)
				{
					this.typeChange(this.typeField, this.typeField.getValue());
					GO.customfields.FieldDialog.superclass.show.call(this);
				},
				failure:function(form, action)
				{
					Ext.Msg.alert(GO.lang['strError'], action.result.feedback)
				},
				scope: this
				
			});
		}else 
		{			
			this.formPanel.form.reset();
			if(!this.lastCategoryId)
				this.lastCategoryId=GO.customfields.categoriesStore.data.items[0].id;

			this.categoryField.setValue(this.lastCategoryId);
			
			this.typeChange(this.typeField, 'text');
			GO.customfields.FieldDialog.superclass.show.call(this);
		}
	},
	
	setCategoryId : function(category_id)
	{
		this.formPanel.baseParams['category_id']=category_id;
		
	},
	setFieldId : function(field_id)
	{		
		this.formPanel.form.baseParams['field_id']=field_id;
		this.field_id=field_id;
		if(this.typeField.getValue()=='select')
			this.optionsGrid.setFieldId(field_id);

		if(this.typeField.getValue()=='treeselect')
			this.treeSelectOptions.setFieldId(field_id);
	},
	
	submitForm : function(hide){

		this.formPanel.form.submit(
		{
			url:GO.settings.modules.customfields.url+'action.php',
			params: {
				'task' : 'save_field',
				'select_options' : Ext.encode(this.optionsGrid.getGridData())
			},
			waitMsg:GO.lang['waitMsgSave'],
			success:function(form, action){
				
				this.fireEvent('save', this);
				
				if(action.result.field_id)
				{
					this.setFieldId(action.result.field_id);
				}

				if(hide)
				{
					this.hide();
				}

				this.lastCategoryId=this.categoryField.getValue();
				
				this.optionsGrid.store.commitChanges();

			},
			failure: function(form, action) {
				if(action.failureType == 'client')
				{
					Ext.MessageBox.alert(GO.lang['strError'], GO.lang['strErrorsInForm']);			
				} else {
					Ext.MessageBox.alert(GO.lang['strError'], action.result.feedback);
				}
			},
			scope: this
		});		
	}
});
