GO.projects.ProjectsTree = function(config){
	
	if(!config)
	{
		config = {};
	}

	this.treeLoader = new Ext.tree.TreeLoader(
	{
		dataUrl:GO.settings.modules.projects.url+'json.php',
		baseParams:{task: 'projects_tree'},
		preloadChildren:true
	});

	config.autoScroll=true;
	config.animate=true;
	config.loader=this.treeLoader;
	config.rootVisible=true;
	config.containerScroll=true;
	config.collapsible=false;
	config.ddAppendOnly=true;
	config.containerScroll=true;
	config.ddGroup='ProjectsDD';
	config.enableDD=true;

	this.rootNode = new Ext.tree.AsyncTreeNode({
		text:GO.projects.lang.projects,
		draggable:false,
		id:'0',
		expanded:true,
		iconCls:'folder-default'
	});
	
	GO.projects.ProjectsTree.superclass.constructor.call(this, config);
	
	this.setRootNode(this.rootNode);
	
	this.on('beforenodedrop', function(e)
	{	
		if(e.data.selections)
		{
			var selections = e.data.selections;
		}else
		{
			var record = {};
			record.data={};
			record.data['id']=e.data.node.id;
			var selections = [record];
		}
		
		this.moveProject(e.target.id, selections);
	},
	this);
	
	this.on('nodedragover', function(dragEvent)
	{
		if(!dragEvent.dropNode)
		{
			if(dragEvent.target.attributes.readonly)
			{
				return false;
			}

			var drag_allowed = true;
			for(var i=0;i<dragEvent.data.selections.length; i++)
			{				
				var moveid = dragEvent.data.selections[i].data.id;
				var targetid = dragEvent.target.id;					
				if(moveid==targetid)
				{
					drag_allowed = false;
				}					
				
				var dragNode = this.getNodeById(moveid);
				if(dragEvent.target.isAncestor(dragNode))
				{
					drag_allowed = false;
				}
								
				var parentId = dragNode.parentNode.id;
				if(parentId == dragEvent.target.id)
				{
					drag_allowed = false;
				}
				
				if(!drag_allowed)
				{
					return false;
				}				
			}
			return true;			
		}else
		{
			var parentId = this.getNodeById(dragEvent.dropNode.id).parentNode.id;					
			if(parentId == dragEvent.target.id)
			{
				return false
			}
		
			return true;		
		}
	}, this);
				
}

Ext.extend(GO.projects.ProjectsTree, Ext.tree.TreePanel,{
	project_id : 0,
	reloadActiveNode : function()
	{		
		var activeNode = this.getNodeById(this.project_id);
		if(activeNode)
		{
			delete activeNode.attributes.children;
			activeNode.reload();
		}
	},
	setActiveGridStore : function(store, searchfield)
	{
		this.store = store;
		this.searchfield=searchfield;
	},
	getActiveGridStore : function()
	{		
		return this.store;
	},
	setProjectID : function(id)
	{
		this.project_id = id;
		this.searchfield.reset();
		this.getActiveGridStore().baseParams.query='';
		this.getActiveGridStore().baseParams.parent_project_id = this.project_id;
		this.getActiveGridStore().load();

		
		/*this.getActiveGridStore().load(
		{
			callback:function()
			{
				var activeNode = this.getNodeById(id);
				if(activeNode)
				{
					activeNode.expand();
				}
			},
			scope:this
		});*/
	},
	moveProject : function(destination, records)
	{		
		var move_sources = Array();
		for(var i=0; i<records.length; i++)
		{
			move_sources.push(records[i].data['id']);
		}
		
		Ext.Ajax.request({
			url: GO.settings.modules.projects.url+'action.php',
			params:{
				task:'move_project',
				move_sources:Ext.encode(move_sources),
				move_destination:destination
			},
			callback: function(options, success, response)
			{			
				var responseParams = Ext.decode(response.responseText);					
				if(!responseParams.success)
				{
					Ext.MessageBox.alert(GO.lang['strError'], responseParams.feedback);
					this.rootNode.reload();
				}else
				{
					var store = this.getActiveGridStore();
					if(!destination || destination == this.project_id)
					{
						store.reload();
					}else if(move_sources)
					{
						for(var i=0; i<move_sources.length; i++)
						{										
							var record = store.getById(move_sources[i]);
							if(record)
							{
								store.reload();
								break;
							}
						}
					}	

					var destinationNode = this.getNodeById(destination);
					if(destinationNode)
					{
						delete destinationNode.attributes.children;							
						destinationNode.reload();
					}
					
					if(move_sources)
					{
						for(var i=0; i<move_sources.length; i++)
						{
							var node = this.getNodeById(move_sources[i]);
							if(node)
							{
								node.remove();
							}
						}	
					}						
				}											
			},
			scope: this		
		});
	}
	
});