/** 
 * Copyright Intermesh
 * 
 * This file is part of Group-Office. You should have received a copy of the
 * Group-Office license along with Group-Office. See the file /LICENSE.TXT
 * 
 * If you have questions write an e-mail to info@intermesh.nl
 * 
 * @version $Id: SettingsDialog.js 9747 2010-12-14 12:19:55Z mschering $
 * @copyright Copyright Intermesh
 * @author Merijn Schering <mschering@intermesh.nl>
 */
 
GO.projects.SettingsDialog = function(config){
	
	if(!config)
	{
		config={};
	}

	this.statusesPanel = new GO.projects.StatusesGrid({
		title:GO.projects.lang.statuses,
		layout:'fit'
	});
		
	this.typesPanel = new GO.projects.TypesGrid({
		title:GO.projects.lang.types,
		layout:'fit'
	});
		
	this.templatesPanel = new GO.projects.TemplatesGrid({
		title:GO.projects.lang.templates,
		layout:'fit'
	});

	this.reportTemplatesPanel = new GO.projects.ReportTemplatesGrid({
		title:GO.projects.lang.reportTemplates,
		layout:'fit'
	});

	this.followNumberPanel = new Ext.FormPanel({
		title: GO.projects.lang.followNumbers,
		waitMsgTarget:true,
		style:'margin:5px',
		items:[{
						fieldLabel: GO.projects.lang.enableFollowNumber,
						name: 'chkCustomId',
						xtype:'checkbox',
						labelStyle:'margin:5px'
					}, {
						fieldLabel: GO.projects.lang.followNumberFormat,
						name: 'customId',
						xtype:'textfield',
						labelStyle:'margin:5px'
					}],
		autoScroll:true,
		listeners:{
			render:function(){
					this.followNumberPanel.form.load({
						url: GO.settings.modules.projects.url+'json.php',
						params: {
							task: 'get_settings_data'
						},

						scope: this
					});
			},
			scope:this
		}
	});

	this.settingsPanel = new Ext.Panel({
			title: GO.projects.lang.settings,
			layout: 'form',
			autoScroll:true,
			items: [
				this.followNumberPanel
			]
		})

	if(GO.settings.modules.timeregistration){
		this.feesPanel = new GO.projects.FeesGrid({
			title:GO.projects.lang.specialFees,
			layout:'fit',
			tabTip:GO.projects.lang.tooltipSpecialFees,
			style:'margin:5px',
			height:150
		});

		this.userFeesPanel = new GO.projects.ProjectFeesPanel({
			title:GO.projects.lang.userFees,
			tabTip:GO.projects.lang.tooltipDefaultFees,
			style:'margin:5px',
			height:150,
			/*
			tbar:[{
				text:GO.lang.cmdSave,
				iconCls:'btn-save',
				handler:function(){
					this.userFeesPanel.el.mask(GO.lang.waitMsgLoad);
					Ext.Ajax.request({
						url:GO.settings.modules.projects.url+'action.php',
						params:{
							task:'user_fees',
							project_id:this.userFeesPanel.store.baseParams.project_id,
							fees:Ext.encode(this.userFeesPanel.getGridData())
						},
						callback:function(options, success, response){
							this.userFeesPanel.store.commitChanges();
							this.userFeesPanel.el.unmask();
						},
						scope:this
					});
				},
				scope:this
			}],
			*/
			listeners:{
				render:function(){
					if(!this.store.loaded)
						this.store.load();
				},
				scope:this.userFeesPanel
			}
		});

		this.settingsPanel.add(this.userFeesPanel,this.feesPanel);
	}

	this.expenseTypesGrid = new GO.projects.ExpenseTypes({
		style:'margin:5px',
		height:150
	});
	this.incomeTypesGrid = new GO.projects.IncomeTypes({
		style:'margin:5px',
		height:150
	});

	this.settingsPanel.add(this.expenseTypesGrid,this.incomeTypesGrid);

	
	var items=[
	this.settingsPanel,
	this.typesPanel,
	this.templatesPanel,
	this.statusesPanel,
	this.reportTemplatesPanel	
	];

	config.layout='fit';
	config.modal=false;
	config.resizable=false;
	config.width=750;
	config.height=500;
	config.closeAction='hide';
	config.title= GO.lang.cmdSettings;

	config.items=this.tabPanel = new Ext.TabPanel({
		activeTab: 0,      
		border:false,
		deferredRender: true,
		enableTabScroll:true,
		items:items
	});
	
	config.buttons=[{
		text: GO.lang.cmdOk,
		handler: function(){
			this.save();
			this.hide();
		},
		scope:this
	},{
		text: GO.lang.cmdClose,
		handler: function(){
			this.hide();
		},
		scope:this
	}];
	
	GO.projects.SettingsDialog.superclass.constructor.call(this, config);	
}
Ext.extend(GO.projects.SettingsDialog, GO.Window,{
	show : function(){
		GO.projects.SettingsDialog.superclass.show.call(this);

	
	},
	save : function(){
		this.followNumberPanel.form.submit(
		{
			url:GO.settings.modules.projects.url+'action.php',
			params: {
				'task' : 'save_settings',
				project_id : this.userFeesPanel.store.baseParams.project_id,
				incomeTypes : Ext.encode(this.incomeTypesGrid.getGridData()),
				expenseTypes : Ext.encode(this.expenseTypesGrid.getGridData()),
				fees : Ext.encode(this.feesPanel.getGridData()),
				userFees : Ext.encode(this.userFeesPanel.getGridData())
			},
			waitMsg:GO.lang['waitMsgSave'],
			success:function(form, action){

				GO.projects.nameTemplate = action.result.new_name_template;
				GO.projects.useNameTemplate = action.result.use_name_template;

				this.fireEvent('save', this);

			},
			failure: function(form, action) {
				if(action.failureType == 'client')
				{
					Ext.MessageBox.alert(GO.lang['strError'], GO.lang['strErrorsInForm']);
				} else {
					Ext.MessageBox.alert(GO.lang['strError'], action.result.feedback);
				}
			},
			scope: this
		});
	}
});