/**
 * Copyright Intermesh
 * 
 * This file is part of Group-Office. You should have received a copy of the
 * Group-Office license along with Group-Office. See the file /LICENSE.TXT
 * 
 * If you have questions write an e-mail to info@intermesh.nl
 * 
 * @version $Id: TemplateDialog.js 10110 2011-02-10 13:02:27Z mschering $
 * @copyright Copyright Intermesh
 * @author Merijn Schering <mschering@intermesh.nl>
 */
GO.projects.TemplateDialog = function(config) {
	if (!config) {
		config = {};
	}
	this.buildForm();
	var focusFirstField = function() {
		this.propertiesPanel.items.items[0].focus();
	};
	config.collapsible = true;
	config.maximizable = true;
	config.layout = 'fit';
	config.modal = false;
	config.resizable = false;
	config.width = 700;
	config.height = 500;
	config.closeAction = 'hide';
	config.title = GO.projects.lang.template;
	config.items = this.formPanel;
	config.focus = focusFirstField.createDelegate(this);
	config.buttons = [{
		text : GO.lang['cmdOk'],
		handler : function() {
			this.submitForm(true);
		},
		scope : this
	}, {
		text : GO.lang['cmdApply'],
		handler : function() {
			this.submitForm();
		},
		scope : this
	}, {
		text : GO.lang['cmdClose'],
		handler : function() {
			this.hide();
		},
		scope : this
	}];
	GO.projects.TemplateDialog.superclass.constructor.call(this, config);
	this.addEvents({
		'save' : true
	});
}
Ext.extend(GO.projects.TemplateDialog, Ext.Window, {
	show : function(template_id) {

		if(!GO.projects.statusesStore.loaded)
		{
			GO.projects.statusesStore.load({
				callback:function(){
					this.show(template_id);
				},
				scope:this
			});
			return false;
		}

		if (!this.rendered) {
			this.render(Ext.getBody());
		}
		this.formPanel.form.reset();
		this.tabPanel.setActiveTab(0);
		if (!template_id) {
			template_id = 0;
		}
		this.setTemplateId(template_id);
		if (this.template_id > 0) {
			this.formPanel.load({
				url : GO.settings.modules.projects.url + 'json.php',
				waitMsg : GO.lang['waitMsgLoad'],
				success : function(form, action) {

					this.readPermissionsTab.setAcl(action.result.data.acl_id);
					this.selectUser.setRemoteText(action.result.data.user_name);

					this.setFilesFolderId(action.result.data.files_folder_id);

					GO.projects.TemplateDialog.superclass.show.call(this);
				},
				failure : function(form, action) {
					Ext.Msg.alert(GO.lang['strError'], action.result.feedback)
				},
				scope : this
			});
		} else {
			this.readPermissionsTab.setAcl(0);

			GO.projects.TemplateDialog.superclass.show.call(this);
		}
	},

	setTemplateId : function(template_id) {
		this.formPanel.form.baseParams['template_id'] = template_id;
		this.template_id = template_id;
		this.templateEventsGrid.setTemplateID(template_id);

		if(this.templateTabs)
			this.templateTabs.setTemplateID(template_id);
		
	},

	setFilesFolderId : function(files_folder_id){
		this.files_folder_id=files_folder_id;
		if(this.fileBrowseButton)
			this.fileBrowseButton.setDisabled(files_folder_id=0);
	},
	submitForm : function(hide) {
		this.formPanel.form.submit({
			url : GO.settings.modules.projects.url + 'action.php',
			params : {
				'task' : 'save_template'
			},
			waitMsg : GO.lang['waitMsgSave'],
			success : function(form, action) {
				if (action.result.template_id) {
					this.setTemplateId(action.result.template_id);
					this.readPermissionsTab
					.setAcl(action.result.acl_id);

					if(action.result.files_folder_id)
						this.setFilesFolderId(action.result.files_folder_id);
				}
				this.fireEvent('save', this, this.template_id);
				if (hide) {
					this.hide();
				}
			},
			failure : function(form, action) {
				if (action.failureType == 'client') {
					Ext.MessageBox.alert(GO.lang['strError'],
						GO.lang['strErrorsInForm']);
				} else {
					Ext.MessageBox.alert(GO.lang['strError'],
						action.result.feedback);
				}
			},
			scope : this
		});
	},
	buildForm : function() {


		/*this.fieldsPanel = {
							xtype:'fieldset',
							title:GO.projects.lang.fields,
							autoHeight:true,
							items:[{
									xtype:'checkbox',
									name:'fields[responsible_user_id]',
									hideLabel: true,
									boxLabel:GO.projects.lang.projectManager
							},{
									xtype:'checkbox',
									name:'fields[customer]',
									hideLabel: true,
									boxLabel:GO.lang.customer
							},{
									xtype:'checkbox',
									name:'fields[contact]',
									hideLabel: true,
									boxLabel:GO.projects.lang.contact
							},{
									xtype:'checkbox',
									name:'fields[status_date]',
									hideLabel: true,
									boxLabel:'Status and date'
							},{
									xtype:'checkbox',
									name:'fields[budget_fees]',
									hideLabel: true,
									boxLabel:'Budget and fees'
							},{
									xtype:'checkbox',
									name:'fields[expenses]',
									hideLabel: true,
									boxLabel:GO.projects.lang.expenses
							},{
									xtype:'checkbox',
									name:'fields[incomes]',
									hideLabel: true,
									boxLabel:GO.projects.lang.income
							}]
					
				
		};*/

		this.fieldsPanel = {
			xtype: 'checkboxgroup',
			fieldLabel: GO.projects.lang.enabledFields,
			columns: 3,
			items:[{
				name:'fields[responsible_user_id]',
				boxLabel:GO.projects.lang.projectManager
			},{
				name:'fields[customer]',
				boxLabel:GO.lang.customer
			},{
				name:'fields[contact]',
				boxLabel:GO.projects.lang.contact
			},{
				name:'fields[status_date]',
				boxLabel:GO.projects.lang.statusAndDate
			},{
				name:'fields[budget_fees]',
				boxLabel:GO.projects.lang.budgetAndFees
			},{
				name:'fields[expenses]',
				boxLabel:GO.projects.lang.expenses
			},{
				name:'fields[incomes]',
				boxLabel:GO.projects.lang.income
			},{
				name:'fields[associated_calendar]',
				boxLabel:GO.projects.lang.associatedCalendar
			}]
		};

		
		this.propertiesPanel = new Ext.Panel({
			title : GO.lang['strProperties'],
			cls : 'go-form-panel',
			layout : 'form',
			autoScroll : true,
			items : [this.selectUser = new GO.form.SelectUser({
				fieldLabel : GO.lang['strUser'],
				disabled : !GO.settings.modules['projects']['write_permission'],
				value : GO.settings.user_id,
				anchor : '-20'
			}), {
				xtype : 'textfield',
				name : 'name',
				anchor : '-20',
				fieldLabel : GO.lang.strName
			},{
				xtype : 'selectfile',
				name : 'icon',
				anchor : '-20',
				fieldLabel : 'Icon',
				root_folder_id : GO.projects.templateIconsFolderId
			},{
    		xtype:'combo',
    		anchor:'-20',
       	fieldLabel: GO.projects.lang.defaultStatus,
        hiddenName:'default_status_id',
        store:GO.projects.statusesStore,
        valueField:'id',
        displayField:'name',
        mode: 'local',
        triggerAction: 'all',
        editable: false,
        selectOnFocus:true,
        forceSelection: true,
        allowBlank:false
			},new GO.projects.SelectType({
    		anchor:'-20',
       	fieldLabel: GO.projects.lang.defaultPermissionType,
        hiddenName:'default_type_id'
			}),
			this.fieldsPanel]			
		});		

		if(GO.files)
		{
			this.fileBrowseButton = new Ext.Button({
				text: GO.files.lang.files,
				handler: function(){
					GO.files.openFolder(this.files_folder_id);
				},
				scope: this,
				disabled: true
			});

			this.propertiesPanel.add(this.fileBrowseButton);
		}

		
		this.templateEventsGrid = new GO.projects.TemplateEventsGrid();


		
		var items = [this.propertiesPanel];
		
		if(GO.customfields){
			this.templateTabs = new GO.projects.TemplateTabs();
			items.push(this.templateTabs);
		}

		items.push(this.templateEventsGrid);


		this.readPermissionsTab = new GO.grid.PermissionsPanel({
			title : GO.lang['strReadPermissions'],
			hideLevel:true
		});

		items.push(this.readPermissionsTab);
		this.tabPanel = new Ext.TabPanel({
			activeTab : 0,
			deferredRender : false,
			border : false,
			items : items,
			anchor : '100% 100%'
		});
		this.formPanel = new Ext.form.FormPanel({
			waitMsgTarget : true,
			url : GO.settings.modules.projects.url + 'action.php',
			border : false,
			baseParams : {
				task : 'template'
			},
			items : this.tabPanel
		});
	}
});
