/** 
 * Copyright Intermesh
 * 
 * This file is part of Group-Office. You should have received a copy of the
 * Group-Office license along with Group-Office. See the file /LICENSE.TXT
 * 
 * If you have questions write an e-mail to info@intermesh.nl
 * 
 * @version $Id: Settings.js 8741 2010-08-10 10:16:24Z mschering $
 * @copyright Copyright Intermesh
 * @author Merijn Schering <mschering@intermesh.nl>
 */
 
GO.sync.SyncSettingsPanel = function(config)
{
	if(!config)
	{
		config={};
	}
	
	config.autoScroll=true;
	config.border=false;
	config.hideLabel=true;
	config.title = GO.sync.lang.sync;
	config.layout='form';
	config.forceLayout=true;
	config.defaults={
		anchor:'-20'
	};
	config.defaultType = 'textfield';
	config.cls='go-form-panel';
	config.labelWidth=190;
	config.items=[{
		xtype: 'plainfield',
		fieldLabel: 'Sync URL',
		name: 'sync_url',
		anchor:'-20'
	}];


	config.items.push(new GO.form.HtmlComponent({
		html: '<p class="go-form-text">'+GO.sync.lang.max_age_text+'</p>'
	}));

	config.items.push(new GO.form.NumberField({
		decimals: "0",
		fieldLabel: GO.sync.lang.max_age,
		name: 'max_days_old',
		width:50
	}));

	config.items.push({
		xtype:'checkbox',
		name: 'delete_old_events',
		hideLabel:true,
		boxLabel: GO.sync.lang.delete_old_events.replace('Group-Office', GO.settings.config.product_name)
	});

	if(GO.settings.modules.email && GO.settings.modules.email.read_permission)
	{
		this.selectAccount = new GO.form.ComboBox({
			fieldLabel: GO.email.lang.account,
			hiddenName:'account_id',
			anchor:'-20',
			emptyText:GO.lang.strPleaseSelect,
			store: new GO.data.JsonStore({
				url: GO.settings.modules.email.url+ 'json.php',
				baseParams: {
					task: 'accounts'
				},
				root: 'results',
				id: 'id',
				totalProperty:'total',
				fields: ['id', 'username'],
				remoteSort: true
			}),
			valueField:'id',
			displayField:'username',
			typeAhead: true,
			mode: 'remote',
			triggerAction: 'all',
			editable: false,
			selectOnFocus:true,
			forceSelection: true
		});
		
		config.items.push(this.selectAccount);
	}

	if(GO.settings.modules.calendar && GO.settings.modules.calendar.read_permission)
	{
		this.selectCalendar = new GO.form.ComboBox({
			fieldLabel: GO.calendar.lang.calendar,
			hiddenName:'calendar_id',
			anchor:'-20',
			emptyText:GO.lang.strPleaseSelect,
			store: new GO.data.JsonStore({
				url: GO.settings.modules.calendar.url+ 'json.php',
				baseParams: {
					task: 'writable_calendars'
				},
				root: 'results',
				id: 'id',
				totalProperty:'total',
				fields: ['id', 'name'],
				remoteSort: true
			}),
			pageSize: parseInt(GO.settings.max_rows_list),
			valueField:'id',
			displayField:'name',
			typeAhead: true,
			mode: 'remote',
			triggerAction: 'all',
			editable: false,
			selectOnFocus:true,
			forceSelection: true,
			allowBlank: false
		});
		config.items.push(this.selectCalendar);
	}

	if(GO.settings.modules.tasks && GO.settings.modules.tasks.read_permission)
	{
		this.selectTasklist = new GO.sync.TasklistsGrid({
			height:100,
			forceLayout:true,
			autoExpandColumn: 'nameCol',
			bodyStyle:'padding:0px'
		});

		this.panelTasklist = new Ext.Panel({
			forceLayout:true,
			layout: 'column',
			bodyStyle:'padding-left:0px; padding-right:0px',
			border:false,
			items: [{
				forceLayout:true,
				bodyStyle:'padding-left:0px',
				width: config.labelWidth,
				border:false,
				html:GO.tasks.lang.tasklists+':'
			},{
				forceLayout:true,
				bodyStyle:'padding-right:0px',
				items:[this.selectTasklist],
				border:false,
				columnWidth:1,
				layout:'fit'
			}]

		});
		config.items.push(this.panelTasklist);
	}
	
	if(GO.settings.modules.addressbook && GO.settings.modules.addressbook.read_permission)
	{
		this.selectAddressbook = new GO.sync.AddressbooksGrid({
			height:100,
			forceLayout:true,
			autoExpandColumn: 'nameCol',
			bodyStyle:'padding:0px'
		});

		this.panelAddressbook = new Ext.Panel({
			forceLayout:true,
			layout: 'column',
			bodyStyle:'padding-left:0px; padding-right:0px',
			border:false,
			items: [{
				forceLayout:true,
				bodyStyle:'padding-left:0px',
				width: config.labelWidth,
				border:false,
				html:GO.sync.lang.addressbooks+':'
			},{
				forceLayout:true,
				bodyStyle:'padding-right:0px',
				items:[this.selectAddressbook],
				border:false,
				columnWidth:1,
				layout:'fit'
			}]

		});
		config.items.push(this.panelAddressbook);
	}



	if(GO.settings.modules.notes && GO.settings.modules.notes.read_permission)
	{
		this.selectNoteCategories = new GO.sync.NoteCategoriesGrid({
			height:100,
			forceLayout:true,
			autoExpandColumn: 'nameCol',
			bodyStyle:'padding:0px'
		});

		this.panelNoteCategory = new Ext.Panel({
			forceLayout:true,
			layout: 'column',
			bodyStyle:'padding-left:0px; padding-right:0px',
			border:false,
			items: [{
				forceLayout:true,
				bodyStyle:'padding-left:0px',
				width: config.labelWidth,
				border:false,
				html:GO.sync.lang.noteCategories+':'
			},{
				forceLayout:true,
				bodyStyle:'padding-right:0px',
				items:[this.selectNoteCategories],
				border:false,
				columnWidth:1,
				layout:'fit'
			}]

		});
		config.items.push(this.panelNoteCategory);
	}


	
	this.devicesGrid = new GO.sync.DevicesGrid({
		height:100,
		forceLayout: true,
		bodyStyle: 'padding:0px'
	});

	this.paneldevicesGrid = new Ext.Panel({
		forceLayout:true,
		layout: 'column',
		bodyStyle:'padding-left:0px; padding-right:0px',
		border:false,
		items: [{
			forceLayout:true,
			bodyStyle:'padding-left:0px',
			width: config.labelWidth,
			border:false,
			html:GO.sync.lang.devices+':'
		},{
			forceLayout:true,
			bodyStyle:'padding-right:0px',
			items:[this.devicesGrid],
			border:false,
			columnWidth:1,
			layout:'fit'
		}]

	});
	config.items.push(this.paneldevicesGrid);
	
	GO.sync.SyncSettingsPanel.superclass.constructor.call(this, config);		
};


Ext.extend(GO.sync.SyncSettingsPanel, Ext.Panel,{
	onLoadSettings : function(action){
		if(this.selectCalendar)
			this.selectCalendar.setRemoteText(action.result.data.calendar_name);

		if(this.selectAccount)
			this.selectAccount.setRemoteText(action.result.data.account_name);

		if(this.selectAddressbook)
			this.selectAddressbook.store.load();
		if(this.selectTasklist)
			this.selectTasklist.store.load();

		if(this.selectNoteCategories)
			this.selectNoteCategories.store.load();
		
	},
	onBeforeSaveSettings : function(dlg){
		if(this.selectAddressbook){
			dlg.formPanel.baseParams.sync_addressbooks=Ext.encode(this.selectAddressbook.getGridData());
			if(!this.selectAddressbook.getGridData().def)
			{
				alert(GO.sync.lang.noDefaultAddressbook);
				return false;
			}
		}
		if(this.selectTasklist){
			dlg.formPanel.baseParams.sync_tasklists=Ext.encode(this.selectTasklist.getGridData());
			if(!this.selectTasklist.getGridData().def)
			{
				alert(GO.sync.lang.noDefaultTasklist);
				return false;
			}		
		}

		if(this.selectNoteCategories){
			dlg.formPanel.baseParams.sync_note_categories=Ext.encode(this.selectNoteCategories.getGridData());
			if(!this.selectNoteCategories.getGridData().def)
			{
				alert(GO.sync.lang.noDefaultNoteCategory);
				return false;
			}
		}

		return true;
	},

	onSaveSettings : function(){
		if(this.selectTasklist)
			this.selectTasklist.store.commitChanges();
		
		if(this.selectAddressbook)
			this.selectAddressbook.store.commitChanges();

		if(this.selectNoteCategories)
			this.selectNoteCategories.store.commitChanges();
	},
	onShow : function(){
		GO.sync.SyncSettingsPanel.superclass.onShow.call(this);

		this.devicesGrid.store.load();
		
	}
});			


GO.mainLayout.onReady(function(){
	GO.moduleManager.addSettingsPanel('sync', GO.sync.SyncSettingsPanel);	
});	
