/**
 * Copyright Intermesh
 *
 * This file is part of Group-Office. You should have received a copy of the
 * Group-Office license along with Group-Office. See the file /LICENSE.TXT
 *
 * If you have questions write an e-mail to info@intermesh.nl
 *
 * @version $Id: MainPanel.js 10811 2011-05-19 06:24:15Z mschering $
 * @copyright Copyright Intermesh
 * @author Michiel Schmidt <michiel@intermesh.nl>
 * @author Merijn Schering <mschering@intermesh.nl>
 */

GO.tickets.MainPanel = function(config){

	if(!config)
	{
		config = {};
	}
	
	this.typesGrid = GO.tickets.typesGrid = new GO.tickets.TypesGrid({
		region:'north',
		id:'ti-types-grid',
		height:200
	});
	

	this.filterPanel = GO.tickets.filterPanel = new GO.tickets.TicketsFilterGrid({
		region:'center',
		id:'ti-filter-panel',
		title: GO.tickets.lang.statuses,
		store:GO.tickets.statusesStore,
		border:true,
		loadMask:true,
		allowNoSelection:true,
		split:true
	});

	this.filterPanel.on('showMineOnly', function(filterGrid, showMineOnly)
	{
		this.centerPanel.store.baseParams.showMineOnly = showMineOnly;
		this.centerPanel.store.load();

		delete this.centerPanel.store.baseParams.showMineOnly;
	},this);
	
	this.filterPanel.on('change', function(filterGrid, statuses, records)
	{
		this.centerPanel.store.baseParams.statuses = Ext.encode(statuses);
		this.centerPanel.store.load();
	
		if(this.centerPanel.store.baseParams.type_id == 0)
			this.statuses = this.centerPanel.store.baseParams.statuses;
		
		delete this.centerPanel.store.baseParams.statuses;		
	}, this);
		
	var westPanel = new Ext.Panel({
		region:'west',
		layout:'border',
		id:'ti-west-panel',
		border:false,
		split:true,
		width:200,
		items:[this.typesGrid, this.filterPanel]
	});
	
	this.typesGrid.on('rowclick', function(grid, rowIndex)
	{
		var record = grid.getStore().getAt(rowIndex);
		
		this.setType(record.data.id, record.data.name, record.data.acl_id);
		this.centerPanel.selModel.clearSelections();
		this.eastPanel.reset();
		
	}, this);
	
	this.typesGrid.store.on('load', function()
	{		
		if(GO.tickets.typesGrid.store.baseParams.reload)
		{
			delete GO.tickets.typesGrid.store.baseParams.reload;
		}else
		{
			this.typesGrid.selModel.selectFirstRow();
			var record = this.typesGrid.selModel.getSelected();

			if(record)
			{
				this.setType(record.data.id, record.data.name, record.data.acl_id);
			}else
			{
				this.setType(0);
			}
		}
	}, this);	
	
	this.centerPanel = GO.tickets.ticketsGrid = new GO.tickets.TicketsGrid({
		title: GO.tickets.lang.tickets,
		region:'center',
		id:'ti-tickets-grid',        
		border:true,
		resizable:false
	});
	
	this.centerPanel.store.on('load', function()
	{
		this.setWritePermission(this.centerPanel.store.reader.jsonData.write_permission, this.centerPanel.store.reader.jsonData.permission_level);
		this.centerPanel.setVars(this.centerPanel.store.reader.jsonData.mtime, this.centerPanel.store.reader.jsonData.total);
		GO.tickets.totalUnseenVisible = this.centerPanel.store.reader.jsonData.unseen_visible;
	}, this);
	
	this.centerPanel.on("delayedrowselect",function(grid, rowIndex, r)
	{
		this.eastPanel.load(r.get('id'));
	}, this);

	if(GO.settings.modules.tickets.write_permission){
		this.centerPanel.on('rowdblclick', function(grid, rowIndex){
			var record = grid.getStore().getAt(rowIndex);
			GO.tickets.showTicketDialog(record.id);
		}, this);
	}
			
	this.eastPanel = new GO.tickets.TicketPanel({
		region:'east',
		id:'ti-ticket-panel',
		mf_id:'ti-message-form',
		mp_id:'ti-message-panel',
		width:500,
		title:GO.tickets.lang.ticket
	});

	var tbarItems = [
	this.addButton = new Ext.Button({
		iconCls: 'btn-add',
		text: GO.tickets.lang.addTicket,
		cls: 'x-btn-text-icon',
		handler: function()
		{
			this.eastPanel.reset();
			GO.tickets.showTicketDialog(0, {
				type_id: this.centerPanel.store.baseParams.type_id,
				type_name: this.type_name
			});
		},
		disabled:true,
		scope: this
	}),{
		iconCls: 'btn-refresh',
		text: GO.lang['cmdRefresh'],
		cls: 'x-btn-text-icon',
		handler: function(){
			this.refresh();
		},
		scope: this
	}];

	if(GO.settings.modules.tickets.write_permission){
		tbarItems.push('-',
			this.deleteButton = new Ext.Button({
				iconCls: 'btn-delete',
				text: GO.lang['cmdDelete'],
				cls: 'x-btn-text-icon',
				handler: function()
				{
					this.centerPanel.deleteSelected();
					this.filterPanel.store.reload();
				},
				disabled:true,
				scope: this
			}),
			{
				iconCls: 'btn-export',
				text: GO.lang.cmdExport,
				cls: 'x-btn-text-icon',
				handler:function(){
					var config = {};

					config.colModel = this.centerPanel.getColumnModel();
					config.title = GO.tickets.lang.tickets;

					var query = this.centerPanel.searchField.getValue();
					if(!GO.util.empty(query))
					{
						config.subtitle= GO.lang.searchQuery+': '+query;
					}else
					{
						config.subtitle='';
					}

					if(!this.exportDialog)
					{
						this.exportDialog = new GO.ExportQueryDialog({
							query:'get_tickets'
						});
					}
					this.exportDialog.show(config);

				},
				scope: this
			});

		if(GO.settings.has_admin_permission){
			tbarItems.push( this.settingsButton = new Ext.Button({
				iconCls: 'btn-settings',
				text: GO.lang.administration,
				cls: 'x-btn-text-icon',

				handler: function()
				{
					if(!this.settingsDialog)
					{
						this.settingsDialog = new GO.tickets.SettingsDialog();
						this.settingsDialog.on('update_statuses', function()
						{
							GO.tickets.statusesStore.load();
						}, this);
						this.settingsDialog.on('update_templates', function()
						{
							GO.tickets.templatesStore.load();
						}, this);
					}
					this.settingsDialog.show();
				},
				scope: this
			}));
		}

		if(GO.billing){
			tbarItems.push('-',{
				iconCls:'btn-add',
				text:GO.tickets.lang.bill,
				handler:function(){
					if(!GO.tickets.invoiceDialog)
					{
						GO.tickets.invoiceDialog= new GO.tickets.InvoiceDialog({
							listeners:{
								invoice:function(){
									this.refresh();
								},
								scope:this
							}
						});
					}
					GO.tickets.invoiceDialog.show();
				},
				scope:this
			});
		}
	}

	config.tbar=new Ext.Toolbar({
		cls:'go-head-tb',
		items: tbarItems
	});
	
	config.items=[
	westPanel,
	{
		border:false,
		region:'center',
		titlebar: false,
		layout:'border',
		items: [this.centerPanel,this.eastPanel]
	}
	];   
		
	config.layout='border';
			
	GO.tickets.MainPanel.superclass.constructor.call(this, config);

}

Ext.extend(GO.tickets.MainPanel, Ext.Panel,{
	onShow : function(){

		GO.tickets.notificationEl.setDisplayed(false);
		GO.tickets.MainPanel.superclass.onShow.call(this);
	},

	statuses: '',

	refresh : function(dontRefreshTickerPanel){
		GO.tickets.statusesStore.load();
		this.centerPanel.store.load();
		if(!dontRefreshTickerPanel)
			this.eastPanel.reload();
	},
	
	afterRender : function()
	{
		GO.tickets.MainPanel.superclass.afterRender.call(this);

		GO.tickets.notificationEl.setDisplayed(false);

		GO.tickets.mainPanel = this;

		GO.dialogListeners.add('ticket',{
			scope:this,
			save:function(e, ticket_id, refresh){
				if(refresh)
					this.filterPanel.store.reload();

				this.centerPanel.store.reload();
			}
		});

		this.typesGrid.store.load();
	},
	setWritePermission : function(write_permission, level)
	{
                // if there is no level 'all-types' is selected, always enable delete button here
                if(!level)
                    level = 3;

                var delete_permission = (level < 3) ? false : true;                
                
		if(GO.settings.modules.tickets.write_permission){
			this.deleteButton.setDisabled(!write_permission || !delete_permission);
		}
		this.addButton.setDisabled(!write_permission);
	},
	setType : function(type_id, type_name, acl_id)
	{
		this.statuses = '';
		
		GO.tickets.statusesStore.baseParams.type_id=type_id;		
		
		this.centerPanel.store.baseParams.type_id = type_id;

		GO.checker.params.tickets_type_id = type_id;

		this.type_name = type_name;

		GO.tickets.statusesStore.load();
		this.centerPanel.store.load();
	}
});

GO.mainLayout.onReady(function(){

	//GO.checker is not available in some screens like accept invitation from calendar
	if(GO.checker){
		//create notify icon
		var notificationArea = Ext.get('notification-area');
		if(notificationArea)
		{
			GO.tickets.notificationEl = notificationArea.createChild({
				id: 'ti-notify',
				tag:'a',
				href:'#',
				style:'display:none'
			});
			GO.tickets.notificationEl.on('click', function(){
				GO.mainLayout.openModule('tickets');
			}, this);
		}

		GO.checker.on('check', function(checker, data){
			var tp = GO.mainLayout.getModulePanel('tickets');

			if(data.tickets.unseen_visible!=GO.tickets.totalUnseenVisible && data.tickets.unseen_visible>0)
			{
				if(tp && (typeof(data.tickets.unseen_visible) != 'undefined'))
				{
					tp.refresh();
				}
			}

			if(data.tickets.unseen!=GO.tickets.totalUnseen && data.tickets.unseen>0)
			{
				data.alarm=true;
				data.reminderText+='<p>'+GO.tickets.lang.youHaveNewTickets.replace('{new}', data.tickets.unseen)+'</p>';

				if(!tp || !tp.isVisible())
					GO.tickets.notificationEl.setDisplayed(true);
			}

			GO.tickets.notificationEl.update(data.tickets.unseen);			
			GO.tickets.totalUnseen=data.tickets.unseen;			
		});
	}
});

	

GO.tickets.showTicketDialog = function(ticket_id, config){

	if(!GO.tickets.ticketDialog)
		GO.tickets.ticketDialog = new GO.tickets.TicketDialog();

	GO.tickets.ticketDialog.show(ticket_id, config);
}

GO.moduleManager.addModule('tickets', GO.tickets.MainPanel, 
{
	title : GO.tickets.lang.tickets,
	iconCls : 'go-tab-icon-tickets'
});

/*
 * If your module has a linkable item, you should add a link handler like this. 
 * The index (no. 1 in this case) should be a unique identifier of your item.
 * See classes/base/links.class.inc for an overview.
 * 
 * Basically this function opens a project window when a user clicks on it from a 
 * panel with links. 
 */
GO.linkHandlers[20]=function(ticket_id)
{
	if(!GO.tickets.linkWindow){
		var ticketPanel = new GO.tickets.TicketPanel({
			id:'ti-ticket-panel-link',
			mf_id:'ti-message-form-link',
			mp_id:'ti-message-panel-link'
		});
		GO.tickets.linkWindow = new GO.LinkViewWindow({
			title: GO.tickets.lang.ticket,
			items: ticketPanel,
			ticketPanel: ticketPanel,
			closeAction:'hide'
		});		
	}

        Ext.Ajax.request({
                url: GO.settings.modules.tickets.url+'json.php',
                params: {
                        ticket_id: ticket_id,
                        task: 'get_ticket'
                },
                scope: this,
                callback: function(options, success, response)
                {
                        var data = Ext.decode(response.responseText);
                        if(!data.success)
                        {
                                Ext.Msg.alert(GO.lang['strError'], GO.tickets.lang.ticketDeleted)
                        }else{
                                GO.tickets.linkWindow.ticketPanel.load(ticket_id);
                                GO.tickets.linkWindow.show();
                        }
                }
        });
}

GO.tickets.showTicket=GO.linkHandlers[20].createSequence(function(){
	GO.mainLayout.openModule('tickets');
});

GO.linkPreviewPanels[20]=function(config){
	config = config || {};
	return new GO.tickets.TicketPanel(config);
}


/* {LINKHANDLERS} */

GO.newMenuItems.push({
	text: GO.tickets.lang.ticket,
	iconCls: 'go-link-icon-20',
	handler:function(item, e)
	{
		if(!GO.tickets.ticketDialog)
			GO.tickets.ticketDialog = new GO.tickets.TicketDialog();
			
		GO.tickets.ticketDialog.formPanel.form.setValues({
			type_id: ""
		});
		GO.tickets.showTicketDialog(0, {
			link_config: item.parentMenu.link_config
		});
	}
});
/* {NEWMENUITEMS} */


