/**
 * Copyright Intermesh
 *
 * This file is part of Group-Office. You should have received a copy of the
 * Group-Office license along with Group-Office. See the file /LICENSE.TXT
 *
 * If you have questions write an e-mail to info@intermesh.nl
 *
 * @version $Id: MessageForm.js 11062 2011-07-15 13:32:29Z wsmits $
 * @copyright Copyright Intermesh
 * @author Michiel Schmidt <michiel@intermesh.nl>
 * @author Merijn Schering <mschering@intermesh.nl>
 */

GO.tickets.MessageForm = function(config)
	{
		if(!config)
		{
			config={};
		}
	
		config.width=500;
		//config.minHeight=config.height=GO.settings.modules.tickets.write_permission ?  200 : 180;
		config.autoHeight=true;
		//config.height=400;
		config.minWidth=300;
		//config.layout='fit';
		config.modal=true;
		config.border=false;
		config.plain=true;
		config.split=true;
		config.resizable=true;
		config.closeAction='hide';
		//config.buttonAlign='right';
		config.title=GO.tickets.lang.newMessage;

		//var height = GO.settings.modules.tickets.write_permission ? '-55' : '-30'
	
		var content = this.content = new Ext.form.TextArea({
			name:'content',
			hideLabel: true,			
			anchor:'100%',
			height:100
		});

		config.focus=function(){
			content.focus();
		}

		this.selectTemplate = new GO.form.ComboBoxReset({
			fieldLabel:GO.tickets.lang.select_template,
			hiddenName:'template_id',
			valueField:'id',
			displayField:'name',
			anchor:'100%',
			store:GO.tickets.templatesStore,
			mode:'local',
			triggerAction:'all',
			//disabled:true,
			editable:false,
			selectOnFocus:true,
			forceSelection:true
		});
		this.selectStatus = new GO.tickets.SelectStatus({
			fieldLabel:GO.tickets.lang.changeTicketStatus,
			disabled:true,
			anchor:'100%'
		});
		/*this.external = new Ext.form.Checkbox({
			name:'external',
			hideLabel:true,
			flex:1,
			boxLabel:GO.tickets.lang.notifyContact,
			disabled:true,
			checked:false
		});*/
		this.btnSaveAsNote = new Ext.Button({
			text:GO.tickets.lang.saveAsNote,
			flex:1,
			handler: function(){
				this.submitForm();
			},
			scope: this
		});

		this.btnSaveAsMessage = new Ext.Button({
			text:GO.tickets.lang.sendMessage,
			flex:1,
			handler: function(){
				this.submitForm(true);
			},
			scope: this
		});

                this.btnUpdateMessage = new Ext.Button({
			text: GO.lang.cmdSave,
			flex:1,
			handler: function(){
                                this.submitForm();
			},
                        hidden:true,
			scope: this
		});

		this.btnCancel = new Ext.Button({
			flex:1,
			text:GO.lang['cmdCancel'],
			minWidth:75,
			handler: function(){
				this.hide();
			},
			scope: this
		});

		var formPanelItems = [this.content];

		var formPanelBaseParams={};

		if(GO.settings.modules.tickets.write_permission){
			formPanelItems.push(this.selectTemplate);
                        formPanelItems.push(this.selectStatus);
		}else
		{
			formPanelBaseParams.external=true;
		}				

		
		if(GO.settings.modules.tickets.write_permission){
			formPanelItems.push({
				xtype:'compositefield',
				itemId:'rate_fields',
				fieldLabel:GO.tickets.lang.rateHours,
				items:[
					{
						flex:2,
						xtype:'comboboxreset',
						mode:'local',
						triggerAction:'all',
						store:GO.tickets.ratesStore,
						emptyText:GO.tickets.lang.noRate,
						hiddenName:'rate_id',
						valueField:'id',
						displayField:'name',
						listeners:{
							clear:this.syncNumber,
							select:this.syncNumber,
							scope:this
						}
					},{
						flex:1,
						xtype:'numberfield',
						name:'rate_hours',
						value:0,
						disabled:true
					}
				]
			},{
				anchor:'100%',
				xtype:'datefield',
				name:'date',
				fieldLabel:GO.lang.strDate,
				value:new Date().format(GO.settings.date_format),
				disabled:true
			});
		}

		this.uploadFile = new GO.form.UploadFile({
				inputName : 'attachments',
				addText : GO.tickets.lang.attachFiles
			});

		formPanelItems.push(this.uploadFile);


		this.formPanel = new Ext.form.FormPanel({
			cls:'go-form-panel',
			fileUpload:true,
			labelWidth:150,
			autoHeight:true,
			waitMsgTarget:true,
			items:formPanelItems,
			baseParams:formPanelBaseParams
		});

		/*
	this.selectTemplate.on('select', function(combo, record)
	{				
		this.setContent(record.data.id);
	}, this);
   
		this.external.on('check', function(cb, checked)
		{
			this.selectTemplate.setDisabled(!checked);
		},this); */
	
		config.items=[this.formPanel];
		config.buttons=[this.btnSaveAsMessage, this.btnSaveAsNote, this.btnUpdateMessage, this.btnCancel];
		
		GO.tickets.MessageForm.superclass.constructor.call(this, config);
			
		this.addEvents({
			'save' : true
		});
			
	}
Ext.extend(GO.tickets.MessageForm, GO.Window,{
	
	message_id : 0,
	status_id: 0,	
	status_name:'',
	has_status: 0,
	ticket_id:0,

	syncNumber : function(){
		if(this.rendered && GO.settings.modules.tickets.write_permission){
			var enabled = this.formPanel.form.findField('rate_id').getValue()>0;
			this.formPanel.form.findField('rate_hours').setDisabled(!enabled);
			enabled ? this.dateEl.show() : this.dateEl.hide();

			this.formPanel.form.findField('date').setDisabled(!enabled);

			this.syncShadow();
		}
	},

	setMessageId : function(id)
	{
		this.message_id = id;

		if(this.message_id)
		{
			this.setTitle(GO.tickets.lang.editMessage);

			this.btnSaveAsNote.hide();
			this.btnSaveAsMessage.hide()
			this.btnUpdateMessage.show();

			this.loadMessage();
		}else
		{
			this.setTitle(GO.tickets.lang.newMessage);

			this.btnSaveAsNote.setVisible(GO.settings.modules.tickets.write_permission);
			this.btnSaveAsMessage.show()
			this.btnUpdateMessage.hide();

			this.reset();
		}
	},
   
	reset : function() 
	{
		if(this.rendered)
				this.formPanel.form.reset();

		if(GO.tickets.templatesStore.data.length >0)
		{
			this.selectTemplate.setValue(GO.tickets.templatesStore.data.items[0].id);
			this.selectTemplate.setRemoteText(GO.tickets.templatesStore.data.items[0].data.name);
		}

		this.selectTemplate.enable();

		this.message_id = 0;
		this.has_status = 0;

		this.setTitle(GO.tickets.lang.newMessage);

		this.selectStatus.setValue(this.status_id);
		this.selectStatus.setRemoteText(this.status_name);
		this.selectStatus.enable();
		
		this.syncNumber();

		this.uploadFile.clearQueue();
	},
	prepareForm : function(ticket_id, status_id, status_name)
	{		
		this.status_id = status_id;
		this.ticket_id = ticket_id;
		this.status_name = status_name;
	},
	loadMessage : function()
	{
		this.formPanel.form.load({
			url: GO.settings.modules.tickets.url+'json.php',
			params:{
				task:'get_message',
				message_id:this.message_id
			},
			waitMsg:GO.lang['waitMsgLoad'],
			success: function(form, action) 
			{
				this.selectTemplate.disable();
				this.selectStatus.disable();
				this.has_status = (action.result.data.has_status) ? 1 : 0;
				this.syncNumber();
				
				GO.tickets.MessageForm.superclass.show.call(this);
			},
			failure:function(form, action)
			{
				Ext.Msg.alert(GO.lang['strError'], action.result.feedback)
			},
			scope: this
		});
	},
	show : function (message_id){		
		if(GO.settings.modules.tickets.write_permission){
			if(!GO.tickets.ratesStore.loaded){
				GO.tickets.ratesStore.load({
					callback:function(){
						this.show(message_id);
					},
					scope:this
				});
				return false;
			}
		}
		
		GO.tickets.MessageForm.superclass.show.call(this);
               

		if(GO.settings.modules.tickets.write_permission){

			if(!this.rateFieldsEl){
				this.rateFieldsEl = this.formPanel.form.findField('rate_fields').getEl().up('.x-form-item');
				this.rateFieldsEl.setVisibilityMode(Ext.Element.DISPLAY);
			}

			if(!this.dateEl){
				this.dateEl = this.formPanel.form.findField('date').getEl().up('.x-form-item');
				this.dateEl.setVisibilityMode(Ext.Element.DISPLAY);				
			}
			this.dateEl.hide();
			this.formPanel.form.findField('date').setDisabled(true);
			
			if(!GO.tickets.ratesStore.getCount()){
				if(this.rateFieldsEl.isVisible()){
					this.rateFieldsEl.hide();					
				}
			}else
			{
				if(!this.rateFieldsEl.isVisible()){
					this.rateFieldsEl.show();
					this.formPanel.form.findField('rate_fields').doLayout();					
				}
			}

			//this.syncShadow();
		}

		this.setMessageId(message_id);
		
	},
	
	submitForm : function(external)
	{
		var params =  {
				task:'save_message',
				message_id:this.message_id,
				has_status:this.has_status,
				ticket_id:this.ticket_id
			};

		if(external){
			params.external='on';
		}
		
		this.formPanel.form.submit(
		{
			url:GO.settings.modules.tickets.url+'action.php',
			params:params,
			waitMsg:GO.lang['waitMsgSave'],
			success:function(form, action)
			{
				//increase the totalUnseen value otherwise the system will think there's
				//a new ticket
				if(action.result.changed_to_unseen){
					GO.tickets.totalUnseen++;					
				}
				this.fireEvent('save');				
				this.reset();
				this.hide();
        
        // Let the reminder check for active reminders
        GO.checker.checkForReminders();

			},
			failure: function(form, action) 
			{
				var error = '';
				if(action.failureType=='client')
				{
					error = GO.lang['strErrorsInForm'];
				}
				else
				{
					error = action.result.feedback;
				}
				Ext.MessageBox.alert(GO.lang['strError'], error);
			},
			scope:this
		});
	}
});