/**
 * Copyright Intermesh
 *
 * This file is part of Group-Office. You should have received a copy of the
 * Group-Office license along with Group-Office. See the file /LICENSE.TXT
 *
 * If you have questions write an e-mail to info@intermesh.nl
 *
 * @version $Id: RatesGrid.js 7712 2010-04-20 08:40:11Z mschering $
 * @copyright Copyright Intermesh
 * @author Merijn Schering <mschering@intermesh.nl>
 */



GO.tickets.RatesGrid = function(config){
	if(!config)
	{
		config = {};
	}

	config.layout='fit';
	config.autoScroll=true;
	config.split=true;

	config.title=GO.tickets.lang.rates;

	config.store=GO.tickets.ratesStore;

	config.bbar = new Ext.PagingToolbar({
		cls: 'go-paging-tb',
		store: config.store,
		pageSize: parseInt(GO.settings['max_rows_list']),
		displayInfo: true,
		displayMsg: GO.lang['displayingItems'],
		emptyMsg: GO.lang['strNoItems']
	});

	var columnModel =  new Ext.grid.ColumnModel({
		defaults:{
			sortable:true
		},
		columns:[	{
			header: GO.lang.strName,
			dataIndex: 'name',
			editor: new Ext.form.TextField({
				allowBlank: false
			})
		},{
			header: GO.tickets.lang.amount,
			dataIndex: 'amount',
			editor: new GO.form.NumberField({
				allowBlank: false
			}),
			align:'right'
		}]
	});

	config.cm=columnModel;
	config.view=new Ext.grid.GridView({
		autoFill: true,
		forceFit: true,
		emptyText: GO.lang['strNoItems']
	});
	config.sm=new Ext.grid.RowSelectionModel();
	config.loadMask=true;

	config.clicksToEdit=1;




	var Rate = Ext.data.Record.create([
	{
		name: 'id',
		type: 'int'
	},
	{
		name: 'name',
		type:'string'
	},{
		name: 'amount',
		type: 'string'
	}
	]);


	config.tbar=[{
		iconCls: 'btn-add',
		text: GO.lang['cmdAdd'],
		cls: 'x-btn-text-icon',
		handler: function(){
			var e = new Rate({
				id: '0',
				name:'',
				amount: GO.util.numberFormat("0")				
			});
			this.stopEditing();
			this.store.insert(0, e);
			this.startEditing(0, 0);
		},
		scope: this
	},{
		iconCls: 'btn-delete',
		text: GO.lang['cmdDelete'],
		cls: 'x-btn-text-icon',
		handler: function(){
			var selectedRows = this.selModel.getSelections();
			for(var i=0;i<selectedRows.length;i++)
			{
				selectedRows[i].commit();
				this.store.remove(selectedRows[i]);
				this.deletedRecords=true;
			}
		},
		scope: this
	}];

	config.listeners={
		render:function(){
			if(GO.settings.modules.tickets.write_permission && !GO.tickets.ratesStore.loaded)
				GO.tickets.ratesStore.load();
		},
		scope:this
	}

	GO.tickets.RatesGrid.superclass.constructor.call(this, config);

};
Ext.extend(GO.tickets.RatesGrid, Ext.grid.EditorGridPanel,{
	
	getGridData : function(){

		var data = {};

		for (var i = 0; i < this.store.data.items.length;  i++)
		{
			var r = this.store.data.items[i].data;

			data[i]={};

			for(var key in r)
			{
				data[i][key]=r[key];
			}
		}

		return data;
	},
	setIds : function(ids)
	{
		for(var index in ids)
		{
			if(index!="remove")
			{
				this.store.getAt(index).set('id', ids[index]);
			}
		}
	},
	save : function(maskEl){
		if(this.store.getModifiedRecords().length>0 || this.deletedRecords){
			maskEl.mask(GO.lang.waitMsgSave);
			Ext.Ajax.request({
				url:GO.settings.modules.tickets.url+'action.php',
				params:{
					task:'rates',
					rates:Ext.encode(this.getGridData())
				},
				callback:function(options, success, response){
					this.store.commitChanges();

					var result = Ext.decode(response.responseText);

					if(result.new_rates)
					{
						this.setIds(result.new_rates);
					}

					this.deletedRecords=false;

					maskEl.unmask();
				},
				scope:this
			});
		}
	}
});
