/**
 * Copyright Intermesh
 *
 * This file is part of Group-Office. You should have received a copy of the
 * Group-Office license along with Group-Office. See the file /LICENSE.TXT
 *
 * If you have questions write an e-mail to info@intermesh.nl
 *
 * @version $Id: SettingsDialog.js 9483 2010-11-11 10:14:43Z wvbeusekom $
 * @copyright Copyright Intermesh
 * @author Michiel Schmidt <michiel@intermesh.nl>
 * @author Merijn Schering <mschering@intermesh.nl>
 */

GO.tickets.SettingsDialog = function(config){
	
	if(!config)
	{
		config={};
	}
		
	this.typesGrid = new GO.tickets.SettingsTypesGrid();
	this.statusesGrid = new GO.tickets.SettingsStatusesGrid();
	this.templatesGrid = new GO.tickets.SettingsTemplatesGrid();
	this.optionsPanel = new GO.tickets.SettingsOptionsPanel();
	this.ratesGrid = new GO.tickets.RatesGrid();
		
	var items = [this.typesGrid, this.statusesGrid, this.templatesGrid, this.optionsPanel, this.ratesGrid];
	
	this.tabPanel = new Ext.TabPanel({
		activeTab:0,
		border:false,
		items:items
	})

	config.layout='fit';
	config.maximizable=true;
	config.modal=false;
	config.resizable=false;
	config.width=600;
	config.height=600;
	config.closeAction='hide';
	config.title= GO.lang.cmdSettings;					
	config.items=this.tabPanel;
	config.buttons=[{
		text: GO.lang['cmdOk'],
		handler: function()
		{
			this.optionsPanel.submitForm();                       

			if(this.statusesGrid.changed)
			{
				this.fireEvent('update_statuses');
				this.statusesGrid.changed=false;
			}
			if(this.templatesGrid.changed)
			{
				this.fireEvent('update_templates');
				this.templatesGrid.changed=false;
			}
			
			this.ratesGrid.save(this.getEl());

			this.hide();
		},
		scope: this
	},{
		text: GO.lang['cmdClose'],
		handler: function()
		{
			if(this.statusesGrid.changed)
			{
				this.fireEvent('update_statuses');
				this.statusesGrid.changed=false;
			}
			if(this.templatesGrid.changed)
			{
				this.fireEvent('update_templates');
				this.templatesGrid.changed=false;
			}

			this.ratesGrid.save(this.getEl());
			
			this.hide();
		},
		scope:this
	}];
	
	this.typesGrid.on('show', this.syncButtons,		this);
	this.statusesGrid.on('show', this.syncButtons,	this);
	this.templatesGrid.on('show', this.syncButtons,	this);
	this.optionsPanel.on('show', this.syncButtons,	this);

	this.typesGrid.on('update_types', function()
	{
		GO.tickets.readableTypesStore.baseParams.reload = true;
		GO.tickets.readableTypesStore.load({
			callback : function()
			{
				GO.tickets.mainPanel.refresh();
			},
			scope:this
		});
	}, this);
	
	GO.tickets.SettingsDialog.superclass.constructor.call(this, config);
	
	this.addEvents({
		'update_statuses' : true
	});
	this.addEvents({
		'update_templates' : true
	});
	
}

Ext.extend(GO.tickets.SettingsDialog, Ext.Window,{

	syncButtons : function()
	{
		this.buttons[0].setVisible(this.optionsPanel.isVisible());
		//this.buttons[1].setVisible(this.optionsPanel.isVisible());
	},	
	show : function(){
		if(!this.typesGrid.store.loaded)
		{
			this.typesGrid.store.load();
		}
		GO.tickets.SettingsDialog.superclass.show.call(this);
	}
});