/**
 * Copyright Intermesh
 *
 * This file is part of Group-Office. You should have received a copy of the
 * Group-Office license along with Group-Office. See the file /LICENSE.TXT
 *
 * If you have questions write an e-mail to info@intermesh.nl
 *
 * @version $Id: SettingsOptionsPanel.js 9483 2010-11-11 10:14:43Z wvbeusekom $
 * @copyright Copyright Intermesh
 * @author Michiel Schmidt <michiel@intermesh.nl>
 * @author Merijn Schering <mschering@intermesh.nl>
 */

GO.tickets.SettingsOptionsPanel = function(config){

	if(!config)
	{
		config = {};
	}

	this.buildForm();

	config.layout='fit';
	config.title=GO.tickets.lang.options;
	config.modal=false;
	config.width=400;
	config.height=400;
	config.resizable=false;
	config.closeAction='hide';
	config.items=this.formPanel;
		
	GO.tickets.SettingsOptionsPanel.superclass.constructor.call(this,config);
	
	this.addEvents({
		'save' : true
	});
}

Ext.extend(GO.tickets.SettingsOptionsPanel, Ext.Panel, {
	
	show : function (record)
	{		
		if(!this.rendered)
			this.render(Ext.getBody());
			
		this.formPanel.load(
		{			
			success:function(form, action)
			{
				GO.tickets.SettingsOptionsPanel.superclass.show.call(this);
				
			},
			failure:function(form, action)
			{
				Ext.Msg.alert(GO.lang['strError'], action.result.feedback)
			},
			scope: this
		});
		GO.tickets.SettingsOptionsPanel.superclass.show.call(this);
	},
	buildForm : function () 
	{
		this.formPanel = new Ext.FormPanel({
			cls:'go-form-panel',
			//bodyStyle:'padding:5px',
			anchor:'100% 100%',
			fileUpload: true,
			defaults:{
				anchor:'98%'
			},
			url:GO.settings.modules.tickets.url+'json.php',
			baseParams:{
				task:'get_settings'
			},
			border: false,
			defaultType:'textfield',
			autoHeight:true,
			waitMsgTarget:true,
			labelWidth:100,
			items: [
			{
				fieldLabel: GO.lang['strName'],
				name: 'from_name',
				allowBlank:false
			},{
				fieldLabel: GO.lang['strEmail'],
				name: 'from_email',
				allowBlank:false
			},{
				fieldLabel: GO.lang['strSubject'],
				name: 'subject',
				allowBlank:false
			},{
				fieldLabel: GO.tickets.lang.url,
				name: 'extern_url',
				allowBlank:false
			},this.languageCombo = new Ext.form.ComboBox({
					fieldLabel: GO.users.lang['cmdFormLabelLanguage'],
					name: 'language_id',
					store:  new Ext.data.SimpleStore({
							fields: ['id', 'language'],
							data : GO.Languages
						}),
					displayField:'language',
					valueField: 'id',
					hiddenName:'language',
					mode:'local',
					triggerAction:'all',
					editable: false,
					selectOnFocus:true,
					forceSelection: true,
					value: GO.settings.language
			}),{
				xtype: 'fileuploadfield',
				id: 'form-file',
				emptyText: GO.lang.strSelectFile,
				fieldLabel: GO.tickets.lang.logo,
				name: 'logo',
				buttonText: GO.lang.browse
			},{
				xtype:'textarea',
				name:'customer_message',
				fieldLabel:GO.tickets.lang.customer_message,
				height:100,
				allowBlank:false
			},{
				xtype:'textarea',
				name:'response_message',
				fieldLabel:GO.tickets.lang.response_message,
				height:100,
				allowBlank:false
			},new Ext.form.FieldSet({
				border: false,
				hideLabel: true,
				labelWidth: 400,
				bodyStyle:'padding:0px',
				style:'padding:0px',
				items:
					new Ext.form.NumberField({
						name: 'expire_days',
						fieldLabel: GO.tickets.lang.expireDays,
						width: 50,
						allowNegative: false,
						allowDecimals: false,
						decimalPrecision: 0
					})
			}),{
				xtype:'checkbox',
				name:'notify_contact',
				boxLabel:GO.tickets.lang.notifyContactCheck,
				hideLabel:true
			}]
		});
	},
	submitForm : function(){
		if(this.formPanel.getForm().isValid())
		{
			this.formPanel.getForm().submit({
				url:GO.settings.modules.tickets.url+'action.php',
				params: {
					task:'save_settings'
				},
				waitMsg: 'Uploading your photo...',
				success: function(form, action)
				{
                                        GO.tickets.notify_contact = (form.findField('notify_contact').checked) ? '1' : '0';
					this.fireEvent('save');
				},
				failure: function(form, action)
				{
					var error = '';
					if(action.failureType=='client')
					{
						error = GO.lang['strErrorsInForm'];
					}
					else
					{
						error = action.result.feedback;
					}
					Ext.MessageBox.alert(GO.lang['strError'], error);
				},
				scope:this
			});
		}
	}
    
});