/**
 * Copyright Intermesh
 *
 * This file is part of Group-Office. You should have received a copy of the
 * Group-Office license along with Group-Office. See the file /LICENSE.TXT
 *
 * If you have questions write an e-mail to info@intermesh.nl
 *
 * @version $Id: SettingsTypesGrid.js 11060 2011-07-05 09:51:04Z wsmits $
 * @copyright Copyright Intermesh
 * @author Michiel Schmidt <michiel@intermesh.nl>
 * @author Merijn Schering <mschering@intermesh.nl>
 */

GO.tickets.SettingsTypesGrid = function(config){
	
	if(!config)
	{
		config = {};
	}
	
	config.title=GO.tickets.lang.types;
	config.layout='fit';
	config.autoScroll=true;
	config.loadMask=true;
	config.store = GO.tickets.writableTypesStore;
	config.paging=true;
	
	var columnModel =  new Ext.grid.ColumnModel({
		defaults:{
			sortable:true
		},
		columns:[
		{
			header: GO.lang.strName, 
			dataIndex: 'name',
      renderer:function(value, p, record){
        if(!GO.util.empty(record.data.description))
        {
          p.attr = 'ext:qtip="'+Ext.util.Format.htmlEncode(record.data.description)+'"';
        }
        return value;
      }
		},{
			header: GO.lang.strOwner, 
			dataIndex: 'user_name'
		}
	]
	});
	
	config.cm=columnModel;
	
	config.view=new Ext.grid.GridView({
		autoFill: true,
		forceFit: true
	}),
	config.sm=new Ext.grid.RowSelectionModel();
	
	this.typeDialog = new GO.tickets.TypeDialog();
	    			    		
	this.typeDialog.on('save', function()
	{
		this.store.reload();
        this.fireEvent('update_types', this);
	}, this);

	if(GO.settings.has_admin_permission)
	{
		config.tbar=[{
			iconCls: 'btn-add',							
			text: GO.lang['cmdAdd'],
			cls: 'x-btn-text-icon',
			handler: function()
			{				
	    		this.typeDialog.show();
			},
			scope: this
		},{
			iconCls: 'btn-delete',
			text: GO.lang['cmdDelete'],
			cls: 'x-btn-text-icon',
			handler: function()
			{
				this.deleteSelected();
                this.fireEvent('update_types', this);
			},
			scope: this
		}];
	}
	
	GO.tickets.SettingsTypesGrid.superclass.constructor.call(this, config);
	
	this.on('rowdblclick', function(grid, rowIndex)
	{
		var record = grid.getStore().getAt(rowIndex);
		this.typeDialog.show(record.data.id);
		
	}, this);
	
};

Ext.extend(GO.tickets.SettingsTypesGrid, GO.grid.GridPanel,{
	
	afterRender : function()
	{
		GO.tickets.SettingsTypesGrid.superclass.afterRender.call(this);
		
		if(this.isVisible())
		{
			this.onGridShow();
		}
	},	
	onGridShow : function()
	{
		if(!this.store.loaded && this.rendered)
		{
			this.store.load();
		}	
	}
});