/**
 * Copyright Intermesh
 *
 * This file is part of Group-Office. You should have received a copy of the
 * Group-Office license along with Group-Office. See the file /LICENSE.TXT
 *
 * If you have questions write an e-mail to info@intermesh.nl
 *
 * @version $Id: TicketDialog.js 11062 2011-07-15 13:32:29Z wsmits $
 * @copyright Copyright Intermesh
 * @author Michiel Schmidt <michiel@intermesh.nl>
 * @author Merijn Schering <mschering@intermesh.nl>
 */

GO.tickets.TicketDialog = function(config){

	if(!config)
	{
		config={};
	}

	config.goDialogId='ticket';

	//this.customerMode=config.customerMode;
	this.buildForm();

	config.width=800;
	config.modal=true;
	//config.border=false;
	config.collapsible=true;
	config.titleCollapse=true;
	config.resizable=true;
	config.maximizable=true;
	//config.autoHeight=true;
	config.height=540;
	config.layout='fit';
	config.closeAction='beforeHide';
	config.items=this.formPanel;
	

	config.buttons=[{
		text: GO.lang['cmdOk'],
		handler: function(){
			this.submitForm(true);
		},
		scope: this
	}]

	/*if(GO.settings.modules.tickets.write_permission){
		config.buttons.push({
			text: GO.lang['cmdApply'],
			handler: function(){
				this.submitForm(false);
			},
			scope:this
		});
	}*/

	config.buttons.push({
		text: GO.lang['cmdClose'],
		handler: function(){
			this.beforeHide();
		},
		scope:this
	});

	GO.tickets.TicketDialog.superclass.constructor.call(this, config);

	this.addEvents({
		'save' : true
	});
}

Ext.extend(GO.tickets.TicketDialog, GO.Window,{

	focus : function(){
		if(this.first_name.getValue()==''){
			if(this.selectContact)
				this.selectContact.focus();
			else
				this.selectCompany.focus();
		}else
		{
			this.subject.focus();
		}
	},

	buildForm : function()
	{
		if(GO.addressbook && GO.settings.modules.tickets.write_permission){
			this.selectContact = new GO.addressbook.SelectContact ({
				name: 'contact_name',
				hiddenName:'contact_id',
				anchor: '-20',
				fieldLabel:GO.tickets.lang.contact
			});
			this.selectContact.on('select', function(combo, record)
			{
				var contact = record.json;

				var values = record.data;

				var email = '';
				if (contact.email)
					email = contact.email;
				else if (contact.email2)
					email = contact.email2;
				else if (contact.email3)
					email = contact.email3;

				values.email=email;

				var phone = '';
				if (contact.work_phone)
					phone = contact.work_phone;
				else if (contact.cellular)
					phone = contact.cellular;
				else if (contact.home_phone)
					phone = contact.home_phone;

				values.phone = phone;                                		

				if(values.company_id){
					this.formPanel.baseParams.company_id=values.company_id;

					values.company = values.company_name;
				}
                                
				this.formPanel.form.setValues(values);

			//this.formPanel.baseParams.contact_id=record.data.id;

			}, this);

		}
		if(GO.addressbook){
			this.selectCompany = new GO.addressbook.SelectCompany({
				fieldLabel:GO.lang.strCompany,
				name:'company',
				listeners:{
					scope:this,
					select:function(combo, record){
						this.formPanel.baseParams.company_id=record.data.id;
					}
				}
			});
		}else
		{
			this.selectCompany = new Ext.form.TextField({
				name:'company',
				fieldLabel:GO.lang.strCompany
			});
		}


		this.first_name = new Ext.form.TextField({
			name:'first_name',
			fieldLabel: GO.lang['strFirstName'],
			allowBlank:false
		});
		this.middle_name = new Ext.form.TextField({
			name:'middle_name',
			fieldLabel: GO.lang['strMiddleName']
		});
		this.last_name = new Ext.form.TextField({
			name:'last_name',
			fieldLabel: GO.lang['strLastName'],
			allowBlank:false
		});
		this.phone = new Ext.form.TextField({
			name:'phone',
			fieldLabel: GO.lang['strPhone'],
			maskRe:/([0-9\s]+)$/
		});
		this.email = new Ext.form.TextField({
			name:'email',
			fieldLabel:GO.lang['strEmail'],
			allowBlank:false
		});

		this.subject = new Ext.form.TextField({
			name:'subject',
			fieldLabel: GO.lang['strSubject'],
			allowBlank:false
		});
		this.selectType = new GO.form.ComboBox({
			hiddenName:'type_id',
			fieldLabel:GO.lang['strType'],
			valueField:'id',
			displayField:'name',
			store:GO.tickets.writableTypesStore,
			mode:'local',
			triggerAction:'all',
			editable:false,
			selectOnFocus:true,
			allowBlank:false,
			forceSelection:true
		});
		this.selectAgent = new GO.form.ComboBoxReset({
			hiddenName:'agent_id',
			fieldLabel:GO.tickets.lang.agent,
			emptyText:GO.tickets.lang.nobody,
			valueField:'agent_id',
			displayField:'agent_name',
			store:GO.tickets.agentsStore,
			mode:'remote',
			triggerAction:'all',
			editable:false,
			selectOnFocus:true
			//forceSelection:true
		});
		this.selectPriority = new GO.form.SelectPriority();		
		this.selectStatus = new GO.form.ComboBox({
			hiddenName:'status_id',
			fieldLabel:GO.tickets.lang.status,
			valueField:'id',
			displayField:'name_clean',
			store:GO.tickets.statusesStore,
			mode:'local',
			triggerAction:'all',
			editable:false,
			selectOnFocus:true,
			forceSelection:true
		});
		

		this.content = new Ext.form.TextArea({
			name:'content',
			hideLabel: true,
			anchor:'100%',
			height:130
		});
		this.selectTemplate = new GO.form.ComboBox({
			hiddenName:'template_id',
			fieldLabel:GO.tickets.lang.select_template,
			valueField:'id',
			displayField:'name',
			store:GO.tickets.templatesStore,
			mode:'local',
			triggerAction:'all',
			editable:false,
			selectOnFocus:true,
			forceSelection:true
		});
		this.external = new Ext.form.Checkbox({
			name:'external',
			boxLabel:GO.tickets.lang.notifyContact,
			hideLabel:true,
			checked:true
		});

		var contactItems=[];

		if(GO.addressbook && GO.settings.modules.tickets.write_permission){
			contactItems.push(this.selectContact);
		}
		contactItems.push(this.selectCompany, this.first_name, this.middle_name, this.last_name, this.phone, this.email);

		this.contactFieldset = {
			xtype:'fieldset',
			title:GO.lang['customer'],
			//autoHeight:true,
			collapsed:false,
			defaults:{
				anchor:'100%'
			},
			items:contactItems
		}

		var ticketItems = [];

		ticketItems.push(this.subject, this.selectType);
		
		if(GO.settings.modules.tickets.write_permission)
			ticketItems.push(this.selectAgent);

		ticketItems.push(this.selectPriority);

		if(GO.settings.modules.tickets.write_permission)
			ticketItems.push(this.selectStatus);

		if(GO.settings.modules.tickets.write_permission){
			ticketItems.push({
				xtype:'compositefield',
				itemId:'rate_fields',
				fieldLabel:GO.tickets.lang.rateHours,
				items:[
				{
					flex:2,
					xtype:'comboboxreset',
					mode:'local',
					triggerAction:'all',
					store:GO.tickets.ratesStore,
					emptyText:GO.tickets.lang.noRate,
					hiddenName:'rate_id',
					valueField:'id',
					displayField:'name',
					listeners:{
						clear:this.syncNumber,
						select:this.syncNumber,
						scope:this
					}
				},{
					flex:1,
					xtype:'numberfield',
					name:'rate_hours',
					value:0
				}
				]
			});
		}


		this.ticketFieldset = {
			xtype:'fieldset',
			title:GO.tickets.lang.ticket,
			//autoHeight:true,
			collapsed:false,
			defaults:{
				anchor:'100%'
			},
			items:ticketItems
		}

		var contentOptionsPanelItems = []

		if(GO.settings.modules.tickets.write_permission){
			contentOptionsPanelItems.push(this.selectTemplate,this.external);
		}

		contentOptionsPanelItems.push(this.uploadFile = new GO.form.UploadFile({
			inputName : 'attachments',
			addText : GO.tickets.lang.attachFiles
		}));

		this.contentOptionsPanel = {
			xtype:'panel',
			layout:'form',
			//autoHeight:true,
			border:false,
			defaults:{
				anchor:'100%'
			},
			items:contentOptionsPanelItems
		}

		if(GO.settings.modules.tickets.write_permission){

			this.selectLinkField = new GO.form.SelectLink();
			this.selectLinkPanel = {
				xtype:'panel',
				layout:'form',
				bodyStyle:'padding-left:10px',
				border:false,
				//autoHeight:true,
				items:[this.selectLinkField]
			}
		}

		this.contentFieldset = new Ext.form.FieldSet({
			title:GO.tickets.lang.message,
			collapsed:false,
			//autoHeight:true,
			defaults:{
				border:false
			},
			items:[{
				layout:'column',				
				defaults:{
					border:false
				},
				items:[{
					columnWidth:.5,
					layout:'form',
					items:[this.content]
				},{
					columnWidth:.5,
					bodyStyle:'padding:10px 0 0 20px',
					items:[this.contentOptionsPanel]
				}]
			}]
		});

		var bottomItems = GO.settings.modules.tickets.write_permission ? [this.contentFieldset, this.selectLinkPanel] : this.contentFieldset;

		this.panel = new Ext.Panel({
			bodyStyle:'padding:5px',			
			defaults:{
				border:false//,
				//anchor:'100%'
			},
			autoScroll:true,
			layoutConfig:{autoScroll:true},
			title:GO.tickets.lang.ticket,
			border:false,
			items:[{				
				layout:'column',
				defaults:{
					border:false
				},
				items:[{
					columnWidth:.5,
					items:[this.contactFieldset]
				},{
					columnWidth:.5,
					bodyStyle:'padding-left:10px',
					items:[this.ticketFieldset]
				}]
			},{
				items:bottomItems
			}]
		})

		var items = [this.panel];

		if(GO.customfields && GO.customfields.types["20"])
		{
			for(var i=0;i<GO.customfields.types["20"].panels.length;i++)
			{
				items.push(GO.customfields.types["20"].panels[i]);
			}
		}

		this.tabPanel = new Ext.TabPanel({
			border: false,
			activeTab: 0,
			hideLabel: true,
			deferredRender: false,
			anchor:'100% 100%',
			items:items
		});

		this.formPanel = new Ext.FormPanel({
			waitMsgTarget:true,
			fileUpload:true,
			//autoHeight:true,
			baseParams:{
				task:'get_ticket'
			},
			border:false,
			defaults:{
				border:false
			},
			items:[this.tabPanel]
		});		

		this.selectType.on('select', function(combo, record)
		{
			this.setAcl(record.data.acl_id, true);
		}, this);

		this.selectStatus.on('select', function(combo, record)
		{
			this.setStatus(record.data.id, record.data.name_clean);
		}, this);
	},
	setAcl : function(acl_id)
	{
		if(this.selectAgent.store.baseParams.acl_id != acl_id){
			this.selectAgent.store.baseParams.acl_id = acl_id;
			this.selectAgent.clearValue();
			delete this.selectAgent.lastQuery;
		}
		
	},
	syncNumber : function(){
		if(this.rendered && GO.settings.modules.tickets.write_permission){
			var enabled = this.formPanel.form.findField('rate_id').getValue()>0;
			this.formPanel.form.findField('rate_hours').setDisabled(!enabled);
		}
	},
	show : function (ticket_id, config)
	{                            
		if(GO.settings.modules.tickets.write_permission){
			if(!GO.tickets.ratesStore.loaded){
				GO.tickets.ratesStore.load({
					callback:function(){
						this.show(ticket_id, config);
					},
					scope:this
				});
				return false;
			}
		}

		if(!this.selectType.store.loaded)
		{
			this.selectType.store.load({
				callback:function(){
					this.show(ticket_id, config);
				},
				scope:this
			});
			return false;
		}
		
		config = config || {};

		if(!ticket_id)
		{
			ticket_id=0;
		}

		this.formPanel.baseParams.tmp_files = config.tmp_files ? Ext.encode(config.tmp_files) : '';

		if(!this.rendered)
		{
			this.render(Ext.getBody());
		}

	
		if(!this.selectStatus.store.loaded)
		{
			this.selectStatus.store.load();
		}	

		delete this.link_config;
		this.formPanel.form.reset();

		if(!this.selectTemplate.store.loaded)
		{
			this.selectTemplate.store.load({
				scope:this,
				callback:function(){
					if(GO.tickets.ticketCreatedforClientTemplateID)
						this.selectTemplate.setValue(GO.tickets.ticketCreatedforClientTemplateID);
				}
			});
		}else
		{
			if(GO.tickets.ticketCreatedforClientTemplateID)
				this.selectTemplate.setValue(GO.tickets.ticketCreatedforClientTemplateID);
		}	

		this.setTicketId(ticket_id);

		//this.formPanel.baseParams.contact_id=0;
		this.formPanel.baseParams.company_id=0;                

		this.external.setValue(GO.tickets.notify_contact);
                
		if(this.ticket_id > 0)
		{
			this.formPanel.form.load({
				url: GO.settings.modules.tickets.url+'json.php',
				success: function(form, action)
				{
					if(!action.result.data.contact_id)
					{
						action.result.data.contact_name = GO.tickets.lang.unknownContact;
					}

					//this.formPanel.baseParams.contact_id=action.result.data.contact_id;
					this.formPanel.baseParams.company_id=action.result.data.company_id;
                                        
					if(GO.addressbook){
						if(GO.settings.modules.tickets.write_permission)
						{
							this.selectContact.setRemoteText(action.result.data.contact_name);
						}
                                                                                                
						this.selectCompany.setRemoteText(action.result.data.company);
					}else
					{
						this.selectCompany.setValue(action.result.data.company);
					}

					this.setType(action.result.data.type_id, action.result.data.type_name);
					this.setAgent(action.result.data.agent_id, action.result.data.agent_name);
					this.setStatus(action.result.data.status_id, action.result.data.status_name);
					//this.setAcl(action.result.data.acl_id);                                       

					this.focus();
				},
				failure:function(form, action)
				{
					Ext.Msg.alert(GO.lang['strError'], action.result.feedback)
				},
				scope: this
			});
		} else{
			if(!config.type_id || (config.type_id == 0))
			{
				config.type_id = GO.tickets.defaultType.id;
				config.type_name = GO.tickets.defaultType.name;
			}

			this.setType(config.type_id, config.type_name);
			this.setAgent(GO.settings.user_id, GO.settings.name);
			this.setStatus(0, GO.tickets.lang.status_open);

			if(!GO.settings.modules.tickets.write_permission){

				config.values={
					company: GO.settings.company,
					first_name: GO.settings.first_name,
					middle_name: GO.settings.middle_name,
					last_name: GO.settings.last_name,
					email: GO.settings.email,
					phone:!GO.util.empty(GO.settings.work_phone) ? GO.settings.work_phone : GO.settings.home_phone
				};


			}

			if(config.values)
			{
				// Ticket creation from within email module
				//this.formPanel.baseParams.contact_id = config.values.sender_contact_id;
				if(config.values.sender_contact_id){
					config.values.contact_id=config.values.sender_contact_id;
				}
				if(!config.values.sender_contact_id && config.values.from)
				{
					var names = config.values.from.split(' ');
					var first_name = names[0];
					var last_name = names[1];
					if(names[2])
					{
						last_name += ' ' +names[2];
					}

					config.values.first_name = first_name;
					config.values.last_name = last_name;
					config.values.email = config.values.sender;
					config.values.contact_name = GO.tickets.lang.unknownContact;
				}

				this.formPanel.form.setValues(config.values);

				if(config.values.contact_name)
					this.selectContact.setRemoteText(config.values.contact_name);

				if(config.values.company_name){
					this.selectCompany.setRemoteText(config.values.company_name);
				}
			}

			if(config.link_config)
			{
				this.link_config=config.link_config;
				if(config.link_config.type_id)
				{
					this.selectLinkField.setValue(config.link_config.type_id);
					this.selectLinkField.setRemoteText(config.link_config.text);

					// Ticket creation from within addressbook module
					if(config.link_config.type == 2)
					{
						//this.formPanel.baseParams.contact_id = config.link_config.id;
						this.loadContact(config.link_config.id);
					}else if(config.link_config.type == 3){
						this.loadCompany(config.link_config.id);
					}

					// Ticket creation from within billing module
					if(config.link_config.type == 7)
					{
						Ext.Ajax.request({
							url: GO.settings.modules.billing.url+'json.php',
							params: {
								order_id: config.link_config.id,
								task: 'order'
							},
							scope: this,
							callback: function(options, success, response)
							{
								var data = Ext.decode(response.responseText);

								if (!data.success)
								{
									Ext.Msg.alert(GO.lang['strError'], data.feedback)
								}else
								{
									this.formPanel.baseParams.contact_id = data.data.contact_id;
									if(data.data.contact_id == 0)
									{
										var contact_name = (data.data.customer_contact_name) ? data.data.customer_contact_name : data.data.customer_name;

										this.first_name.setValue(contact_name)
										this.last_name.setValue(GO.tickets.lang.company);

										this.email.setValue(data.data.customer_email);
										this.selectContact.setRemoteText(GO.tickets.lang.unknownContact);

									}else
									{
										this.loadContact(data.data.contact_id);

										this.subject.setValue(data.data.order_id);
									}
								}
							}
						});
					}
				}
			}
		}	

		GO.tickets.TicketDialog.superclass.show.call(this);

		if(GO.settings.modules.tickets.write_permission){
			var rateFieldsEl = this.formPanel.form.findField('rate_fields').getEl().up('.x-form-item');
			rateFieldsEl.setVisibilityMode(Ext.Element.DISPLAY);

			if(!GO.tickets.ratesStore.getCount()){
				if(rateFieldsEl.isVisible()){
					rateFieldsEl.hide();
				}
			}else
			{
				if(!rateFieldsEl.isVisible()){
					rateFieldsEl.show();
					this.formPanel.form.findField('rate_fields').doLayout();
				}
			}
		}


	},
	loadContact : function(contact_id)
	{
		Ext.Ajax.request({
			url: GO.settings.modules.addressbook.url+'json.php',
			params: {
				contact_id: contact_id,
				task: 'load_contact'
			},
			scope: this,
			callback: function(options, success, response)
			{
				var data = Ext.decode(response.responseText);

				if (!data.success)
				{
					Ext.Msg.alert(GO.lang['strError'], data.feedback)
				}else
				{
					var contact = data.data;

					this.first_name.setValue(contact.first_name);
					this.last_name.setValue(contact.last_name);
					this.selectContact.setValue(contact_id);
					this.selectContact.setRemoteText(contact.full_name);

					this.selectCompany.setValue(contact.company_id);
					this.selectCompany.setRemoteText(contact.company_name);

					var email = '';
					if (contact.email)
						email = contact.email;
					else if (contact.email2)
						email = contact.email2;
					else if (contact.email3)
						email = contact.email3;

					this.email.setValue(email);

					var phone = '';
					if (contact.work_phone)
						phone = contact.work_phone;
					else if (contact.cellular)
						phone = contact.cellular;
					else if (contact.home_phone)
						phone = contact.home_phone;

					this.phone.setValue(phone);
				}
			}
		});
	},

	loadCompany: function(company_id)
	{
		Ext.Ajax.request({
			url: GO.settings.modules.addressbook.url+'json.php',
			params: {
				company_id: company_id,
				task: 'load_company'
			},
			scope: this,
			callback: function(options, success, response)
			{
				var data = Ext.decode(response.responseText);

				if (!data.success)
				{
					Ext.Msg.alert(GO.lang['strError'], data.feedback)
				}else
				{
					var company = data.data;

					this.selectCompany.setValue(company.id);
					this.selectCompany.setRemoteText(company.name);
					this.email.setValue(company.email);
					this.phone.setValue(company.phone);
				}
			}
		});
	},


	setTicketId : function(ticket_id)
	{
		this.formPanel.form.baseParams['ticket_id']=ticket_id;
		this.ticket_id=ticket_id;

		if (this.ticket_id == 0)
		{
			this.setTitle(GO.tickets.lang.createTicket);
			this.contentFieldset.show();
			this.content.allowBlank=false;

			//this.setHeight(540);
		}else{
			this.setTitle(GO.tickets.lang.editTicket);
			this.contentFieldset.hide();
			this.content.allowBlank=true;

			this.content.reset();
			//this.setHeight(320);
		}
		if(this.selectLinkField)
			this.selectLinkField.container.up('div.x-form-item').setDisplayed(ticket_id==0);
	},
	setType : function(type_id, type_name)
	{
		this.selectType.setValue(type_id);
		this.selectType.setRemoteText(type_name);

		var typeRecord = this.selectType.store.getById(type_id);
		if(typeRecord)
			this.setAcl(typeRecord.get('acl_id'));
	},
	setStatus : function(status_id, status_name)
	{
		this.selectStatus.setValue(status_id);
		this.selectStatus.setRemoteText(status_name);
	},
	setAgent : function(agent_id, agent_name)
	{
		this.selectAgent.setValue(agent_id);
		this.selectAgent.setRemoteText(agent_name);
	},
	submitForm : function(hide)
	{
		this.formPanel.form.submit(
		{
			url:GO.settings.modules.tickets.url+'action.php',
			params: {
				task : 'save_ticket'
			},
			waitMsg:GO.lang['waitMsgSave'],
			success:function(form, action)
			{
        // Let the reminder check for active reminders
        GO.checker.checkForReminders();

				if(action.result.id)
				{
					this.setTicketId(action.result.id);
				}

				if(hide)
				{
					this.beforeHide();
				}                              
                                
				if(action.result.changed_to_unseen){
					GO.tickets.totalUnseen++;
				}

				var refresh = (action.result.refresh) ? true : false;
				this.fireEvent('save', this, this.ticket_id, refresh);

				if(this.link_config && this.link_config.callback)
				{
					this.link_config.callback.call(this);
				}

				if(action.result.feedback){
					Ext.MessageBox.alert(GO.lang.thankyou, Ext.util.Format.htmlDecode(action.result.feedback));
				}
			},
			failure: function(form, action)
			{
				if(action.failureType=='client')
				{
					Ext.MessageBox.alert(GO.lang['strError'], GO.lang['strErrorsInForm']);
				} else {
					Ext.MessageBox.alert(GO.lang['strError'], action.result.feedback);
				}
			},
			scope:this
		});
	},
        
	beforeHide : function()
	{
		this.uploadFile.clearQueue();

		this.hide();
	}

});