/**
 * Copyright Intermesh
 *
 * This file is part of Group-Office. You should have received a copy of the
 * Group-Office license along with Group-Office. See the file /LICENSE.TXT
 *
 * If you have questions write an e-mail to info@intermesh.nl
 *
 * @version $Id: TicketPanel.js 10838 2011-05-25 09:29:21Z mschering $
 * @copyright Copyright Intermesh
 * @author Michiel Schmidt <michiel@intermesh.nl>
 * @author Merijn Schering <mschering@intermesh.nl>
 */

GO.tickets.TicketPanel = Ext.extend(GO.DisplayPanel,{

	cls :'ti-message-panel',

	link_type : 20,

	loadParams : {
		task: 'ticket_with_items'
	},

	idParam : 'ticket_id',

	loadUrl : GO.settings.modules.tickets.url+'json.php',

	is_claimed: false,
	
	is_claimed_by_user : 0,

	status_id: 0,

	user_id:0,

	editGoDialogId : 'ticket',

	editHandler : function(){
		GO.tickets.showTicketDialog(this.link_id);		
	},
	initComponent : function(){
		this.template ='';

		this.messageForm = new GO.tickets.MessageForm();
		this.messageForm.on('save', function(){
			this.reload();
			if(GO.tickets.ticketsGrid.store)
				GO.tickets.ticketsGrid.store.reload();
		}, this);


		this.buttons = [this.newMessageButton = new Ext.Button({
			disabled:true,
			text:GO.tickets.lang.newMessage,
			handler:function(){
				this.messageForm.show(0);
			},
			scope:this
		})]


		this.store  = new GO.data.JsonStore({
			url: GO.settings.modules.tickets.url+'json.php',
			baseParams:{
				task:'ticket_with_items',
				hiddenSections:''
			},
			root:'data',
			totalProperty:'total',
			fields:[
			'id',
			'agent_id',
			'write_permission',
			'ticket_number',
			'contact',
			'contact_id',
			'subject',
			'email',
			'phone',
			'ctime',
			'mtime',
			'type_name',
			'status_name',
			'status_id',
			'agent_name',
			'files_folder_id',
			'acl_id',
			'priority',
			'reload_ticketsgrid',
			'user_id',
			'user_name',
			'company_id',
			'company',
			'comments',
			'customfields',
			'panelId',
			'events',
			'tasks',
			'link_type',
			{
				name: 'rate_totals'
			},
			{
				name:'messages'
			},

			{
				name:'links'
			},

			{
				name:'files'
			}
			]
		});

		this.store.on('beforeload',function(){
			this.getEl().mask(GO.lang.waitMsgLoad);
		}, this);
		this.store.on('load', function(){
			this.getEl().unmask();
		}, this);

		this.template_summary =
		'<div class="wrapper">'+
		//'<div class="display-panel-heading">'+ GO.tickets.lang['ticketDetails'] +': <b>#{ticket_number}</b></div>'+
		'<table class="display-panel" cellpadding="0" cellspacing="0" border="0">'+
		'<tr>'+
		'<td style="vertical-align:top">'+
		'<table cellpadding="0" cellspacing="0" border="0">'+
		/*'<tr>'+
		'<td class="column_def">' + GO.lang['strSubject'] + ':</td><td>{subject}</td>'+
		'</tr>'+*/

		'<tr>'+
		'<td class="column_def">' + GO.tickets.lang.ticketId + ':</td><td>'+
		'#{ticket_number}'+
		'</td>'+
		'</tr>'+

		'<tpl if="company !=\'\'">'+
		'<tr>'+
		'<td class="column_def">' + GO.lang['strCompany'] + ':</td><td>'+
		'<tpl if="company_id &gt; 0">';
		this.template_summary += (GO.addressbook) ? '<a href="#" onclick="GO.linkHandlers[3].call(this, {company_id});">{company}</a>' : '{company}';
		this.template_summary += '</tpl>'+
		'<tpl if="company_id == 0">'+
		'{company}'+
		'</tpl>'+
		'</td>'+
		'</tr>'+
		'</tpl>'+

		'<tr>'+
		'<td class="column_def">' + GO.tickets.lang['contact'] + ':</td><td>'+
		'<tpl if="contact_id &gt; 0">';            
		this.template_summary += (GO.addressbook) ? '<a href="#" onclick="GO.linkHandlers[2].call(this, {contact_id});">{contact}</a>' : '{contact}';
		this.template_summary += '</tpl>'+
		'<tpl if="contact_id == 0">'+
		'{contact}'+
		'</tpl>'+
		'</td>'+
		'</tr>'+
		'<tr>'+
		'<td class="column_def">' + GO.lang['strOwner'] + ':</td><td>';
		this.template_summary += (GO.linkHandlers[8] != undefined) ? '<a href="#" onclick="GO.linkHandlers[8].call(this, {user_id});">{user_name}</a>' : '{user_name}';
		this.template_summary += '</td>'+
		'</tr>'+
		'<tr>'+
		'<td class="column_def">' + GO.lang['strEmail'] + ':</td><td>{[this.mailTo(values.email, values.contact)]}</a></td>'+
		'</tr>'+
		'<tpl if="phone.length">'+
		'<tr>'+
		'<td class="column_def">' + GO.lang['strPhone'] +':</td><td><a href="{[GO.util.callToHref(values.phone)]}">{phone}</a></td>'+
		'</tr>'+
		'</tpl>'+		
		'</table>'+
		'</td>'+

		'<td style="vertical-align:top">'+
		'<table cellpadding="0" cellspacing="0" border="0">'+
		'<tr>'+
		'<td class="column_def">' + GO.tickets.lang['agent'] + ':</td><td>{agent_name}</td>'+
		'</tr>'+
		'<tr>'+
		'<td class="column_def">' + GO.lang['strCtime'] + ':</td><td>{ctime}</td>'+
		'</tr>'+
		'<tr>'+
		'<td class="column_def">' + GO.lang['strMtime'] + ':</td><td>{mtime}</td>'+
		'</tr>'+
		'<tr>'+
		'<td class="column_def">' + GO.lang['strType'] + ':</td><td>{type_name}</td>'+
		'</tr>'+
		'<tr>'+
		'<td class="column_def">' + GO.lang['strStatus'] + ':</td><td>{status_name}</td>'+
		'</tr>'+
		'<tr>'+
		'<td class="column_def">' + GO.tickets.lang['priority'] + ':</td><td>{priority}</td>'+
		'</tr>'+
		'</table>'+
		'</td>'+
		'</tr>'+
		'</table>'+
		'<div class="display-panel-heading">' + GO.tickets.lang.messages + '</div>'+
		'</div>';


		var tpl =
		'<tpl for=".">'+
		this.template_summary+
		'<tpl for="messages">'+
		'<div class="msg-wrap" id="{message_id}">'+
		'<div class="msg-head"><span class="msg-left">{from_name}'+
		'<tpl if="!external">'+
		' ('+GO.tickets.lang['is_note']+')'+
		'</tpl>'+
		'</span><span class="msg-right">{ctime}</span></div>'+
		'<tpl if="content">'+
		'<div class="msg-content">{content}</div>'+
		'</tpl>'+
		'<tpl if="num_files">'+
		'<div class="msg-part">' + GO.tickets.lang.attachments + ':<br />'+
		'<tpl for="files">'+
		'<a class="go-grid-icon filetype filetype-{extension}" href="#files_{index}">{name}</a>'+
		'</tpl></div>'+
		'</tpl>'+
		'<tpl if="status.length">'+
		'<div class="msg-head">'+
		'<span class="msg-left">'+
		'<tpl if="status.length">'+
		GO.tickets.lang['statusChange']+': {status}' +
		'</tpl>'+
		'</span>'+
		'</div>'+
		'</tpl>';
		if(GO.settings.modules.tickets.write_permission){
			tpl +=
			'<tpl if="rate_hours">'+
		'<div class="ti-rate">{rate_name}: {rate_hours}</div>'+
		'</tpl>';
		}

		tpl +=
		'</div>' +
		'<div class="x-clear"></div>'+
		'</tpl>';
			

		if(GO.settings.modules.tickets.write_permission){
			tpl +=
			'<tpl if="rate_totals.length">'
			+ '<div class="display-panel-heading">' + GO.tickets.lang.rateTotals + '</div>'
			+ '<table class="ti-rate-totals" cellpadding="0" cellspacing="0">'
			+ '<tpl for="rate_totals">'
			+ '<tr><td>{name}</td><td>: {amount}</td></tr>'
			+ '</tpl>'
			+ '</table>'
			+ '</tpl>';
		}


		if(GO.customfields)
		{
			tpl +=GO.customfields.displayPanelTemplate;
		}

		var tplConfig={};

		if(GO.settings.modules.tickets.write_permission){
			if(GO.tasks)
				tpl +=GO.tasks.TaskTemplate;

			if(GO.calendar)
				tpl += GO.calendar.EventTemplate;


			tpl += GO.linksTemplate;

			

			tplConfig= Ext.apply(tplConfig, GO.linksTemplateConfig);


			if(GO.comments)
			{
				tpl += GO.comments.displayPanelTemplate;
			}
		}

		tpl += '</tpl>';

		tplConfig.panel=this;

		tplConfig.collapsibleSectionHeader = function(title, id, dataKey){
			this.panel.collapsibleSections[id]=dataKey;

			return '<div class="collapsible-display-panel-header">'+title+'<div class="x-tool x-tool-toggle" style="float:right;cursor:pointer" id="toggle-'+id+'">&nbsp;</div></div>';
		}

		tplConfig = Ext.apply(tplConfig, {
			addSlashes : function(str)
			{
				str = GO.util.html_entity_decode(str, 'ENT_QUOTES');
				str = GO.util.add_slashes(str);
				return str;
			},
			mailTo : function(email, name)
			{
				if(GO.email && GO.settings.modules.email.read_permission)
				{
					return '<a href="#" onclick="GO.email.showAddressMenu(event, \''+this.addSlashes(email)+'\',\''+this.addSlashes(name)+'\');">'+email+'</a>';
				}else {
					return '<a href="mailto:'+email+'">'+email+'</a>';
				}
			}
		});

		this.messagesView =  new Ext.DataView(
		{
			store:this.store,
			singleSelect:GO.settings.modules.tickets.write_permission,
			scope:this,
			overClass:'x-view-over',
			itemSelector:'div.msg-wrap',
			//emptyText:GO.lang['strNoItems'],
			tpl: new Ext.XTemplate(
				tpl,tplConfig),
			listeners :
			{
				dblclick:
				{
					scope:this,
					fn: function(dv,nodes)
					{
						if (dv.getSelectionCount() > 0)
						{
							var items = this.store.data.items[0];

							var index = dv.getSelectedIndexes();
							var message_id = items.data.messages[index].message_id;
							this.messageForm.show(message_id);							
						}
					}
				}
			}
		});

		this.items = [this.messagesView];


		this.on('afterbodyclick', function(panel, target, e, href){
			if(href!='#')
				window.open(href);
		}, this);

		GO.tickets.TicketPanel.superclass.initComponent.call(this);
	},

	
	createTopToolbar : function(){

		if(GO.settings.modules.tickets.write_permission){
			var tbar = GO.tickets.TicketPanel.superclass.createTopToolbar.call(this);


			tbar.push('-');
			tbar.push(this.claimButton = new Ext.Button({
				iconCls:"btn-reply-all",
				text:GO.tickets.lang.claim,
				tooltip:GO.tickets.lang.claimTooltip,
				handler: function()
				{
					this.toggleClaim(1);
				},
				hidden:true,
				scope:this
			}));
			tbar.push(this.unclaimButton = new Ext.Button({
				iconCls:"btn-forward",
				text:GO.tickets.lang.unclaim,
				tooltip:GO.tickets.lang.unclaimTooltip,
				handler: function()
				{
					this.toggleClaim(0);
				},
				hidden:true,
				scope:this
			}));
			tbar.push(this.openButton = new Ext.Button({
				iconCls:"btn-reply",
				text:GO.tickets.lang.reopen,
				tooltip:GO.tickets.lang.reopenTooltip,
				handler: function()
				{
					this.reopen();
				},
				hidden:true,
				scope:this
			}));
			return tbar;
		}else
		{
			return false;
		}
	},


	load : function(id, reload)
	{
		if(this.collapsed){
			this.collapsedLinkId=id;
		}else if(this.link_id!=id || reload)
		{
			this.ticket_id = this.link_id = id;

			if(!GO.tickets.statusesStore.loaded)
			{
				GO.tickets.statusesStore.load();
			}
			if(!GO.tickets.templatesStore.loaded)
			{
				GO.tickets.templatesStore.load();
			}

			this.store.baseParams.ticket_id = this.ticket_id;
			this.store.baseParams.hidden_sections=Ext.encode(this.hiddenSections);
			this.store.load({
				callback:function(){
					this.data = this.store.getAt(0).data;
					this.setClaimed(this.data.agent_id);
					var title = GO.tickets.lang.ticket+': #'+this.data.ticket_number+' '+this.data.subject;
					this.setTitle('<div style="height:15px"><span style="overflow:hidden" title="'+title+'">'+title+'</span></div>');

					var tbar = this.getTopToolbar();
					if(tbar)
					{
						tbar.setDisabled(false);
						this.editButton.setDisabled(!this.data.write_permission);
					}
					
					this.messageForm.prepareForm(this.data.id, this.data.status_id, this.data.status_name);


					for(var id in this.collapsibleSections){
						if(!this.data[this.collapsibleSections[id]]){
							this.toggleSection(id, true);
						}
					}

				},
				scope:this
			});
		}
	},
	setClaimed : function(agent_id)
	{
		this.is_claimed = (agent_id > 0) ? 1 : 0;
		this.is_claimed_by_user = (agent_id == GO.settings.user_id) ? 1 : 0;

		this.toggleButtons();
	},
	reset : function(){
		this.store.removeAll();
		var tbar = this.getTopToolbar();

		if(tbar)
			this.getTopToolbar().setDisabled(true);

		this.newMessageButton.setDisabled(true);

		this.link_id=0;		
		this.data={};
		this.ticket_id=0;

		if(this.title){
			this.setTitle(GO.tickets.lang.ticket);
		}else
		{
			//we are in a window
			this.ownerCt.setTitle(GO.tickets.lang.ticket);
		}

	},
	toggleButtons : function()
	{
		this.newMessageButton.setDisabled(!this.data.write_permission  || this.data.status_id == -1 || (!this.is_claimed && this.data.user_id!=GO.settings.user_id));
		
		if(GO.settings.modules.tickets.write_permission){			
			this.unclaimButton.setVisible(this.is_claimed_by_user && this.data.status_id != -1);
			this.claimButton.setVisible(!this.is_claimed && this.data.status_id != -1);
			this.openButton.setVisible(this.data.status_id == -1);

			//this.unclaimButton.setDisabled(!this.is_claimed_by_user);
			this.claimButton.setDisabled(this.is_claimed || !this.data.write_permission);
			this.openButton.setDisabled(!this.data.write_permission);
			this.editButton.setDisabled(!this.data.write_permission || !this.is_claimed || this.data.status_id == -1);

			if(this.link_type>0)
			{
				this.linkBrowseButton.setDisabled(false);
			}

			if(this.fileBrowseButton)
			{
				this.fileBrowseButton.setDisabled(this.files_folder_id<1);
			}

			if(this.data.write_permission)
			{
				this.newMenuButton.setLinkConfig({
					id:this.link_id,
					type:this.link_type,
					text: this.data.ticket_number,
					callback:this.reload,
					scope:this
				});
			}else
			{
				this.newMenuButton.setDisabled(true);
			}
		}
	//this.messageForm.btnSave.setDisabled(!this.write_permission || this.status_id == -1);

	},
	reopen : function()
	{
		Ext.Ajax.request({
			url: GO.settings.modules.tickets.url+'action.php',
			params: {
				ticket_id: this.ticket_id,
				task: 'reopen_ticket'
			},
			scope: this,
			callback: function(options, success, response)
			{
				var data = Ext.decode(response.responseText);

				if (!data.success)
				{
					Ext.Msg.alert(GO.lang['strError'], data.feedback)
				} else
{
					this.reload();

					GO.tickets.ticketsGrid.store.reload();
				}
			}
		});
	},
	setClaimed : function(agent_id)
	{
		this.is_claimed = (agent_id > 0) ? 1 : 0;
		this.is_claimed_by_user = (agent_id == GO.settings.user_id) ? 1 : 0;

		this.toggleButtons();
	},
	toggleClaim : function(claimed)
	{
		Ext.Ajax.request({
			url: GO.settings.modules.tickets.url+'action.php',
			params: {
				ticket_id: this.ticket_id,
				claimed: claimed,
				task: 'set_claim'
			},
			scope: this,
			callback: function(options, success, response)
			{
				var data = Ext.decode(response.responseText);

				if (!data.success)
				{
					Ext.Msg.alert(GO.lang['strError'], data.feedback)
					this.store.reload();
				} else {
					this.setClaimed(data.agent_id);

					var store = this.store.data.items[0].data;
					store.agent_name = data.agent_name;
					store.mtime = data.mtime;

					GO.tickets.mainPanel.centerPanel.store.reload();
					this.messagesView.refresh();
				}
			}
		});
	}
});