/**
 * Copyright Intermesh
 *
 * This file is part of Group-Office. You should have received a copy of the
 * Group-Office license along with Group-Office. See the file /LICENSE.TXT
 *
 * If you have questions write an e-mail to info@intermesh.nl
 *
 * @version $Id: TicketsGrid.js 12245 2011-11-15 08:49:48Z wsmits $
 * @copyright Copyright Intermesh
 * @author Michiel Schmidt <michiel@intermesh.nl>
 * @author Merijn Schering <mschering@intermesh.nl>
 */

GO.tickets.TicketsGrid = function(config){
	
	if(!config)
	{
		config = {};
	}
	
	config.title = GO.tickets.lang.tickets;
	config.layout='fit';
	config.autoScroll=true;
	config.split=true;
	config.paging=true;

	var fields ={
		fields:['id','ticket_number','priority','priority_name','agent_id','agent_name','contact_name','subject','ctime','mtime','status','status_id','type','unseen','email','phone','company'],
		columns:[
		{
			header: '&nbsp;',
      id:'first_column',
			dataIndex: 'unseen',
			hideInExport:true,
			width:30,
			renderer : function(value, cell, record) {
				var str = '';
				
				if(value=='1')
				{
					str += '<div class="tickets-grid-icon btn-unseen ti-status-' + record.data.status_id  + '"></div>';
				}else
				{
					str += '<div class="tickets-grid-icon btn-seen ti-status-' + record.data.status_id  + '"></div>';
				}
				return str;
			}
		},{
			header: GO.tickets.lang.ticketId, 
			dataIndex: 'ticket_number',
			width:110,
			hidden:true
		},{
			header: GO.lang.strSubject, 
			dataIndex: 'subject',
			width:280
		},{
			header: GO.tickets.lang.status, 
			dataIndex: 'status',
			width:80
		},{
			header: GO.tickets.lang.type,
			dataIndex: 'type',
			hidden:true,
			width:110
		},{
			header: GO.tickets.lang.priority,
			dataIndex: 'priority_name',
			width:70,
			hidden:true
		},{
			header: GO.tickets.lang.agent,
			dataIndex: 'agent_name',
			width:150
		},{
			header: GO.tickets.lang['contact'],
			dataIndex: 'contact_name',
			width:150
		},{
			header: GO.lang['strCompany'],
			dataIndex: 'company',
			width:150,
			hidden:true
		},{
			header: GO.lang.strEmail,
			dataIndex: 'email',
			hidden:true,
			width:110
		},{
			header: GO.lang.strPhone,
			dataIndex: 'phone',
			hidden:true,
			width:110
		},{
			header: GO.lang.strCtime, 
			dataIndex: 'ctime',
			hidden:true,
			width:110
		},{
			header: GO.lang.strMtime, 
			dataIndex: 'mtime',			
			width:110
		}
		]
		};

	if(GO.customfields)
	{
		GO.customfields.addColumns(20, fields);
	}
	config.store = new GO.data.JsonStore({
		url: GO.settings.modules.tickets.url+ 'json.php',
		baseParams:{
			task:'tickets',
			type_id:0
		},
		root: 'results',
		id: 'id',
		totalProperty:'total',
		fields: fields.fields,
		remoteSort: true
	});
	
	config.store.on('load', function()
	{
		if(config.store.reader.jsonData.feedback)
		{
			alert(config.store.reader.jsonData.feedback);
		}
	},this)

	var columnModel =  new Ext.grid.ColumnModel({
		defaults:{
			sortable:true
		},
		columns:fields.columns
	});
	config.cm=columnModel;

	config.view=new Ext.grid.GridView({
		emptyText: GO.lang.strNoItems,
		getRowClass:function(row, index, rowParams) 
		{                                        
			var cls = '';
			if (row.data.unseen == true)
			{                                
				cls+= 'ml-new-row ';
			}
			
			if(row.data.priority=="0"){
				cls += 'ti-low-priority ';
			}else if(row.data.priority=="2"){
				cls += 'ti-high-priority ';
			}

			return cls;
		}		
	});
			
	config.sm=new Ext.grid.RowSelectionModel();
	config.loadMask=true;
	
	this.searchField = new GO.form.SearchField({
		store: config.store,
		width:320
	});

	config.tbar = [GO.lang['strSearch'] + ':', this.searchField];

	GO.tickets.TicketsGrid.superclass.constructor.call(this, config);

	if(GO.settings.modules.tickets.write_permission)
		this.on('rowcontextmenu', this.onContextClick, this);

};

Ext.extend(GO.tickets.TicketsGrid, GO.grid.GridPanel,{

	mtime: 0,
	total: 0,
	
	checkGrid : function(total, mtime, reload)
	{
		if(!this.store.baseParams.query && ((this.total != total) || (this.mtime != mtime) || reload))
		{		
			if(this.total != total)
			{
				GO.tickets.filterPanel.store.reload();
			}
			this.store.reload();
		}
	},
	setVars : function(mtime, total)
	{
		this.mtime = (mtime) ? mtime : 0;
		this.total = (total) ? total : 0;
	},
	flagTickets : function(tickets, unseen)
	{
		if(tickets.length){
			this.store.baseParams['flag_tickets'] = Ext.encode(tickets);
			this.store.baseParams['unseen'] = unseen;
			this.store.reload();

			this.selModel.clearSelections();

			delete this.store.baseParams.flag_tickets;
			delete this.store.baseParams.unseen;
		}
	},
	onContextClick : function(grid, index, e)
	{
		if(!this.menu)
		{
			this.menu = new Ext.menu.Menu({
				id:'grid-ctx',
				items: [
				{
					text:GO.tickets.lang.markAsRead,
					scope:this,
					handler: function(){

						var records = grid.selModel.getSelections();
						var selectedRows = [];
						for(var i=0;i<records.length;i++){
							if(records[i].get('unseen')=='1'){// && records[i].get('agent_id')==GO.settings.user_id){
								selectedRows.push(records[i].id);
								GO.tickets.totalUnseen--;
							}
						}
						this.flagTickets(selectedRows, 0);
					}
				},{
					text:GO.tickets.lang.markAsUnread,
					scope:this,
					handler: function(){

						var records = grid.selModel.getSelections();
						var selectedRows = [];
						for(var i=0;i<records.length;i++){
							if(records[i].get('unseen')=='0'){// && records[i].get('agent_id')==GO.settings.user_id){
								selectedRows.push(records[i].id);
								GO.tickets.totalUnseen++;
							}
						}

						this.flagTickets(selectedRows, 1);
					}
				}]
			});
            
			this.menu.on('hide', this.onContextHide, this);
		}
        
		e.stopEvent();

		if(GO.settings.modules.tickets.write_permission){
        
			this.ctxRecord = this.store.getAt(index);
		//var agent_id = this.ctxRecord.data.agent_id;

		//if(agent_id == GO.settings.user_id)
			this.menu.showAt(e.getXY());
		}
        
	}, 
	onContextHide : function()
	{
		if(this.selectedRows)
		{
			this.selectedRows = null;
		}
	}
    
});