/**
 * Copyright Intermesh
 *
 * This file is part of Group-Office. You should have received a copy of the
 * Group-Office license along with Group-Office. See the file /LICENSE.TXT
 *
 * If you have questions write an e-mail to info@intermesh.nl
 *
 * @version $Id: TypeDialog.js 11060 2011-07-05 09:51:04Z wsmits $
 * @copyright Copyright Intermesh
 * @author Michiel Schmidt <michiel@intermesh.nl>
 * @author Merijn Schering <mschering@intermesh.nl>
 */

GO.tickets.TypeDialog = function(config){	
	
	if(!config)
	{
		config={};
	}
	
	this.buildForm();
	
	var focusFirstField = function(){
		this.propertiesPanel.items.items[0].focus();
	};
	
	config.layout='fit';
	config.title=GO.tickets.lang.type;
	config.maximizable=true;
	config.modal=false;
	config.width=700;
	config.height=500;
	config.resizable=false;
	config.minizable=true;
	config.closeAction='hide';	
	config.items=this.formPanel;
	config.focus=focusFirstField.createDelegate(this);
	config.buttons=[{
		text: GO.lang['cmdOk'],
		handler: function()
		{
			this.submitForm(true);
		},
		scope: this
	},{
		text: GO.lang['cmdApply'],
		handler: function()
		{
			this.submitForm();
		},
		scope:this
	},{
		text: GO.lang['cmdClose'],
		handler: function()
		{
			this.hide();
		},
		scope:this
	}];
	
	GO.tickets.TypeDialog.superclass.constructor.call(this, config);
	
	this.addEvents({
		'save' : true
	});
}

Ext.extend(GO.tickets.TypeDialog, Ext.Window,{
		
	show : function (type_id)
	{
		if(!this.rendered)
			this.render(Ext.getBody());
		
		this.tabPanel.setActiveTab(0);
		
		if(!type_id)
		{
			type_id=0;			
		}
			
		this.setTypeId(type_id);
		
		if(this.type_id>0)
		{
			this.formPanel.load({
				url : GO.settings.modules.tickets.url+'json.php',
				
				success:function(form, action)
				{
					this.setWritePermission(action.result.data.write_permission);					
					this.readPermissionsTab.setAcl(action.result.data.acl_id);
					
					this.selectUser.setRemoteText(action.result.data.user_name);
					
					GO.tickets.TypeDialog.superclass.show.call(this);
				},
				failure:function(form, action)
				{
					Ext.Msg.alert(GO.lang['strError'], action.result.feedback)
				},
				scope: this
			});
		}else {
			this.formPanel.form.reset();

			this.readPermissionsTab.setAcl(0);
			
			this.setWritePermission(true);
			
			GO.tickets.TypeDialog.superclass.show.call(this);
		}
	},
	setWritePermission : function(writePermission)
	{
		this.buttons[0].setDisabled(!writePermission);
		this.buttons[1].setDisabled(!writePermission);
	},
	setTypeId : function(type_id)
	{
		this.formPanel.form.baseParams['type_id']=type_id;
		this.type_id=type_id;
	},
	submitForm : function(hide)
	{
		this.formPanel.form.submit(
		{
			url:GO.settings.modules.tickets.url+'action.php',
			params: {
				task : 'save_type'
			},
			waitMsg:GO.lang['waitMsgSave'],
			success:function(form, action)
			{
				this.fireEvent('save', this);
				
				if(hide)
				{
					this.hide();	
				}else{
					if(action.result.type_id)
					{
						this.setTypeId(action.result.type_id);
						
						this.readPermissionsTab.setAcl(action.result.acl_id);
					}
				}
			},		
			failure: function(form, action)
			{
				if(action.failureType == 'client')
				{					
					Ext.MessageBox.alert(GO.lang['strError'], GO.lang['strErrorsInForm']);			
				} else {
					Ext.MessageBox.alert(GO.lang['strError'], action.result.feedback);
				}
			},
			scope: this
		});
	},
	buildForm : function ()
	{
		var propItems = [ 
		this.selectUser = new GO.form.SelectUser({
			fieldLabel:GO.lang['strUser'],
			disabled:!GO.settings.modules['tickets']['write_permission'],
			value:GO.settings.user_id,
			anchor:'95%'
		}),{
			xtype:'textfield',
			name:'name',
			anchor:'95%',
			allowBlank:false,
			fieldLabel:GO.lang.strName
		},{
      xtype:'textarea',
			name:'description',
			anchor:'95%',
			allowBlank:true,
			fieldLabel:GO.lang.strDescription
		},{
			xtype:'checkbox',
			name:'show_external',
			boxLabel:GO.tickets.lang.show_external,
			hideLabel:true
		},{
			xtype:'checkbox',
			name:'show_from_others',
			boxLabel:GO.tickets.lang.show_from_others,
			hideLabel:true
		},{
			xtype:'checkbox',
			name:'notify_agents_on_new',
			boxLabel:GO.tickets.lang.notifyAgents,
			hideLabel:true,
			listeners:{
				scope:this,
				check:function(cb, checked){
					this.formPanel.form.findField('notify_admin').setDisabled(!checked);
				}
			}
		},{
			xtype:'checkbox',
			name:'notify_admin',
			boxLabel:GO.tickets.lang.notifyAdmin,
			hideLabel:true,
			disabled:true
		}
		];
			
		this.propertiesPanel = new Ext.Panel({
			url:GO.settings.modules.tickets.url+'action.php',
			border:false,
			baseParams:{
				task:'type'
			},
			title:GO.lang['strProperties'],	
			cls:'go-form-panel',
			waitMsgTarget:true,			
			layout:'form',
			autoScroll:true,
			items:propItems
		});
				     		
		this.readPermissionsTab = new GO.grid.PermissionsPanel();
  
		var items = [this.propertiesPanel, this.readPermissionsTab];
			 
		this.tabPanel = new Ext.TabPanel({
			activeTab:0,      
			deferredRender:false,
			border:false,
			items:items,
			anchor:'100% 100%'
		});
	    
		this.formPanel = new Ext.form.FormPanel({
			waitMsgTarget:true,
			url:GO.settings.modules.tickets.url+'action.php',
			border:false,
			baseParams:{
				task:'type'
			},
			items:this.tabPanel
		});
	}
});