/** 
 * Copyright Intermesh
 * 
 * This file is part of Group-Office. You should have received a copy of the
 * Group-Office license along with Group-Office. See the file /LICENSE.TXT
 * 
 * If you have questions write an e-mail to info@intermesh.nl
 * 
 * @copyright Copyright Intermesh
 * @version $Id: HoursDialog.js 11441 2011-09-27 10:30:00Z mschering $
 * @author Merijn Schering <mschering@intermesh.nl>
 */


GO.timeregistration.HoursDialog = function(config)
{
	config = config || {};
	
	this.unitsField = new GO.form.NumberField({
		name: 'units',
		width: 40,
		allowBlank:false,
		fieldLabel: GO.projects.lang.units,
		value: GO.util.numberFormat("0",2,GO.settings.decimal_separator, GO.settings.thousands_separator)
	});  	      		

	var comments = new Ext.form.TextArea({
		name: 'comments',
		anchor:'100%',
		height:'100',
		allowBlank:true,
		fieldLabel: GO.lang.strDescription
	});
  	
	var now = new Date();
	var date = new Ext.form.DateField({
		name: 'date',
		anchor:'100%',
		format: GO.settings['date_format'],
		allowBlank:false,
		fieldLabel: GO.lang['strDate'],
		value: now.format(GO.settings.date_format)
	});
  	
	this.selectFee = new GO.timeregistration.SelectFee({
		anchor:'100%'
	
	});
	
	var items =[
		this.unitsField,
		date,
		this.selectFee,
		comments
		] ;

	if(GO.customfields){
		var cfFS, formField;
		for(var i=0;i<GO.customfields.types["19"].panels.length;i++)
		{
			var cfPanel = GO.customfields.types["19"].panels[i];

			cfFS = {
				layout: 'form',
				columnWidth:.5,
				items:[]
			};
			for(var n=0;n<cfPanel.customfields.length;n++)
			{
				formField = GO.customfields.getFormField(cfPanel.customfields[n]);
				formField.anchor='100%';
				cfFS.items.push(formField);
			}
			items.push(cfFS);
		}
	}

	this.formPanel = new Ext.FormPanel({
		layout:'form',
		cls:'go-form-panel',
		defaults:{
			border:false
		},
		baseParams:{
			hours_id:0,
			task:'hours_entry'
		},
		items:items,
		waitMsgTarget:true
	});

	config.title=GO.projects.lang.units;
	config.width=600;
	config.autoHeight=true;
	config.items=this.formPanel;
	config.buttons=[{
		text: GO.lang['cmdOk'],
		handler: function(){
			this.submit();
		},
		scope: this
	},{
		text: GO.lang['cmdClose'],
		handler: function(){
			this.hide();
		},
		scope:this
	}
	];
    		

	GO.timeregistration.HoursDialog.superclass.constructor.call(this, config);
	
	this.addEvents({
		'save':true
	});
};

Ext.extend(GO.timeregistration.HoursDialog, GO.Window,{



	submit : function(){
		this.formPanel.form.submit({
			url:GO.settings.modules.timeregistration.url+'action.php',
			params: {
				'task' : 'save_hours'
			},
			waitMsg:GO.lang['waitMsgSave'],
			success:function(form, action){				
				this.fireEvent('save', this);
				this.hide();
			},		
			failure: function(form, action) {
				if (action.failureType == 'client') {
					Ext.MessageBox.alert(GO.lang['strError'],
						GO.lang['strErrorsInForm']);
				} else {
					Ext.MessageBox.alert(GO.lang['strError'],
						action.result.feedback);
				}
			},
			scope: this
		});		
	},
	
	
	show : function(hours_id){
		
		this.render(Ext.getBody());
		
		this.setHoursId(hours_id);
		
		this.formPanel.load({
			url : GO.settings.modules.timeregistration.url+'json.php',
			success:function(form, action)
			{
				GO.timeregistration.HoursDialog.superclass.show.call(this);
			},
			failure:function(form, action)
			{
				Ext.Msg.alert(GO.lang['strError'], action.result.feedback);
			},
			scope: this
		});
	},
	
	reset : function(){		
		this.formPanel.form.reset();
		this.selectFee.selectFirst();		
	},
	setHoursId : function(hours_id)
	{
		this.formPanel.form.baseParams['hours_id']=hours_id;
		this.hours_id=hours_id;
	}		

});