/**
 * Copyright Intermesh
 *
 * This file is part of Group-Office. You should have received a copy of the
 * Group-Office license along with Group-Office. See the file /LICENSE.TXT
 *
 * If you have questions write an e-mail to info@intermesh.nl
 *
 * @copyright Copyright Intermesh
 * @version $Id: MultiplePerDay.js 12952 2012-02-14 13:43:17Z wsmits $
 * @author Merijn Schering <mschering@intermesh.nl>
 */



GO.timeregistration.MultiplePerDay = function(config) {
	config = config || {};

	config.border=true;
	config.title = GO.projects.lang.timeTracking;
	config.waitMsgTarget = true;
	config.autoScroll = true;
	config.layout='border';

	this.selectProject = new GO.timeregistration.SelectProject({
		allowBlank:false,
		anchor:'100%'
	});

	this.stStore = new GO.data.JsonStore({
		url: GO.settings.modules.timeregistration.url+ 'json.php',
		baseParams:{
			task:'standard_tasks'
		},
		root: 'results',
		totalProperty: 'total',
		id: 'id',
		fields:['id', 'code', 'name', 'units', 'description', 'display']
	});

	this.selectStandardTask = new GO.form.ComboBoxReset({
		name: 'standard_task',
		fieldLabel: GO.timeregistration.lang.standardTask,
		allowBlank:true,
		emptyText:GO.timeregistration.lang.none,
		anchor:'100%',
		store: this.stStore,
		triggerAction:'all',
		valueField: 'id',
		displayField: 'display',
		//tpl: '<tpl for="."><div class="x-combo-list-item">[{code}] {name}</div></tpl>',
		listeners:{
			scope:this,
			select: function(combo, record, index){
				this.unitsField.setValue(record.get('units'));
				comments.setValue(record.get('description'));
			}
		}
	});

	this.unitsField = new GO.form.NumberField({
		name: 'units',
		width: 40,
		allowBlank:false,
		fieldLabel: GO.projects.lang.units,
		value: GO.util.numberFormat("0",2,GO.settings.decimal_separator, GO.settings.thousands_separator),
		listeners:{
			scope:this,
			change: function(field, value){
				field.setValue(this.roundTime(value));
			}
		}
	});

	var comments = new Ext.form.TextArea({
		name: 'comments',
		anchor:'100%',
		height:'100',
		allowBlank:true,
		fieldLabel: GO.lang.strDescription,
		height:60
	});

	var now = new Date();

	
	var index;
	var items=[];
	this.cb = [];
	var weekday = now.format('w');
	for (var day = 1; day < 8; day++) {
		index = day>6 ? 0 : day;
		this.cb[index] = new Ext.form.Radio({
			boxLabel : GO.lang.shortDays[index],
			inputValue: day,
			checked : index==weekday,
			name:'weekday',
			hideLabel : true
		});
		items.push(this.cb[index]);
	}

	var daysGroup = {
		xtype: 'radiogroup',
		hideLabel: false,		
		fieldLabel:GO.lang.strDay,
		itemCls: 'x-check-group-alt',
		name:'day',
		items:items
	};

	this.selectFee = new GO.timeregistration.SelectFee({
		anchor:'100%'
	});

	var items = [

		this.selectStandardTask,
		this.selectProject,
		this.unitsField,
		daysGroup,
		this.selectFee,
		comments
		

	];

	if(GO.customfields){
		var cfFS, formField;
		for(var i=0;i<GO.customfields.types["19"].panels.length;i++)
		{
			var cfPanel = GO.customfields.types["19"].panels[i];

			cfFS = {
				layout: 'form',
				columnWidth:.5,
				items:[]
			};
			for(var n=0;n<cfPanel.customfields.length;n++)
			{
				formField = GO.customfields.getFormField(cfPanel.customfields[n]);
				formField.anchor='100%';
				cfFS.items.push(formField);
			}
			items.push(cfFS);
		}
	}

	this.formPanel = new Ext.FormPanel({
		layout:'form',
		region:'north',
		autoHeight:true,
		bodyStyle:'padding:5px;',
		defaults:{
			border:false,
			bodyStyle:'padding:5px;'
		},
		baseParams:{
			task:'save_hours'
		},
		items:items,
		waitMsgTarget:true,
		buttonAlign:'left',
		buttons:[{
			text:GO.lang.cmdSave,
			scope:this,
			handler:function(){
				this.formPanel.form.submit({
					url:GO.settings.modules.timeregistration.url+'action.php',
					params: {
						'user_id' : this.hoursGrid.store.baseParams.user_id,
						date: this.store.baseParams.date
					},
					waitMsg:GO.lang['waitMsgSave'],
					success:function(form, action){
						this.hoursGrid.store.reload();
						//this.formPanel.form.reset();
						comments.reset();
					},
					failure: function(form, action) {
						if (action.failureType == 'client') {
							Ext.MessageBox.alert(GO.lang['strError'],
								GO.lang['strErrorsInForm']);
						} else {
							Ext.MessageBox.alert(GO.lang['strError'],
								action.result.feedback);
						}
					},
					scope: this
				});
			}
		}]
	});

	this.hoursGrid = new GO.timeregistration.HoursGrid({
		region:'center'
	});
	this.hoursGrid.store.baseParams.user_id=GO.settings.user_id;

	this.store = this.hoursGrid.store;

	this.store.on('load', function(){
		this.hours_booked=this.store.reader.jsonData.totals.units;
	},this);


	config.items=[this.formPanel, this.hoursGrid];
	
	GO.timeregistration.MultiplePerDay.superclass.constructor.call(this, config);
}

Ext.extend(GO.timeregistration.MultiplePerDay, Ext.Panel, {
	hours_booked:0,
	
	isClosed : false,
	
	setClosed : function(closed){
		this.isClosed = closed;
		this.formPanel.setDisabled(closed);
		this.hoursGrid.setClosed(closed);
	},

	roundTime : function(value) {
		value = GO.util.unlocalizeNumber(value);
		value = GO.util.round(value*60, GO.timeregistration.roundMinutes, !GO.timeregistration.roundUp);
		value = value/60;
		return GO.util.numberFormat(value, this.decimals);
	},

	setDate : function(date){

		if (!date) {
			var now = new Date();
			date = now.getLastSunday();
			date = date.add(Date.DAY,parseInt(GO.settings.first_weekday));
		}

		//var firstWeekDay = date.add(Date.DAY,parseInt(GO.settings.first_weekday));
		this.setTitle(GO.lang.strWeek+' '+date.format('W')+' ('+date.format(GO.settings.date_format)+')');

		this.store.commitChanges();
		this.store.baseParams.date = date.format(GO.settings.date_format);

		this.store.load();
	},

	confirmChanges : function() {
		return true;
	},

	isDirty : function(){
		var mods = this.store.getModifiedRecords();
		return mods.length>0;
	}

});